*========================PROGRAM: PQI_ALL_FORMATS.SAS =======================;
*============================================================================;
* Title:
*     Format Library for Prevention Quality Indicators Program;
*
* Description:
*     FORMAT LIB FOR AHRQ PREVENTION QUALITY INDICATORS;
*
*           >>>  AHRQ QI ICD-10 VERSION 6.0 <<<
*	          >>> VERSION DATE JULY, 2016 <<< 
*============================================================================;
*PATHNAME specifies the location of the PQI folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=c:\Pathname;                        *<==USER MUST modify;

filename CONTROL "&PATHNAME.\PQI\Programs\PQI_ALL_CONTROL.SAS"; 
 %INCLUDE CONTROL; 
 
proc format Library=library;

 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR STRATIFIERS ---------------------------------- */
 /* -------------------------------------------------------------- */

 /* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
 1 = 'Male'
 2 = 'Female'
  ;

 /* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value AGECAT
 0 = '00 to 17'
 1 = '18 to 39'
 2 = '40 to 64'
 3 = '65 to 74'
 4 = '75+'
  ;

 /* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
 1 = 'White'
 2 = 'Black'
 3 = 'Hispanic'
 4 = 'Asian and NH/PI'
 5 = 'Amer Indian/AN'
 6 = 'Other'
  ;

 * -------------------------------------------------------------- ;
 * --- QI DEFINING FORMATS -------------------------------------- ;
 * -------------------------------------------------------------- ;

 * -------------------------------------------------------------- ;
 * --- FORMATS - AREA LEVEL PQI INDICATORS   -------------------- ;
 * -------------------------------------------------------------- ;

 /* ---------------------------------------------- */
 /* Diabetes short term complication rate (ACDIAS) */
 /*   PQI  01                                      */
 /* ---------------------------------------------- */

 /* Diabetes with Short Term Complications */
 /* ICD-10-CM Diagnosis Codes: */

value $ACDIASD
"E1010"  =  "1"  /* Type 1 diabetes mellitus with ketoacidosis without coma */
"E1011"  =  "1"  /* Type 1 diabetes mellitus with ketoacidosis with coma */
"E10641"  =  "1"  /* Type 1 diabetes mellitus with hypoglycemia with coma */
"E1065"  =  "1"  /* Type 1 diabetes mellitus with hyperglycemia */
"E1100"  =  "1"  /* Type 2 diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1101"  =  "1"  /* Type 2 diabetes mellitus with hyperosmolarity with coma */
"E11641"  =  "1"  /* Type 2 diabetes mellitus with hypoglycemia with coma */
"E1165"  =  "1"  /* Type 2 diabetes mellitus with hyperglycemia */
OTHER   = 0 ;

/* Gastroenteritis */
/* ICD-10-CM Diagnosis Codes: */

value $ACPGASD
"A080"  =  "1"  /* Rotaviral enteritis */
"A0811"  =  "1"  /* Acute gastroenteropathy due to Norwalk agent */
"A0819"  =  "1"  /* Acute gastroenteropathy due to other small round viruses */
"A082"  =  "1"  /* Adenoviral enteritis */
"A0831"  =  "1"  /* Calicivirus enteritis */
"A0832"  =  "1"  /* Astrovirus enteritis */
"A0839"  =  "1"  /* Other viral enteritis */
"A084"  =  "1"  /* Viral intestinal infection, unspecified */
"A088"  =  "1"  /* Other specified intestinal infections */
"A09"  =  "1"  /* Infectious gastroenteritis and colitis, unspecified */
"K5289"  =  "1"  /* Other specified noninfective gastroenteritis and colitis */
"K529"  =  "1"  /* Noninfective gastroenteritis and colitis, unspecified */
OTHER   = "0" ;


 /* --------------------------------- */
 /* Perforated Appendix rate (ACSAPP) */
 /*   PQI  02                         */
 /* --------------------------------- */

 /* Perforated Appendix (Outcome of Interest) */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSAPPD
"K352"  =  "1"  /* Acute appendicitis with generalized peritonitis */
"K353"  =  "1"  /* Acute appendicitis with localized peritonitis */
OTHER   = 0 ;

 /* Appendicitis (Population at Risk) */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSAP2D
"K352"  =  "1"  /* Acute appendicitis with generalized peritonitis */
"K353"  =  "1"  /* Acute appendicitis with localized peritonitis */
"K3580"  =  "1"  /* Unspecified acute appendicitis */
"K3589"  =  "1"  /* Other acute appendicitis */
"K37"  =  "1"  /* Unspecified appendicitis */
OTHER   = 0 ;


 /* --------------------------------------------- */
 /* Diabetes long term complication rate (ACDIAL) */
 /*   PQI  03                                     */
 /* --------------------------------------------- */

 /* Diabetes with Long Term Complications */
 /* ICD-10-CM Diagnosis Codes: */

value $ACDIALD
"E1021"  =  "1"  /* Type 1 diabetes mellitus with diabetic nephropathy */
"E1022"  =  "1"  /* Type 1 diabetes mellitus with diabetic chronic kidney disease */
"E1029"  =  "1"  /* Type 1 diabetes mellitus with other diabetic kidney complication */
"E10311"  =  "1"  /* Type 1 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E10319"  =  "1"  /* Type 1 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E10321"  =  "1"  /* Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E10329"  =  "1"  /* Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E10331"  =  "1"  /* Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E10339"  =  "1"  /* Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E10341"  =  "1"  /* Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E10349"  =  "1"  /* Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E10351"  =  "1"  /* Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E10359"  =  "1"  /* Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E1036"  =  "1"  /* Type 1 diabetes mellitus with diabetic cataract */
"E1039"  =  "1"  /* Type 1 diabetes mellitus with other diabetic ophthalmic complication */
"E1040"  =  "1"  /* Type 1 diabetes mellitus with diabetic neuropathy, unspecified */
"E1041"  =  "1"  /* Type 1 diabetes mellitus with diabetic mononeuropathy */
"E1042"  =  "1"  /* Type 1 diabetes mellitus with diabetic polyneuropathy */
"E1043"  =  "1"  /* Type 1 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1044"  =  "1"  /* Type 1 diabetes mellitus with diabetic amyotrophy */
"E1049"  =  "1"  /* Type 1 diabetes mellitus with other diabetic neurological complication */
"E1051"  =  "1"  /* Type 1 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1052"  =  "1"  /* Type 1 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1059"  =  "1"  /* Type 1 diabetes mellitus with other circulatory complications */
"E10610"  =  "1"  /* Type 1 diabetes mellitus with diabetic neuropathic arthropathy */
"E10618"  =  "1"  /* Type 1 diabetes mellitus with other diabetic arthropathy */
"E10620"  =  "1"  /* Type 1 diabetes mellitus with diabetic dermatitis */
"E10621"  =  "1"  /* Type 1 diabetes mellitus with foot ulcer */
"E10622"  =  "1"  /* Type 1 diabetes mellitus with other skin ulcer */
"E10628"  =  "1"  /* Type 1 diabetes mellitus with other skin complications */
"E10630"  =  "1"  /* Type 1 diabetes mellitus with periodontal disease */
"E10638"  =  "1"  /* Type 1 diabetes mellitus with other oral complications */
"E1069"  =  "1"  /* Type 1 diabetes mellitus with other specified complication */
"E108"  =  "1"  /* Type 1 diabetes mellitus with unspecified complications */
"E1121"  =  "1"  /* Type 2 diabetes mellitus with diabetic nephropathy */
"E1122"  =  "1"  /* Type 2 diabetes mellitus with diabetic chronic kidney disease */
"E1129"  =  "1"  /* Type 2 diabetes mellitus with other diabetic kidney complication */
"E11311"  =  "1"  /* Type 2 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E11319"  =  "1"  /* Type 2 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E11321"  =  "1"  /* Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E11329"  =  "1"  /* Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E11331"  =  "1"  /* Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E11339"  =  "1"  /* Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E11341"  =  "1"  /* Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E11349"  =  "1"  /* Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E11351"  =  "1"  /* Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E11359"  =  "1"  /* Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E1136"  =  "1"  /* Type 2 diabetes mellitus with diabetic cataract */
"E1139"  =  "1"  /* Type 2 diabetes mellitus with other diabetic ophthalmic complication */
"E1140"  =  "1"  /* Type 2 diabetes mellitus with diabetic neuropathy, unspecified */
"E1141"  =  "1"  /* Type 2 diabetes mellitus with diabetic mononeuropathy */
"E1142"  =  "1"  /* Type 2 diabetes mellitus with diabetic polyneuropathy */
"E1143"  =  "1"  /* Type 2 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1144"  =  "1"  /* Type 2 diabetes mellitus with diabetic amyotrophy */
"E1149"  =  "1"  /* Type 2 diabetes mellitus with other diabetic neurological complication */
"E1151"  =  "1"  /* Type 2 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1152"  =  "1"  /* Type 2 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1159"  =  "1"  /* Type 2 diabetes mellitus with other circulatory complications */
"E11610"  =  "1"  /* Type 2 diabetes mellitus with diabetic neuropathic arthropathy */
"E11618"  =  "1"  /* Type 2 diabetes mellitus with other diabetic arthropathy */
"E11620"  =  "1"  /* Type 2 diabetes mellitus with diabetic dermatitis */
"E11621"  =  "1"  /* Type 2 diabetes mellitus with foot ulcer */
"E11622"  =  "1"  /* Type 2 diabetes mellitus with other skin ulcer */
"E11628"  =  "1"  /* Type 2 diabetes mellitus with other skin complications */
"E11630"  =  "1"  /* Type 2 diabetes mellitus with periodontal disease */
"E11638"  =  "1"  /* Type 2 diabetes mellitus with other oral complications */
"E1169"  =  "1"  /* Type 2 diabetes mellitus with other specified complication */
"E118"  =  "1"  /* Type 2 diabetes mellitus with unspecified complications */
OTHER   = 0 ;

 /* --------------------- */
 /* Asthma rate (ACSAST)  */
 /*   PQI  15 - Adult    */
 /* --------------------- */

 /* Asthma                    */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSASTD
"J4521"  =  "1"  /* Mild intermittent asthma with (acute) exacerbation */
"J4522"  =  "1"  /* Mild intermittent asthma with status asthmaticus */
"J4531"  =  "1"  /* Mild persistent asthma with (acute) exacerbation */
"J4532"  =  "1"  /* Mild persistent asthma with status asthmaticus */
"J4541"  =  "1"  /* Moderate persistent asthma with (acute) exacerbation */
"J4542"  =  "1"  /* Moderate persistent asthma with status asthmaticus */
"J4551"  =  "1"  /* Severe persistent asthma with (acute) exacerbation */
"J4552"  =  "1"  /* Severe persistent asthma with status asthmaticus */
"J45901"  =  "1"  /* Unspecified asthma with (acute) exacerbation */
"J45902"  =  "1"  /* Unspecified asthma with status asthmaticus */
"J45990"  =  "1"  /* Exercise induced bronchospasm */
"J45991"  =  "1"  /* Cough variant asthma */
"J45998"  =  "1"  /* Other asthma */
OTHER   = 0 ;

 /* EXCLUDE: CYSTIC FIBROSIS AND ANOMALIES OF RESPIRATORY SYSTEM */
 /* ICD-10-CM DIAGNOSIS CODES */

value $RESPAN
"E840"  =  "1"  /* Cystic fibrosis with pulmonary manifestations */
"E8411"  =  "1"  /* Meconium ileus in cystic fibrosis */
"E8419"  =  "1"  /* Cystic fibrosis with other intestinal manifestations */
"E848"  =  "1"  /* Cystic fibrosis with other manifestations */
"E849"  =  "1"  /* Cystic fibrosis, unspecified */
"J8483"  =  "1"  /* Surfactant mutations of the lung */
"J84841"  =  "1"  /* Neuroendocrine cell hyperplasia of infancy */
"J84842"  =  "1"  /* Pulmonary interstitial glycogenosis */
"J84843"  =  "1"  /* Alveolar capillary dysplasia with vein misalignment */
"J84848"  =  "1"  /* Other interstitial  lung diseases of childhood */
"P270"  =  "1"  /* Wilson-Mikity syndrome */
"P271"  =  "1"  /* Bronchopulmonary dysplasia originating in the perinatal period */
"P278"  =  "1"  /* Other chronic respiratory diseases originating in the perinatal period */
"P279"  =  "1"  /* Unspecified chronic respiratory disease originating in the perinatal period */
"Q254"  =  "1"  /* Other congenital malformations of aorta */
"Q311"  =  "1"  /* Congenital subglottic stenosis */
"Q312"  =  "1"  /* Laryngeal hypoplasia */
"Q313"  =  "1"  /* Laryngocele */
"Q315"  =  "1"  /* Congenital laryngomalacia */
"Q318"  =  "1"  /* Other congenital malformations of larynx */
"Q319"  =  "1"  /* Congenital malformation of larynx, unspecified */
"Q320"  =  "1"  /* Congenital tracheomalacia */
"Q321"  =  "1"  /* Other congenital malformations of trachea */
"Q322"  =  "1"  /* Congenital bronchomalacia */
"Q323"  =  "1"  /* Congenital stenosis of bronchus */
"Q324"  =  "1"  /* Other congenital malformations of bronchus */
"Q330"  =  "1"  /* Congenital cystic lung */
"Q331"  =  "1"  /* Accessory lobe of lung */
"Q332"  =  "1"  /* Sequestration of lung */
"Q333"  =  "1"  /* Agenesis of lung */
"Q334"  =  "1"  /* Congenital bronchiectasis */
"Q335"  =  "1"  /* Ectopic tissue in lung */
"Q336"  =  "1"  /* Congenital hypoplasia and dysplasia of lung */
"Q338"  =  "1"  /* Other congenital malformations of lung */
"Q339"  =  "1"  /* Congenital malformation of lung, unspecified */
"Q340"  =  "1"  /* Anomaly of pleura */
"Q341"  =  "1"  /* Congenital cyst of mediastinum */
"Q348"  =  "1"  /* Other specified congenital malformations of respiratory system */
"Q349"  =  "1"  /* Congenital malformation of respiratory system, unspecified */
"Q390"  =  "1"  /* Atresia of esophagus without fistula */
"Q391"  =  "1"  /* Atresia of esophagus with tracheo-esophageal fistula */
"Q392"  =  "1"  /* Congenital tracheo-esophageal fistula without atresia */
"Q393"  =  "1"  /* Congenital stenosis and stricture of esophagus */
"Q394"  =  "1"  /* Esophageal web */
"Q893"  =  "1"  /* Situs inversus */
OTHER   = 0;

 /* ------------------ */
 /* COPD rate (ACCOPD) */
 /*   PQI  05          */
 /* ------------------ */

 /* COPD */
 /* ICD-10-CM Diagnosis Codes: */

value $ACCOPDD
"J410"  =  "1"  /* Simple chronic bronchitis */
"J411"  =  "1"  /* Mucopurulent chronic bronchitis */
"J418"  =  "1"  /* Mixed simple and mucopurulent chronic bronchitis */
"J42"  =  "1"  /* Unspecified chronic bronchitis */
"J430"  =  "1"  /* Unilateral pulmonary emphysema [MacLeod's syndrome] */
"J431"  =  "1"  /* Panlobular emphysema */
"J432"  =  "1"  /* Centrilobular emphysema */
"J438"  =  "1"  /* Other emphysema */
"J439"  =  "1"  /* Emphysema, unspecified */
"J440"  =  "1"  /* Chronic obstructive pulmonary disease with acute lower respiratory infection */
"J441"  =  "1"  /* Chronic obstructive pulmonary disease with (acute) exacerbation */
"J449"  =  "1"  /* Chronic obstructive pulmonary disease, unspecified */
"J470"  =  "1"  /* Bronchiectasis with acute lower respiratory infection */
"J471"  =  "1"  /* Bronchiectasis with (acute) exacerbation */
"J479"  =  "1"  /* Bronchiectasis, uncomplicated */
OTHER   = 0 ;

 /* -------------------------- */
 /* Hypertension rate (ACSHYP) */
 /*   PQI  07                  */
 /* -------------------------- */

 /* Hypertension */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSHYPD
"I10"  =  "1"  /* Essential (primary) hypertension */
"I119"  =  "1"  /* Hypertensive heart disease without heart failure */
"I129"  =  "1"  /* Hypertensive chronic kidney disease with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease */
"I1310"  =  "1"  /* Hypertensive heart and chronic kidney disease without heart failure, with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease */
OTHER   = 0 ;

 /* Exclude: Stage I-IV Kidney Disease */
 /* ICD-10-CM Diagnosis Codes: */
value $ACSHY2D
"I129"  =  "1"  /* Hypertensive chronic kidney disease with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease */
"I1310"  =  "1"  /* Hypertensive heart and chronic kidney disease without heart failure, with stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease */
OTHER   = 0 ;

/* EXCLUDE: CHRONIC RENAL FAILURE */
 /* ICD-10-CM DIAGNOSIS CODES: */

value $CRENLFD
"I120"  =  "1"  /* Hypertensive chronic kidney disease with stage 5 chronic kidney disease or end stage renal disease */
"I1311"  =  "1"  /* Hypertensive heart and chronic kidney disease without heart failure, with stage 5 chronic kidney disease, or end stage renal disease */
"I132"  =  "1"  /* Hypertensive heart and chronic kidney disease with heart failure and with stage 5 chronic kidney disease, or end stage renal disease */
"N185"  =  "1"  /* Chronic kidney disease, stage 5 */
"N186"  =  "1"  /* End stage renal disease */
OTHER   = "0" ;

/* Renal Failure */
/* ICD-10-CM Diagnosis Codes: */

value $PHYSIDB
"N170"  =  "1"  /* Acute kidney failure with tubular necrosis */
"N171"  =  "1"  /* Acute kidney failure with acute cortical necrosis */
"N172"  =  "1"  /* Acute kidney failure with medullary necrosis */
"N178"  =  "1"  /* Other acute kidney failure */
"N179"  =  "1"  /* Acute kidney failure, unspecified */
"N19"  =  "1"  /* Unspecified kidney failure */
"N990"  =  "1"  /* Postprocedural (acute) (chronic) kidney failure */
OTHER   = "0" ;

 /*Dialysis access procedures */
 /* ICD-10-CM Procedure codes: */

value $ACSHYPP
"031209D"  =  "1"  /* Bypass Innominate Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031209F"  =  "1"  /* Bypass Innominate Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03120AD"  =  "1"  /* Bypass Innominate Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03120AF"  =  "1"  /* Bypass Innominate Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03120JD"  =  "1"  /* Bypass Innominate Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03120JF"  =  "1"  /* Bypass Innominate Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03120KD"  =  "1"  /* Bypass Innominate Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03120KF"  =  "1"  /* Bypass Innominate Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03120ZD"  =  "1"  /* Bypass Innominate Artery to Upper Arm Vein, Open Approach */
"03120ZF"  =  "1"  /* Bypass Innominate Artery to Lower Arm Vein, Open Approach */
"031309D"  =  "1"  /* Bypass Right Subclavian Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031309F"  =  "1"  /* Bypass Right Subclavian Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03130AD"  =  "1"  /* Bypass Right Subclavian Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03130AF"  =  "1"  /* Bypass Right Subclavian Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03130JD"  =  "1"  /* Bypass Right Subclavian Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03130JF"  =  "1"  /* Bypass Right Subclavian Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03130KD"  =  "1"  /* Bypass Right Subclavian Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03130KF"  =  "1"  /* Bypass Right Subclavian Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03130ZD"  =  "1"  /* Bypass Right Subclavian Artery to Upper Arm Vein, Open Approach */
"03130ZF"  =  "1"  /* Bypass Right Subclavian Artery to Lower Arm Vein, Open Approach */
"031409D"  =  "1"  /* Bypass Left Subclavian Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031409F"  =  "1"  /* Bypass Left Subclavian Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03140AD"  =  "1"  /* Bypass Left Subclavian Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03140AF"  =  "1"  /* Bypass Left Subclavian Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03140JD"  =  "1"  /* Bypass Left Subclavian Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03140JF"  =  "1"  /* Bypass Left Subclavian Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03140KD"  =  "1"  /* Bypass Left Subclavian Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03140KF"  =  "1"  /* Bypass Left Subclavian Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03140ZD"  =  "1"  /* Bypass Left Subclavian Artery to Upper Arm Vein, Open Approach */
"03140ZF"  =  "1"  /* Bypass Left Subclavian Artery to Lower Arm Vein, Open Approach */
"031509D"  =  "1"  /* Bypass Right Axillary Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031509F"  =  "1"  /* Bypass Right Axillary Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03150AD"  =  "1"  /* Bypass Right Axillary Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03150AF"  =  "1"  /* Bypass Right Axillary Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03150JD"  =  "1"  /* Bypass Right Axillary Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03150JF"  =  "1"  /* Bypass Right Axillary Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03150KD"  =  "1"  /* Bypass Right Axillary Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03150KF"  =  "1"  /* Bypass Right Axillary Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03150ZD"  =  "1"  /* Bypass Right Axillary Artery to Upper Arm Vein, Open Approach */
"03150ZF"  =  "1"  /* Bypass Right Axillary Artery to Lower Arm Vein, Open Approach */
"031609D"  =  "1"  /* Bypass Left Axillary Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031609F"  =  "1"  /* Bypass Left Axillary Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03160AD"  =  "1"  /* Bypass Left Axillary Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03160AF"  =  "1"  /* Bypass Left Axillary Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03160JD"  =  "1"  /* Bypass Left Axillary Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03160JF"  =  "1"  /* Bypass Left Axillary Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03160KD"  =  "1"  /* Bypass Left Axillary Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03160KF"  =  "1"  /* Bypass Left Axillary Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03160ZD"  =  "1"  /* Bypass Left Axillary Artery to Upper Arm Vein, Open Approach */
"03160ZF"  =  "1"  /* Bypass Left Axillary Artery to Lower Arm Vein, Open Approach */
"031709D"  =  "1"  /* Bypass Right Brachial Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031709F"  =  "1"  /* Bypass Right Brachial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03170AD"  =  "1"  /* Bypass Right Brachial Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03170AF"  =  "1"  /* Bypass Right Brachial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03170JD"  =  "1"  /* Bypass Right Brachial Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03170JF"  =  "1"  /* Bypass Right Brachial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03170KD"  =  "1"  /* Bypass Right Brachial Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03170KF"  =  "1"  /* Bypass Right Brachial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03170ZD"  =  "1"  /* Bypass Right Brachial Artery to Upper Arm Vein, Open Approach */
"03170ZF"  =  "1"  /* Bypass Right Brachial Artery to Lower Arm Vein, Open Approach */
"031809D"  =  "1"  /* Bypass Left Brachial Artery to Upper Arm Vein with Autologous Venous Tissue, Open Approach */
"031809F"  =  "1"  /* Bypass Left Brachial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03180AD"  =  "1"  /* Bypass Left Brachial Artery to Upper Arm Vein with Autologous Arterial Tissue, Open Approach */
"03180AF"  =  "1"  /* Bypass Left Brachial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03180JD"  =  "1"  /* Bypass Left Brachial Artery to Upper Arm Vein with Synthetic Substitute, Open Approach */
"03180JF"  =  "1"  /* Bypass Left Brachial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03180KD"  =  "1"  /* Bypass Left Brachial Artery to Upper Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03180KF"  =  "1"  /* Bypass Left Brachial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03180ZD"  =  "1"  /* Bypass Left Brachial Artery to Upper Arm Vein, Open Approach */
"03180ZF"  =  "1"  /* Bypass Left Brachial Artery to Lower Arm Vein, Open Approach */
"031909F"  =  "1"  /* Bypass Right Ulnar Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"03190AF"  =  "1"  /* Bypass Right Ulnar Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"03190JF"  =  "1"  /* Bypass Right Ulnar Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"03190KF"  =  "1"  /* Bypass Right Ulnar Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"03190ZF"  =  "1"  /* Bypass Right Ulnar Artery to Lower Arm Vein, Open Approach */
"031A09F"  =  "1"  /* Bypass Left Ulnar Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031A0AF"  =  "1"  /* Bypass Left Ulnar Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031A0JF"  =  "1"  /* Bypass Left Ulnar Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031A0KF"  =  "1"  /* Bypass Left Ulnar Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031A0ZF"  =  "1"  /* Bypass Left Ulnar Artery to Lower Arm Vein, Open Approach */
"031B09F"  =  "1"  /* Bypass Right Radial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031B0AF"  =  "1"  /* Bypass Right Radial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031B0JF"  =  "1"  /* Bypass Right Radial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031B0KF"  =  "1"  /* Bypass Right Radial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031B0ZF"  =  "1"  /* Bypass Right Radial Artery to Lower Arm Vein, Open Approach */
"031C09F"  =  "1"  /* Bypass Left Radial Artery to Lower Arm Vein with Autologous Venous Tissue, Open Approach */
"031C0AF"  =  "1"  /* Bypass Left Radial Artery to Lower Arm Vein with Autologous Arterial Tissue, Open Approach */
"031C0JF"  =  "1"  /* Bypass Left Radial Artery to Lower Arm Vein with Synthetic Substitute, Open Approach */
"031C0KF"  =  "1"  /* Bypass Left Radial Artery to Lower Arm Vein with Nonautologous Tissue Substitute, Open Approach */
"031C0ZF"  =  "1"  /* Bypass Left Radial Artery to Lower Arm Vein, Open Approach */
"03PY07Z"  =  "1"  /* Removal of Autologous Tissue Substitute from Upper Artery, Open Approach */
"03PY0JZ"  =  "1"  /* Removal of Synthetic Substitute from Upper Artery, Open Approach */
"03PY0KZ"  =  "1"  /* Removal of Nonautologous Tissue Substitute from Upper Artery, Open Approach */
"03PY37Z"  =  "1"  /* Removal of Autologous Tissue Substitute from Upper Artery, Percutaneous Approach */
"03PY3JZ"  =  "1"  /* Removal of Synthetic Substitute from Upper Artery, Percutaneous Approach */
"03PY3KZ"  =  "1"  /* Removal of Nonautologous Tissue Substitute from Upper Artery, Percutaneous Approach */
"03PY47Z"  =  "1"  /* Removal of Autologous Tissue Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4JZ"  =  "1"  /* Removal of Synthetic Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03PY4KZ"  =  "1"  /* Removal of Nonautologous Tissue Substitute from Upper Artery, Percutaneous Endoscopic Approach */
"03WY0JZ"  =  "1"  /* Revision of Synthetic Substitute in Upper Artery, Open Approach */
"03WY3JZ"  =  "1"  /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Approach */
"03WY4JZ"  =  "1"  /* Revision of Synthetic Substitute in Upper Artery, Percutaneous Endoscopic Approach */
"03WYXJZ"  =  "1"  /* Revision of Synthetic Substitute in Upper Artery, External Approach */
"05HY33Z"  =  "1"  /* Insertion of Infusion Device into Upper Vein, Percutaneous Approach */
"06HY33Z"  =  "1"  /* Insertion of Infusion Device into Lower Vein, Percutaneous Approach */
OTHER   = 0 ;

 /* Exclude: Cardiac Procedures */
 /* ICD-10-CM Procedure codes: */

value $ACSCARP
"0210093"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0210098"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0210099"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021009C"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021009F"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021009W"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Autologous Venous Tissue, Open Approach */
"02100A3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02100A8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100A9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100AC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02100AF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02100AW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Autologous Arterial Tissue, Open Approach */
"02100J3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Synthetic Substitute, Open Approach */
"02100J8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02100J9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02100JC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Synthetic Substitute, Open Approach */
"02100JF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Synthetic Substitute, Open Approach */
"02100JW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Synthetic Substitute, Open Approach */
"02100K3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02100K8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100K9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100KC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02100Z3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery, Open Approach */
"02100Z8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary, Open Approach */
"02100Z9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary, Open Approach */
"02100ZC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery, Open Approach */
"02100ZF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery, Open Approach */
"0210344"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02103D4"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0210444"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0210493"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210498"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210499"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049C"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049F"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049W"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02104A3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104D4"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02104J3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104K3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KW"  =  "1"  /* Bypass Coronary Artery, One Site from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104Z3"  =  "1"  /* Bypass Coronary Artery, One Site from Coronary Artery, Percutaneous Endoscopic Approach */
"02104Z8"  =  "1"  /* Bypass Coronary Artery, One Site from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02104Z9"  =  "1"  /* Bypass Coronary Artery, One Site from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02104ZC"  =  "1"  /* Bypass Coronary Artery, One Site from Thoracic Artery, Percutaneous Endoscopic Approach */
"02104ZF"  =  "1"  /* Bypass Coronary Artery, One Site from Abdominal Artery, Percutaneous Endoscopic Approach */
"0211093"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0211098"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0211099"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021109C"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021109F"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021109W"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02110A3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02110A8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110A9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110AC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02110AF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02110AW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02110J3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02110J8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02110J9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02110JC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02110JF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02110JW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Synthetic Substitute, Open Approach */
"02110K3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02110K8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110K9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110KC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02110Z3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery, Open Approach */
"02110Z8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary, Open Approach */
"02110Z9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary, Open Approach */
"02110ZC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery, Open Approach */
"02110ZF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery, Open Approach */
"0211344"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02113D4"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0211444"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0211493"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211498"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211499"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149C"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149F"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149W"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02114A3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114D4"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02114J3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114K3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KW"  =  "1"  /* Bypass Coronary Artery, Two Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114Z3"  =  "1"  /* Bypass Coronary Artery, Two Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02114Z8"  =  "1"  /* Bypass Coronary Artery, Two Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02114Z9"  =  "1"  /* Bypass Coronary Artery, Two Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02114ZC"  =  "1"  /* Bypass Coronary Artery, Two Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02114ZF"  =  "1"  /* Bypass Coronary Artery, Two Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"0212093"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0212098"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0212099"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021209C"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021209F"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021209W"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02120A3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02120A8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120A9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120AC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02120AF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02120AW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02120J3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02120J8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02120J9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02120JC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02120JF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02120JW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Synthetic Substitute, Open Approach */
"02120K3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02120K8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120K9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120KC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02120Z3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery, Open Approach */
"02120Z8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary, Open Approach */
"02120Z9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary, Open Approach */
"02120ZC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery, Open Approach */
"02120ZF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery, Open Approach */
"0212344"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02123D4"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0212444"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0212493"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212498"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212499"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249C"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249F"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249W"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02124A3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124D4"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02124J3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124K3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KW"  =  "1"  /* Bypass Coronary Artery, Three Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124Z3"  =  "1"  /* Bypass Coronary Artery, Three Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02124Z8"  =  "1"  /* Bypass Coronary Artery, Three Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02124Z9"  =  "1"  /* Bypass Coronary Artery, Three Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02124ZC"  =  "1"  /* Bypass Coronary Artery, Three Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02124ZF"  =  "1"  /* Bypass Coronary Artery, Three Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"0213093"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0213098"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0213099"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021309C"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021309F"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021309W"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02130A3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02130A8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130A9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130AC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02130AF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02130AW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02130J3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02130J8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02130J9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02130JC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02130JF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02130JW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Synthetic Substitute, Open Approach */
"02130K3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02130K8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130K9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130KC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02130Z3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery, Open Approach */
"02130Z8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary, Open Approach */
"02130Z9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary, Open Approach */
"02130ZC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery, Open Approach */
"02130ZF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery, Open Approach */
"0213344"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02133D4"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0213444"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0213493"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213498"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213499"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349C"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349F"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349W"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02134A3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134D4"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02134J3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134K3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KW"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134Z3"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Coronary Artery, Percutaneous Endoscopic Approach */
"02134Z8"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02134Z9"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02134ZC"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Thoracic Artery, Percutaneous Endoscopic Approach */
"02134ZF"  =  "1"  /* Bypass Coronary Artery, Four or More Sites from Abdominal Artery, Percutaneous Endoscopic Approach */
"021609P"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021609Q"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021609R"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"02160AP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02160AQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160AR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02160JP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02160JQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160JR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02160KP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02160KQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160KR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02160ZP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk, Open Approach */
"02160ZQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery, Open Approach */
"02160ZR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery, Open Approach */
"021649P"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649Q"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021649R"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02164AP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164AR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02164JP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164JR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02164KP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164KR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02164ZP"  =  "1"  /* Bypass Right Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02164ZQ"  =  "1"  /* Bypass Right Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02164ZR"  =  "1"  /* Bypass Right Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021709P"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021709Q"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021709R"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"02170AP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"02170AQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170AR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"02170JP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02170JQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170JR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02170KP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"02170KQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170KR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"02170ZP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk, Open Approach */
"02170ZQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery, Open Approach */
"02170ZR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery, Open Approach */
"021749P"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749Q"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749R"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02174AP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174JP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174KP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174ZP"  =  "1"  /* Bypass Left Atrium to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"02174ZQ"  =  "1"  /* Bypass Left Atrium to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02174ZR"  =  "1"  /* Bypass Left Atrium to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K09P"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021K09Q"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K09R"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021K0AP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021K0AQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0AR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021K0JP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021K0JQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0JR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021K0KP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021K0KQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0KR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021K0Z5"  =  "1"  /* Bypass Right Ventricle to Coronary Circulation, Open Approach */
"021K0Z8"  =  "1"  /* Bypass Right Ventricle to Right Internal Mammary, Open Approach */
"021K0Z9"  =  "1"  /* Bypass Right Ventricle to Left Internal Mammary, Open Approach */
"021K0ZC"  =  "1"  /* Bypass Right Ventricle to Thoracic Artery, Open Approach */
"021K0ZF"  =  "1"  /* Bypass Right Ventricle to Abdominal Artery, Open Approach */
"021K0ZP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk, Open Approach */
"021K0ZQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery, Open Approach */
"021K0ZR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery, Open Approach */
"021K0ZW"  =  "1"  /* Bypass Right Ventricle to Aorta, Open Approach */
"021K49P"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49Q"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K49R"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021K4AP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4AR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021K4JP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4JR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021K4KP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4KR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021K4Z5"  =  "1"  /* Bypass Right Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021K4Z8"  =  "1"  /* Bypass Right Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021K4Z9"  =  "1"  /* Bypass Right Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021K4ZC"  =  "1"  /* Bypass Right Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021K4ZF"  =  "1"  /* Bypass Right Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021K4ZP"  =  "1"  /* Bypass Right Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021K4ZQ"  =  "1"  /* Bypass Right Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZR"  =  "1"  /* Bypass Right Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021K4ZW"  =  "1"  /* Bypass Right Ventricle to Aorta, Percutaneous Endoscopic Approach */
"021L09P"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"021L09Q"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L09R"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"021L0AP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"021L0AQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0AR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"021L0JP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"021L0JQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0JR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"021L0KP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"021L0KQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0KR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"021L0Z5"  =  "1"  /* Bypass Left Ventricle to Coronary Circulation, Open Approach */
"021L0Z8"  =  "1"  /* Bypass Left Ventricle to Right Internal Mammary, Open Approach */
"021L0Z9"  =  "1"  /* Bypass Left Ventricle to Left Internal Mammary, Open Approach */
"021L0ZC"  =  "1"  /* Bypass Left Ventricle to Thoracic Artery, Open Approach */
"021L0ZF"  =  "1"  /* Bypass Left Ventricle to Abdominal Artery, Open Approach */
"021L0ZP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk, Open Approach */
"021L0ZQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery, Open Approach */
"021L0ZR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery, Open Approach */
"021L0ZW"  =  "1"  /* Bypass Left Ventricle to Aorta, Open Approach */
"021L49P"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49Q"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L49R"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021L4AP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4AR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"021L4JP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4JR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"021L4KP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4KR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"021L4Z5"  =  "1"  /* Bypass Left Ventricle to Coronary Circulation, Percutaneous Endoscopic Approach */
"021L4Z8"  =  "1"  /* Bypass Left Ventricle to Right Internal Mammary, Percutaneous Endoscopic Approach */
"021L4Z9"  =  "1"  /* Bypass Left Ventricle to Left Internal Mammary, Percutaneous Endoscopic Approach */
"021L4ZC"  =  "1"  /* Bypass Left Ventricle to Thoracic Artery, Percutaneous Endoscopic Approach */
"021L4ZF"  =  "1"  /* Bypass Left Ventricle to Abdominal Artery, Percutaneous Endoscopic Approach */
"021L4ZP"  =  "1"  /* Bypass Left Ventricle to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"021L4ZQ"  =  "1"  /* Bypass Left Ventricle to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZR"  =  "1"  /* Bypass Left Ventricle to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"021L4ZW"  =  "1"  /* Bypass Left Ventricle to Aorta, Percutaneous Endoscopic Approach */
"02540ZZ"  =  "1"  /* Destruction of Coronary Vein, Open Approach */
"02543ZZ"  =  "1"  /* Destruction of Coronary Vein, Percutaneous Approach */
"02544ZZ"  =  "1"  /* Destruction of Coronary Vein, Percutaneous Endoscopic Approach */
"02550ZZ"  =  "1"  /* Destruction of Atrial Septum, Open Approach */
"02553ZZ"  =  "1"  /* Destruction of Atrial Septum, Percutaneous Approach */
"02554ZZ"  =  "1"  /* Destruction of Atrial Septum, Percutaneous Endoscopic Approach */
"02560ZZ"  =  "1"  /* Destruction of Right Atrium, Open Approach */
"02563ZZ"  =  "1"  /* Destruction of Right Atrium, Percutaneous Approach */
"02564ZZ"  =  "1"  /* Destruction of Right Atrium, Percutaneous Endoscopic Approach */
"02570ZK"  =  "1"  /* Destruction of Left Atrial Appendage, Open Approach */
"02570ZZ"  =  "1"  /* Destruction of Left Atrium, Open Approach */
"02573ZK"  =  "1"  /* Destruction of Left Atrial Appendage, Percutaneous Approach */
"02573ZZ"  =  "1"  /* Destruction of Left Atrium, Percutaneous Approach */
"02574ZK"  =  "1"  /* Destruction of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02574ZZ"  =  "1"  /* Destruction of Left Atrium, Percutaneous Endoscopic Approach */
"02580ZZ"  =  "1"  /* Destruction of Conduction Mechanism, Open Approach */
"02583ZZ"  =  "1"  /* Destruction of Conduction Mechanism, Percutaneous Approach */
"02584ZZ"  =  "1"  /* Destruction of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02590ZZ"  =  "1"  /* Destruction of Chordae Tendineae, Open Approach */
"02593ZZ"  =  "1"  /* Destruction of Chordae Tendineae, Percutaneous Approach */
"02594ZZ"  =  "1"  /* Destruction of Chordae Tendineae, Percutaneous Endoscopic Approach */
"025D0ZZ"  =  "1"  /* Destruction of Papillary Muscle, Open Approach */
"025D3ZZ"  =  "1"  /* Destruction of Papillary Muscle, Percutaneous Approach */
"025D4ZZ"  =  "1"  /* Destruction of Papillary Muscle, Percutaneous Endoscopic Approach */
"025F0ZZ"  =  "1"  /* Destruction of Aortic Valve, Open Approach */
"025F3ZZ"  =  "1"  /* Destruction of Aortic Valve, Percutaneous Approach */
"025F4ZZ"  =  "1"  /* Destruction of Aortic Valve, Percutaneous Endoscopic Approach */
"025G0ZZ"  =  "1"  /* Destruction of Mitral Valve, Open Approach */
"025G3ZZ"  =  "1"  /* Destruction of Mitral Valve, Percutaneous Approach */
"025G4ZZ"  =  "1"  /* Destruction of Mitral Valve, Percutaneous Endoscopic Approach */
"025H0ZZ"  =  "1"  /* Destruction of Pulmonary Valve, Open Approach */
"025H3ZZ"  =  "1"  /* Destruction of Pulmonary Valve, Percutaneous Approach */
"025H4ZZ"  =  "1"  /* Destruction of Pulmonary Valve, Percutaneous Endoscopic Approach */
"025J0ZZ"  =  "1"  /* Destruction of Tricuspid Valve, Open Approach */
"025J3ZZ"  =  "1"  /* Destruction of Tricuspid Valve, Percutaneous Approach */
"025J4ZZ"  =  "1"  /* Destruction of Tricuspid Valve, Percutaneous Endoscopic Approach */
"025K0ZZ"  =  "1"  /* Destruction of Right Ventricle, Open Approach */
"025K3ZZ"  =  "1"  /* Destruction of Right Ventricle, Percutaneous Approach */
"025K4ZZ"  =  "1"  /* Destruction of Right Ventricle, Percutaneous Endoscopic Approach */
"025L0ZZ"  =  "1"  /* Destruction of Left Ventricle, Open Approach */
"025L3ZZ"  =  "1"  /* Destruction of Left Ventricle, Percutaneous Approach */
"025L4ZZ"  =  "1"  /* Destruction of Left Ventricle, Percutaneous Endoscopic Approach */
"025M0ZZ"  =  "1"  /* Destruction of Ventricular Septum, Open Approach */
"025M3ZZ"  =  "1"  /* Destruction of Ventricular Septum, Percutaneous Approach */
"025M4ZZ"  =  "1"  /* Destruction of Ventricular Septum, Percutaneous Endoscopic Approach */
"025N0ZZ"  =  "1"  /* Destruction of Pericardium, Open Approach */
"025N3ZZ"  =  "1"  /* Destruction of Pericardium, Percutaneous Approach */
"025N4ZZ"  =  "1"  /* Destruction of Pericardium, Percutaneous Endoscopic Approach */
"0270046"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027004Z"  =  "1"  /* Dilation of Coronary Artery, One Site with Drug-eluting Intraluminal Device, Open Approach */
"02700D6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Intraluminal Device, Open Approach */
"02700DZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Intraluminal Device, Open Approach */
"02700T6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02700TZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Radioactive Intraluminal Device, Open Approach */
"02700Z6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, Open Approach */
"02700ZZ"  =  "1"  /* Dilation of Coronary Artery, One Site, Open Approach */
"0270346"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027034Z"  =  "1"  /* Dilation of Coronary Artery, One Site with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02703D6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02703DZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Intraluminal Device, Percutaneous Approach */
"02703T6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02703TZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Radioactive Intraluminal Device, Percutaneous Approach */
"02703Z6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, Percutaneous Approach */
"02703ZZ"  =  "1"  /* Dilation of Coronary Artery, One Site, Percutaneous Approach */
"0270446"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027044Z"  =  "1"  /* Dilation of Coronary Artery, One Site with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"02704D6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704DZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704T6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02704TZ"  =  "1"  /* Dilation of Coronary Artery, One Site with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02704Z6"  =  "1"  /* Dilation of Coronary Artery, One Site, Bifurcation, Percutaneous Endoscopic Approach */
"02704ZZ"  =  "1"  /* Dilation of Coronary Artery, One Site, Percutaneous Endoscopic Approach */
"0271046"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027104Z"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Drug-eluting Intraluminal Device, Open Approach */
"02710D6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02710DZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Intraluminal Device, Open Approach */
"02710T6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02710TZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Radioactive Intraluminal Device, Open Approach */
"02710Z6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, Open Approach */
"02710ZZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Open Approach */
"0271346"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027134Z"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02713D6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02713DZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Intraluminal Device, Percutaneous Approach */
"02713T6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02713TZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Radioactive Intraluminal Device, Percutaneous Approach */
"02713Z6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, Percutaneous Approach */
"02713ZZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Percutaneous Approach */
"0271446"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027144Z"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"02714D6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714DZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714T6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02714TZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02714Z6"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Bifurcation, Percutaneous Endoscopic Approach */
"02714ZZ"  =  "1"  /* Dilation of Coronary Artery, Two Sites, Percutaneous Endoscopic Approach */
"0272046"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027204Z"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Drug-eluting Intraluminal Device, Open Approach */
"02720D6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02720DZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Intraluminal Device, Open Approach */
"02720T6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02720TZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Radioactive Intraluminal Device, Open Approach */
"02720Z6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, Open Approach */
"02720ZZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Open Approach */
"0272346"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027234Z"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02723D6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02723DZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Intraluminal Device, Percutaneous Approach */
"02723T6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02723TZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Radioactive Intraluminal Device, Percutaneous Approach */
"02723Z6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, Percutaneous Approach */
"02723ZZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Percutaneous Approach */
"0272446"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027244Z"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"02724D6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724DZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724T6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02724TZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02724Z6"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Bifurcation, Percutaneous Endoscopic Approach */
"02724ZZ"  =  "1"  /* Dilation of Coronary Artery, Three Sites, Percutaneous Endoscopic Approach */
"0273046"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027304Z"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Drug-eluting Intraluminal Device, Open Approach */
"02730D6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Intraluminal Device, Open Approach */
"02730DZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Intraluminal Device, Open Approach */
"02730T6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02730TZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Radioactive Intraluminal Device, Open Approach */
"02730Z6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, Open Approach */
"02730ZZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Open Approach */
"0273346"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027334Z"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02733D6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02733DZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Intraluminal Device, Percutaneous Approach */
"02733T6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02733TZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Radioactive Intraluminal Device, Percutaneous Approach */
"02733Z6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, Percutaneous Approach */
"02733ZZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Percutaneous Approach */
"0273446"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027344Z"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"02734D6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734DZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734T6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734TZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734Z6"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Bifurcation, Percutaneous Endoscopic Approach */
"02734ZZ"  =  "1"  /* Dilation of Coronary Artery, Four or More Sites, Percutaneous Endoscopic Approach */
"027F04Z"  =  "1"  /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Open Approach */
"027F0DZ"  =  "1"  /* Dilation of Aortic Valve with Intraluminal Device, Open Approach */
"027F0ZZ"  =  "1"  /* Dilation of Aortic Valve, Open Approach */
"027F34Z"  =  "1"  /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027F3DZ"  =  "1"  /* Dilation of Aortic Valve with Intraluminal Device, Percutaneous Approach */
"027F3ZZ"  =  "1"  /* Dilation of Aortic Valve, Percutaneous Approach */
"027F44Z"  =  "1"  /* Dilation of Aortic Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027F4DZ"  =  "1"  /* Dilation of Aortic Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027F4ZZ"  =  "1"  /* Dilation of Aortic Valve, Percutaneous Endoscopic Approach */
"027G04Z"  =  "1"  /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Open Approach */
"027G0DZ"  =  "1"  /* Dilation of Mitral Valve with Intraluminal Device, Open Approach */
"027G0ZZ"  =  "1"  /* Dilation of Mitral Valve, Open Approach */
"027G34Z"  =  "1"  /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027G3DZ"  =  "1"  /* Dilation of Mitral Valve with Intraluminal Device, Percutaneous Approach */
"027G3ZZ"  =  "1"  /* Dilation of Mitral Valve, Percutaneous Approach */
"027G44Z"  =  "1"  /* Dilation of Mitral Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027G4DZ"  =  "1"  /* Dilation of Mitral Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027G4ZZ"  =  "1"  /* Dilation of Mitral Valve, Percutaneous Endoscopic Approach */
"027H04Z"  =  "1"  /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Open Approach */
"027H0DZ"  =  "1"  /* Dilation of Pulmonary Valve with Intraluminal Device, Open Approach */
"027H0ZZ"  =  "1"  /* Dilation of Pulmonary Valve, Open Approach */
"027H34Z"  =  "1"  /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027H3DZ"  =  "1"  /* Dilation of Pulmonary Valve with Intraluminal Device, Percutaneous Approach */
"027H3ZZ"  =  "1"  /* Dilation of Pulmonary Valve, Percutaneous Approach */
"027H44Z"  =  "1"  /* Dilation of Pulmonary Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027H4DZ"  =  "1"  /* Dilation of Pulmonary Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027H4ZZ"  =  "1"  /* Dilation of Pulmonary Valve, Percutaneous Endoscopic Approach */
"027J04Z"  =  "1"  /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Open Approach */
"027J0DZ"  =  "1"  /* Dilation of Tricuspid Valve with Intraluminal Device, Open Approach */
"027J0ZZ"  =  "1"  /* Dilation of Tricuspid Valve, Open Approach */
"027J34Z"  =  "1"  /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027J3DZ"  =  "1"  /* Dilation of Tricuspid Valve with Intraluminal Device, Percutaneous Approach */
"027J3ZZ"  =  "1"  /* Dilation of Tricuspid Valve, Percutaneous Approach */
"027J44Z"  =  "1"  /* Dilation of Tricuspid Valve with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027J4DZ"  =  "1"  /* Dilation of Tricuspid Valve with Intraluminal Device, Percutaneous Endoscopic Approach */
"027J4ZZ"  =  "1"  /* Dilation of Tricuspid Valve, Percutaneous Endoscopic Approach */
"02890ZZ"  =  "1"  /* Division of Chordae Tendineae, Open Approach */
"02893ZZ"  =  "1"  /* Division of Chordae Tendineae, Percutaneous Approach */
"02894ZZ"  =  "1"  /* Division of Chordae Tendineae, Percutaneous Endoscopic Approach */
"028D0ZZ"  =  "1"  /* Division of Papillary Muscle, Open Approach */
"028D3ZZ"  =  "1"  /* Division of Papillary Muscle, Percutaneous Approach */
"028D4ZZ"  =  "1"  /* Division of Papillary Muscle, Percutaneous Endoscopic Approach */
"02B40ZZ"  =  "1"  /* Excision of Coronary Vein, Open Approach */
"02B43ZZ"  =  "1"  /* Excision of Coronary Vein, Percutaneous Approach */
"02B44ZZ"  =  "1"  /* Excision of Coronary Vein, Percutaneous Endoscopic Approach */
"02B50ZZ"  =  "1"  /* Excision of Atrial Septum, Open Approach */
"02B53ZZ"  =  "1"  /* Excision of Atrial Septum, Percutaneous Approach */
"02B54ZZ"  =  "1"  /* Excision of Atrial Septum, Percutaneous Endoscopic Approach */
"02B60ZZ"  =  "1"  /* Excision of Right Atrium, Open Approach */
"02B63ZZ"  =  "1"  /* Excision of Right Atrium, Percutaneous Approach */
"02B64ZZ"  =  "1"  /* Excision of Right Atrium, Percutaneous Endoscopic Approach */
"02B70ZK"  =  "1"  /* Excision of Left Atrial Appendage, Open Approach */
"02B70ZZ"  =  "1"  /* Excision of Left Atrium, Open Approach */
"02B73ZK"  =  "1"  /* Excision of Left Atrial Appendage, Percutaneous Approach */
"02B73ZZ"  =  "1"  /* Excision of Left Atrium, Percutaneous Approach */
"02B74ZK"  =  "1"  /* Excision of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02B74ZZ"  =  "1"  /* Excision of Left Atrium, Percutaneous Endoscopic Approach */
"02B80ZZ"  =  "1"  /* Excision of Conduction Mechanism, Open Approach */
"02B83ZZ"  =  "1"  /* Excision of Conduction Mechanism, Percutaneous Approach */
"02B84ZZ"  =  "1"  /* Excision of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02B90ZZ"  =  "1"  /* Excision of Chordae Tendineae, Open Approach */
"02B93ZZ"  =  "1"  /* Excision of Chordae Tendineae, Percutaneous Approach */
"02B94ZZ"  =  "1"  /* Excision of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02BD0ZZ"  =  "1"  /* Excision of Papillary Muscle, Open Approach */
"02BD3ZZ"  =  "1"  /* Excision of Papillary Muscle, Percutaneous Approach */
"02BD4ZZ"  =  "1"  /* Excision of Papillary Muscle, Percutaneous Endoscopic Approach */
"02BF0ZZ"  =  "1"  /* Excision of Aortic Valve, Open Approach */
"02BF3ZZ"  =  "1"  /* Excision of Aortic Valve, Percutaneous Approach */
"02BF4ZZ"  =  "1"  /* Excision of Aortic Valve, Percutaneous Endoscopic Approach */
"02BG0ZZ"  =  "1"  /* Excision of Mitral Valve, Open Approach */
"02BG3ZZ"  =  "1"  /* Excision of Mitral Valve, Percutaneous Approach */
"02BG4ZZ"  =  "1"  /* Excision of Mitral Valve, Percutaneous Endoscopic Approach */
"02BH0ZZ"  =  "1"  /* Excision of Pulmonary Valve, Open Approach */
"02BH3ZZ"  =  "1"  /* Excision of Pulmonary Valve, Percutaneous Approach */
"02BH4ZZ"  =  "1"  /* Excision of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02BJ0ZZ"  =  "1"  /* Excision of Tricuspid Valve, Open Approach */
"02BJ3ZZ"  =  "1"  /* Excision of Tricuspid Valve, Percutaneous Approach */
"02BJ4ZZ"  =  "1"  /* Excision of Tricuspid Valve, Percutaneous Endoscopic Approach */
"02BK0ZZ"  =  "1"  /* Excision of Right Ventricle, Open Approach */
"02BK3ZZ"  =  "1"  /* Excision of Right Ventricle, Percutaneous Approach */
"02BK4ZZ"  =  "1"  /* Excision of Right Ventricle, Percutaneous Endoscopic Approach */
"02BL0ZZ"  =  "1"  /* Excision of Left Ventricle, Open Approach */
"02BL3ZZ"  =  "1"  /* Excision of Left Ventricle, Percutaneous Approach */
"02BL4ZZ"  =  "1"  /* Excision of Left Ventricle, Percutaneous Endoscopic Approach */
"02BM0ZZ"  =  "1"  /* Excision of Ventricular Septum, Open Approach */
"02BM3ZZ"  =  "1"  /* Excision of Ventricular Septum, Percutaneous Approach */
"02BM4ZZ"  =  "1"  /* Excision of Ventricular Septum, Percutaneous Endoscopic Approach */
"02BN0ZZ"  =  "1"  /* Excision of Pericardium, Open Approach */
"02BN3ZZ"  =  "1"  /* Excision of Pericardium, Percutaneous Approach */
"02BN4ZZ"  =  "1"  /* Excision of Pericardium, Percutaneous Endoscopic Approach */
"02C00ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, One Site, Open Approach */
"02C03ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, One Site, Percutaneous Approach */
"02C04ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, One Site, Percutaneous Endoscopic Approach */
"02C10ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Two Sites, Open Approach */
"02C13ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Two Sites, Percutaneous Approach */
"02C14ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Two Sites, Percutaneous Endoscopic Approach */
"02C20ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Three Sites, Open Approach */
"02C23ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Three Sites, Percutaneous Approach */
"02C24ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Three Sites, Percutaneous Endoscopic Approach */
"02C30ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Four or More Sites, Open Approach */
"02C33ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Four or More Sites, Percutaneous Approach */
"02C34ZZ"  =  "1"  /* Extirpation of Matter from Coronary Artery, Four or More Sites, Percutaneous Endoscopic Approach */
"02C40ZZ"  =  "1"  /* Extirpation of Matter from Coronary Vein, Open Approach */
"02C43ZZ"  =  "1"  /* Extirpation of Matter from Coronary Vein, Percutaneous Approach */
"02C44ZZ"  =  "1"  /* Extirpation of Matter from Coronary Vein, Percutaneous Endoscopic Approach */
"02C50ZZ"  =  "1"  /* Extirpation of Matter from Atrial Septum, Open Approach */
"02C53ZZ"  =  "1"  /* Extirpation of Matter from Atrial Septum, Percutaneous Approach */
"02C54ZZ"  =  "1"  /* Extirpation of Matter from Atrial Septum, Percutaneous Endoscopic Approach */
"02CD0ZZ"  =  "1"  /* Extirpation of Matter from Papillary Muscle, Open Approach */
"02CD3ZZ"  =  "1"  /* Extirpation of Matter from Papillary Muscle, Percutaneous Approach */
"02CD4ZZ"  =  "1"  /* Extirpation of Matter from Papillary Muscle, Percutaneous Endoscopic Approach */
"02CF0ZZ"  =  "1"  /* Extirpation of Matter from Aortic Valve, Open Approach */
"02CF3ZZ"  =  "1"  /* Extirpation of Matter from Aortic Valve, Percutaneous Approach */
"02CF4ZZ"  =  "1"  /* Extirpation of Matter from Aortic Valve, Percutaneous Endoscopic Approach */
"02CG0ZZ"  =  "1"  /* Extirpation of Matter from Mitral Valve, Open Approach */
"02CG3ZZ"  =  "1"  /* Extirpation of Matter from Mitral Valve, Percutaneous Approach */
"02CG4ZZ"  =  "1"  /* Extirpation of Matter from Mitral Valve, Percutaneous Endoscopic Approach */
"02CH0ZZ"  =  "1"  /* Extirpation of Matter from Pulmonary Valve, Open Approach */
"02CH3ZZ"  =  "1"  /* Extirpation of Matter from Pulmonary Valve, Percutaneous Approach */
"02CH4ZZ"  =  "1"  /* Extirpation of Matter from Pulmonary Valve, Percutaneous Endoscopic Approach */
"02CJ0ZZ"  =  "1"  /* Extirpation of Matter from Tricuspid Valve, Open Approach */
"02CJ3ZZ"  =  "1"  /* Extirpation of Matter from Tricuspid Valve, Percutaneous Approach */
"02CJ4ZZ"  =  "1"  /* Extirpation of Matter from Tricuspid Valve, Percutaneous Endoscopic Approach */
"02CM0ZZ"  =  "1"  /* Extirpation of Matter from Ventricular Septum, Open Approach */
"02CM3ZZ"  =  "1"  /* Extirpation of Matter from Ventricular Septum, Percutaneous Approach */
"02CM4ZZ"  =  "1"  /* Extirpation of Matter from Ventricular Septum, Percutaneous Endoscopic Approach */
"02H400Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Open Approach */
"02H402Z"  =  "1"  /* Insertion of Monitoring Device into Coronary Vein, Open Approach */
"02H403Z"  =  "1"  /* Insertion of Infusion Device into Coronary Vein, Open Approach */
"02H40DZ"  =  "1"  /* Insertion of Intraluminal Device into Coronary Vein, Open Approach */
"02H40JZ"  =  "1"  /* Insertion of Pacemaker Lead into Coronary Vein, Open Approach */
"02H40KZ"  =  "1"  /* Insertion of Defibrillator Lead into Coronary Vein, Open Approach */
"02H40MZ"  =  "1"  /* Insertion of Cardiac Lead into Coronary Vein, Open Approach */
"02H430Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Percutaneous Approach */
"02H432Z"  =  "1"  /* Insertion of Monitoring Device into Coronary Vein, Percutaneous Approach */
"02H433Z"  =  "1"  /* Insertion of Infusion Device into Coronary Vein, Percutaneous Approach */
"02H43DZ"  =  "1"  /* Insertion of Intraluminal Device into Coronary Vein, Percutaneous Approach */
"02H43JZ"  =  "1"  /* Insertion of Pacemaker Lead into Coronary Vein, Percutaneous Approach */
"02H43KZ"  =  "1"  /* Insertion of Defibrillator Lead into Coronary Vein, Percutaneous Approach */
"02H43MZ"  =  "1"  /* Insertion of Cardiac Lead into Coronary Vein, Percutaneous Approach */
"02H440Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H442Z"  =  "1"  /* Insertion of Monitoring Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H443Z"  =  "1"  /* Insertion of Infusion Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44DZ"  =  "1"  /* Insertion of Intraluminal Device into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44JZ"  =  "1"  /* Insertion of Pacemaker Lead into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44KZ"  =  "1"  /* Insertion of Defibrillator Lead into Coronary Vein, Percutaneous Endoscopic Approach */
"02H44MZ"  =  "1"  /* Insertion of Cardiac Lead into Coronary Vein, Percutaneous Endoscopic Approach */
"02H600Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Open Approach */
"02H60JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Atrium, Open Approach */
"02H60KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Atrium, Open Approach */
"02H60MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Atrium, Open Approach */
"02H630Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Percutaneous Approach */
"02H63JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Atrium, Percutaneous Approach */
"02H63KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Atrium, Percutaneous Approach */
"02H63MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Atrium, Percutaneous Approach */
"02H640Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Atrium, Percutaneous Endoscopic Approach */
"02H64JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Atrium, Percutaneous Endoscopic Approach */
"02H64KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Atrium, Percutaneous Endoscopic Approach */
"02H64MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Atrium, Percutaneous Endoscopic Approach */
"02H700Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Open Approach */
"02H70JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Atrium, Open Approach */
"02H70KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Atrium, Open Approach */
"02H70MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Atrium, Open Approach */
"02H730Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Percutaneous Approach */
"02H73JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Atrium, Percutaneous Approach */
"02H73KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Atrium, Percutaneous Approach */
"02H73MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Atrium, Percutaneous Approach */
"02H740Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Atrium, Percutaneous Endoscopic Approach */
"02H74JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Atrium, Percutaneous Endoscopic Approach */
"02H74KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Atrium, Percutaneous Endoscopic Approach */
"02H74MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Atrium, Percutaneous Endoscopic Approach */
"02HA0QZ"  =  "1"  /* Insertion of Implantable Heart Assist System into Heart, Open Approach */
"02HA0RS"  =  "1"  /* Insertion of Biventricular External Heart Assist System into Heart, Open Approach */
"02HA0RZ"  =  "1"  /* Insertion of External Heart Assist System into Heart, Open Approach */
"02HA3QZ"  =  "1"  /* Insertion of Implantable Heart Assist System into Heart, Percutaneous Approach */
"02HA3RS"  =  "1"  /* Insertion of Biventricular External Heart Assist System into Heart, Percutaneous Approach */
"02HA3RZ"  =  "1"  /* Insertion of External Heart Assist System into Heart, Percutaneous Approach */
"02HA4QZ"  =  "1"  /* Insertion of Implantable Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RS"  =  "1"  /* Insertion of Biventricular External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RZ"  =  "1"  /* Insertion of External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HK00Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Ventricle, Open Approach */
"02HK02Z"  =  "1"  /* Insertion of Monitoring Device into Right Ventricle, Open Approach */
"02HK0JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Ventricle, Open Approach */
"02HK0KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Ventricle, Open Approach */
"02HK0MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Ventricle, Open Approach */
"02HK30Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Ventricle, Percutaneous Approach */
"02HK32Z"  =  "1"  /* Insertion of Monitoring Device into Right Ventricle, Percutaneous Approach */
"02HK3JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Ventricle, Percutaneous Approach */
"02HK3KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Ventricle, Percutaneous Approach */
"02HK3MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Ventricle, Percutaneous Approach */
"02HK40Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK42Z"  =  "1"  /* Insertion of Monitoring Device into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4JZ"  =  "1"  /* Insertion of Pacemaker Lead into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4KZ"  =  "1"  /* Insertion of Defibrillator Lead into Right Ventricle, Percutaneous Endoscopic Approach */
"02HK4MZ"  =  "1"  /* Insertion of Cardiac Lead into Right Ventricle, Percutaneous Endoscopic Approach */
"02HL00Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Open Approach */
"02HL0JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Ventricle, Open Approach */
"02HL0KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Ventricle, Open Approach */
"02HL0MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Ventricle, Open Approach */
"02HL30Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Percutaneous Approach */
"02HL3JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Ventricle, Percutaneous Approach */
"02HL3KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Ventricle, Percutaneous Approach */
"02HL3MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Ventricle, Percutaneous Approach */
"02HL40Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4JZ"  =  "1"  /* Insertion of Pacemaker Lead into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4KZ"  =  "1"  /* Insertion of Defibrillator Lead into Left Ventricle, Percutaneous Endoscopic Approach */
"02HL4MZ"  =  "1"  /* Insertion of Cardiac Lead into Left Ventricle, Percutaneous Endoscopic Approach */
"02HN0JZ"  =  "1"  /* Insertion of Pacemaker Lead into Pericardium, Open Approach */
"02HN0KZ"  =  "1"  /* Insertion of Defibrillator Lead into Pericardium, Open Approach */
"02HN0MZ"  =  "1"  /* Insertion of Cardiac Lead into Pericardium, Open Approach */
"02HN3JZ"  =  "1"  /* Insertion of Pacemaker Lead into Pericardium, Percutaneous Approach */
"02HN3KZ"  =  "1"  /* Insertion of Defibrillator Lead into Pericardium, Percutaneous Approach */
"02HN3MZ"  =  "1"  /* Insertion of Cardiac Lead into Pericardium, Percutaneous Approach */
"02HN4JZ"  =  "1"  /* Insertion of Pacemaker Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HN4KZ"  =  "1"  /* Insertion of Defibrillator Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HN4MZ"  =  "1"  /* Insertion of Cardiac Lead into Pericardium, Percutaneous Endoscopic Approach */
"02HS00Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Open Approach */
"02HS30Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Percutaneous Approach */
"02HS40Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HT00Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Open Approach */
"02HT30Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Percutaneous Approach */
"02HT40Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02HV00Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Open Approach */
"02HV30Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Percutaneous Approach */
"02HV40Z"  =  "1"  /* Insertion of Pressure Sensor Monitoring Device into Superior Vena Cava, Percutaneous Endoscopic Approach */
"02L70CK"  =  "1"  /* Occlusion of Left Atrial Appendage with Extraluminal Device, Open Approach */
"02L70DK"  =  "1"  /* Occlusion of Left Atrial Appendage with Intraluminal Device, Open Approach */
"02L70ZK"  =  "1"  /* Occlusion of Left Atrial Appendage, Open Approach */
"02L73CK"  =  "1"  /* Occlusion of Left Atrial Appendage with Extraluminal Device, Percutaneous Approach */
"02L73DK"  =  "1"  /* Occlusion of Left Atrial Appendage with Intraluminal Device, Percutaneous Approach */
"02L73ZK"  =  "1"  /* Occlusion of Left Atrial Appendage, Percutaneous Approach */
"02L74CK"  =  "1"  /* Occlusion of Left Atrial Appendage with Extraluminal Device, Percutaneous Endoscopic Approach */
"02L74DK"  =  "1"  /* Occlusion of Left Atrial Appendage with Intraluminal Device, Percutaneous Endoscopic Approach */
"02L74ZK"  =  "1"  /* Occlusion of Left Atrial Appendage, Percutaneous Endoscopic Approach */
"02LR0ZT"  =  "1"  /* Occlusion of Ductus Arteriosus, Open Approach */
"02LS0ZZ"  =  "1"  /* Occlusion of Right Pulmonary Vein, Open Approach */
"02LT0ZZ"  =  "1"  /* Occlusion of Left Pulmonary Vein, Open Approach */
"02N50ZZ"  =  "1"  /* Release Atrial Septum, Open Approach */
"02N53ZZ"  =  "1"  /* Release Atrial Septum, Percutaneous Approach */
"02N54ZZ"  =  "1"  /* Release Atrial Septum, Percutaneous Endoscopic Approach */
"02N90ZZ"  =  "1"  /* Release Chordae Tendineae, Open Approach */
"02N93ZZ"  =  "1"  /* Release Chordae Tendineae, Percutaneous Approach */
"02N94ZZ"  =  "1"  /* Release Chordae Tendineae, Percutaneous Endoscopic Approach */
"02ND0ZZ"  =  "1"  /* Release Papillary Muscle, Open Approach */
"02ND3ZZ"  =  "1"  /* Release Papillary Muscle, Percutaneous Approach */
"02ND4ZZ"  =  "1"  /* Release Papillary Muscle, Percutaneous Endoscopic Approach */
"02NF0ZZ"  =  "1"  /* Release Aortic Valve, Open Approach */
"02NF3ZZ"  =  "1"  /* Release Aortic Valve, Percutaneous Approach */
"02NF4ZZ"  =  "1"  /* Release Aortic Valve, Percutaneous Endoscopic Approach */
"02NG0ZZ"  =  "1"  /* Release Mitral Valve, Open Approach */
"02NG3ZZ"  =  "1"  /* Release Mitral Valve, Percutaneous Approach */
"02NG4ZZ"  =  "1"  /* Release Mitral Valve, Percutaneous Endoscopic Approach */
"02NH0ZZ"  =  "1"  /* Release Pulmonary Valve, Open Approach */
"02NH3ZZ"  =  "1"  /* Release Pulmonary Valve, Percutaneous Approach */
"02NH4ZZ"  =  "1"  /* Release Pulmonary Valve, Percutaneous Endoscopic Approach */
"02NJ0ZZ"  =  "1"  /* Release Tricuspid Valve, Open Approach */
"02NJ3ZZ"  =  "1"  /* Release Tricuspid Valve, Percutaneous Approach */
"02NJ4ZZ"  =  "1"  /* Release Tricuspid Valve, Percutaneous Endoscopic Approach */
"02NK0ZZ"  =  "1"  /* Release Right Ventricle, Open Approach */
"02NK3ZZ"  =  "1"  /* Release Right Ventricle, Percutaneous Approach */
"02NK4ZZ"  =  "1"  /* Release Right Ventricle, Percutaneous Endoscopic Approach */
"02NL0ZZ"  =  "1"  /* Release Left Ventricle, Open Approach */
"02NL3ZZ"  =  "1"  /* Release Left Ventricle, Percutaneous Approach */
"02NL4ZZ"  =  "1"  /* Release Left Ventricle, Percutaneous Endoscopic Approach */
"02NM0ZZ"  =  "1"  /* Release Ventricular Septum, Open Approach */
"02NM3ZZ"  =  "1"  /* Release Ventricular Septum, Percutaneous Approach */
"02NM4ZZ"  =  "1"  /* Release Ventricular Septum, Percutaneous Endoscopic Approach */
"02PA0MZ"  =  "1"  /* Removal of Cardiac Lead from Heart, Open Approach */
"02PA0QZ"  =  "1"  /* Removal of Implantable Heart Assist System from Heart, Open Approach */
"02PA0RZ"  =  "1"  /* Removal of External Heart Assist System from Heart, Open Approach */
"02PA3MZ"  =  "1"  /* Removal of Cardiac Lead from Heart, Percutaneous Approach */
"02PA3QZ"  =  "1"  /* Removal of Implantable Heart Assist System from Heart, Percutaneous Approach */
"02PA3RZ"  =  "1"  /* Removal of External Heart Assist System from Heart, Percutaneous Approach */
"02PA4MZ"  =  "1"  /* Removal of Cardiac Lead from Heart, Percutaneous Endoscopic Approach */
"02PA4QZ"  =  "1"  /* Removal of Implantable Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PA4RZ"  =  "1"  /* Removal of External Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PAXMZ"  =  "1"  /* Removal of Cardiac Lead from Heart, External Approach */
"02Q00ZZ"  =  "1"  /* Repair Coronary Artery, One Site, Open Approach */
"02Q03ZZ"  =  "1"  /* Repair Coronary Artery, One Site, Percutaneous Approach */
"02Q04ZZ"  =  "1"  /* Repair Coronary Artery, One Site, Percutaneous Endoscopic Approach */
"02Q10ZZ"  =  "1"  /* Repair Coronary Artery, Two Sites, Open Approach */
"02Q13ZZ"  =  "1"  /* Repair Coronary Artery, Two Sites, Percutaneous Approach */
"02Q14ZZ"  =  "1"  /* Repair Coronary Artery, Two Sites, Percutaneous Endoscopic Approach */
"02Q20ZZ"  =  "1"  /* Repair Coronary Artery, Three Sites, Open Approach */
"02Q23ZZ"  =  "1"  /* Repair Coronary Artery, Three Sites, Percutaneous Approach */
"02Q24ZZ"  =  "1"  /* Repair Coronary Artery, Three Sites, Percutaneous Endoscopic Approach */
"02Q30ZZ"  =  "1"  /* Repair Coronary Artery, Four or More Sites, Open Approach */
"02Q33ZZ"  =  "1"  /* Repair Coronary Artery, Four or More Sites, Percutaneous Approach */
"02Q34ZZ"  =  "1"  /* Repair Coronary Artery, Four or More Sites, Percutaneous Endoscopic Approach */
"02Q40ZZ"  =  "1"  /* Repair Coronary Vein, Open Approach */
"02Q43ZZ"  =  "1"  /* Repair Coronary Vein, Percutaneous Approach */
"02Q44ZZ"  =  "1"  /* Repair Coronary Vein, Percutaneous Endoscopic Approach */
"02Q50ZZ"  =  "1"  /* Repair Atrial Septum, Open Approach */
"02Q53ZZ"  =  "1"  /* Repair Atrial Septum, Percutaneous Approach */
"02Q54ZZ"  =  "1"  /* Repair Atrial Septum, Percutaneous Endoscopic Approach */
"02Q70ZZ"  =  "1"  /* Repair Left Atrium, Open Approach */
"02Q73ZZ"  =  "1"  /* Repair Left Atrium, Percutaneous Approach */
"02Q74ZZ"  =  "1"  /* Repair Left Atrium, Percutaneous Endoscopic Approach */
"02Q90ZZ"  =  "1"  /* Repair Chordae Tendineae, Open Approach */
"02Q93ZZ"  =  "1"  /* Repair Chordae Tendineae, Percutaneous Approach */
"02Q94ZZ"  =  "1"  /* Repair Chordae Tendineae, Percutaneous Endoscopic Approach */
"02QA0ZZ"  =  "1"  /* Repair Heart, Open Approach */
"02QA3ZZ"  =  "1"  /* Repair Heart, Percutaneous Approach */
"02QA4ZZ"  =  "1"  /* Repair Heart, Percutaneous Endoscopic Approach */
"02QB0ZZ"  =  "1"  /* Repair Right Heart, Open Approach */
"02QB3ZZ"  =  "1"  /* Repair Right Heart, Percutaneous Approach */
"02QB4ZZ"  =  "1"  /* Repair Right Heart, Percutaneous Endoscopic Approach */
"02QC0ZZ"  =  "1"  /* Repair Left Heart, Open Approach */
"02QC3ZZ"  =  "1"  /* Repair Left Heart, Percutaneous Approach */
"02QC4ZZ"  =  "1"  /* Repair Left Heart, Percutaneous Endoscopic Approach */
"02QD0ZZ"  =  "1"  /* Repair Papillary Muscle, Open Approach */
"02QD3ZZ"  =  "1"  /* Repair Papillary Muscle, Percutaneous Approach */
"02QD4ZZ"  =  "1"  /* Repair Papillary Muscle, Percutaneous Endoscopic Approach */
"02QF0ZZ"  =  "1"  /* Repair Aortic Valve, Open Approach */
"02QF3ZZ"  =  "1"  /* Repair Aortic Valve, Percutaneous Approach */
"02QF4ZZ"  =  "1"  /* Repair Aortic Valve, Percutaneous Endoscopic Approach */
"02QG0ZZ"  =  "1"  /* Repair Mitral Valve, Open Approach */
"02QG3ZZ"  =  "1"  /* Repair Mitral Valve, Percutaneous Approach */
"02QG4ZZ"  =  "1"  /* Repair Mitral Valve, Percutaneous Endoscopic Approach */
"02QH0ZZ"  =  "1"  /* Repair Pulmonary Valve, Open Approach */
"02QH3ZZ"  =  "1"  /* Repair Pulmonary Valve, Percutaneous Approach */
"02QH4ZZ"  =  "1"  /* Repair Pulmonary Valve, Percutaneous Endoscopic Approach */
"02QJ0ZZ"  =  "1"  /* Repair Tricuspid Valve, Open Approach */
"02QJ3ZZ"  =  "1"  /* Repair Tricuspid Valve, Percutaneous Approach */
"02QJ4ZZ"  =  "1"  /* Repair Tricuspid Valve, Percutaneous Endoscopic Approach */
"02QM0ZZ"  =  "1"  /* Repair Ventricular Septum, Open Approach */
"02QM3ZZ"  =  "1"  /* Repair Ventricular Septum, Percutaneous Approach */
"02QM4ZZ"  =  "1"  /* Repair Ventricular Septum, Percutaneous Endoscopic Approach */
"02R907Z"  =  "1"  /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02R908Z"  =  "1"  /* Replacement of Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02R90JZ"  =  "1"  /* Replacement of Chordae Tendineae with Synthetic Substitute, Open Approach */
"02R90KZ"  =  "1"  /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02R947Z"  =  "1"  /* Replacement of Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02R948Z"  =  "1"  /* Replacement of Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02R94JZ"  =  "1"  /* Replacement of Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02R94KZ"  =  "1"  /* Replacement of Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD07Z"  =  "1"  /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02RD08Z"  =  "1"  /* Replacement of Papillary Muscle with Zooplastic Tissue, Open Approach */
"02RD0JZ"  =  "1"  /* Replacement of Papillary Muscle with Synthetic Substitute, Open Approach */
"02RD0KZ"  =  "1"  /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02RD47Z"  =  "1"  /* Replacement of Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RD48Z"  =  "1"  /* Replacement of Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RD4JZ"  =  "1"  /* Replacement of Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RD4KZ"  =  "1"  /* Replacement of Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF07Z"  =  "1"  /* Replacement of Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02RF08Z"  =  "1"  /* Replacement of Aortic Valve with Zooplastic Tissue, Open Approach */
"02RF0JZ"  =  "1"  /* Replacement of Aortic Valve with Synthetic Substitute, Open Approach */
"02RF0KZ"  =  "1"  /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02RF37H"  =  "1"  /* Replacement of Aortic Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RF37Z"  =  "1"  /* Replacement of Aortic Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RF38H"  =  "1"  /* Replacement of Aortic Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RF38Z"  =  "1"  /* Replacement of Aortic Valve with Zooplastic Tissue, Percutaneous Approach */
"02RF3JH"  =  "1"  /* Replacement of Aortic Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RF3JZ"  =  "1"  /* Replacement of Aortic Valve with Synthetic Substitute, Percutaneous Approach */
"02RF3KH"  =  "1"  /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RF3KZ"  =  "1"  /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RF47Z"  =  "1"  /* Replacement of Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RF48Z"  =  "1"  /* Replacement of Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RF4JZ"  =  "1"  /* Replacement of Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RF4KZ"  =  "1"  /* Replacement of Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG07Z"  =  "1"  /* Replacement of Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02RG08Z"  =  "1"  /* Replacement of Mitral Valve with Zooplastic Tissue, Open Approach */
"02RG0JZ"  =  "1"  /* Replacement of Mitral Valve with Synthetic Substitute, Open Approach */
"02RG0KZ"  =  "1"  /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02RG37H"  =  "1"  /* Replacement of Mitral Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RG37Z"  =  "1"  /* Replacement of Mitral Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RG38H"  =  "1"  /* Replacement of Mitral Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RG38Z"  =  "1"  /* Replacement of Mitral Valve with Zooplastic Tissue, Percutaneous Approach */
"02RG3JH"  =  "1"  /* Replacement of Mitral Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RG3JZ"  =  "1"  /* Replacement of Mitral Valve with Synthetic Substitute, Percutaneous Approach */
"02RG3KH"  =  "1"  /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RG3KZ"  =  "1"  /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RG47Z"  =  "1"  /* Replacement of Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RG48Z"  =  "1"  /* Replacement of Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RG4JZ"  =  "1"  /* Replacement of Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RG4KZ"  =  "1"  /* Replacement of Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH07Z"  =  "1"  /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02RH08Z"  =  "1"  /* Replacement of Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02RH0JZ"  =  "1"  /* Replacement of Pulmonary Valve with Synthetic Substitute, Open Approach */
"02RH0KZ"  =  "1"  /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02RH37H"  =  "1"  /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RH37Z"  =  "1"  /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RH38H"  =  "1"  /* Replacement of Pulmonary Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RH38Z"  =  "1"  /* Replacement of Pulmonary Valve with Zooplastic Tissue, Percutaneous Approach */
"02RH3JH"  =  "1"  /* Replacement of Pulmonary Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RH3JZ"  =  "1"  /* Replacement of Pulmonary Valve with Synthetic Substitute, Percutaneous Approach */
"02RH3KH"  =  "1"  /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RH3KZ"  =  "1"  /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RH47Z"  =  "1"  /* Replacement of Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RH48Z"  =  "1"  /* Replacement of Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RH4JZ"  =  "1"  /* Replacement of Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RH4KZ"  =  "1"  /* Replacement of Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ07Z"  =  "1"  /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02RJ08Z"  =  "1"  /* Replacement of Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02RJ0JZ"  =  "1"  /* Replacement of Tricuspid Valve with Synthetic Substitute, Open Approach */
"02RJ0KZ"  =  "1"  /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02RJ47Z"  =  "1"  /* Replacement of Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RJ48Z"  =  "1"  /* Replacement of Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02RJ4JZ"  =  "1"  /* Replacement of Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RJ4KZ"  =  "1"  /* Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK07Z"  =  "1"  /* Replacement of Right Ventricle with Autologous Tissue Substitute, Open Approach */
"02RK0JZ"  =  "1"  /* Replacement of Right Ventricle with Synthetic Substitute, Open Approach */
"02RK0KZ"  =  "1"  /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RK47Z"  =  "1"  /* Replacement of Right Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RK4KZ"  =  "1"  /* Replacement of Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL07Z"  =  "1"  /* Replacement of Left Ventricle with Autologous Tissue Substitute, Open Approach */
"02RL0JZ"  =  "1"  /* Replacement of Left Ventricle with Synthetic Substitute, Open Approach */
"02RL0KZ"  =  "1"  /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02RL47Z"  =  "1"  /* Replacement of Left Ventricle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RL4KZ"  =  "1"  /* Replacement of Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM07Z"  =  "1"  /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02RM0JZ"  =  "1"  /* Replacement of Ventricular Septum with Synthetic Substitute, Open Approach */
"02RM0KZ"  =  "1"  /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02RM47Z"  =  "1"  /* Replacement of Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RM4JZ"  =  "1"  /* Replacement of Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02RM4KZ"  =  "1"  /* Replacement of Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02RP0JZ"  =  "1"  /* Replacement of Pulmonary Trunk with Synthetic Substitute, Open Approach */
"02RQ07Z"  =  "1"  /* Replacement of Right Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RQ0JZ"  =  "1"  /* Replacement of Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"02RR07Z"  =  "1"  /* Replacement of Left Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"02RR0JZ"  =  "1"  /* Replacement of Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"02SP0ZZ"  =  "1"  /* Reposition Pulmonary Trunk, Open Approach */
"02SW0ZZ"  =  "1"  /* Reposition Thoracic Aorta, Open Approach */
"02T50ZZ"  =  "1"  /* Resection of Atrial Septum, Open Approach */
"02T53ZZ"  =  "1"  /* Resection of Atrial Septum, Percutaneous Approach */
"02T54ZZ"  =  "1"  /* Resection of Atrial Septum, Percutaneous Endoscopic Approach */
"02T80ZZ"  =  "1"  /* Resection of Conduction Mechanism, Open Approach */
"02T83ZZ"  =  "1"  /* Resection of Conduction Mechanism, Percutaneous Approach */
"02T84ZZ"  =  "1"  /* Resection of Conduction Mechanism, Percutaneous Endoscopic Approach */
"02T90ZZ"  =  "1"  /* Resection of Chordae Tendineae, Open Approach */
"02T93ZZ"  =  "1"  /* Resection of Chordae Tendineae, Percutaneous Approach */
"02T94ZZ"  =  "1"  /* Resection of Chordae Tendineae, Percutaneous Endoscopic Approach */
"02TD0ZZ"  =  "1"  /* Resection of Papillary Muscle, Open Approach */
"02TD3ZZ"  =  "1"  /* Resection of Papillary Muscle, Percutaneous Approach */
"02TD4ZZ"  =  "1"  /* Resection of Papillary Muscle, Percutaneous Endoscopic Approach */
"02TH0ZZ"  =  "1"  /* Resection of Pulmonary Valve, Open Approach */
"02TH3ZZ"  =  "1"  /* Resection of Pulmonary Valve, Percutaneous Approach */
"02TH4ZZ"  =  "1"  /* Resection of Pulmonary Valve, Percutaneous Endoscopic Approach */
"02TM0ZZ"  =  "1"  /* Resection of Ventricular Septum, Open Approach */
"02TM3ZZ"  =  "1"  /* Resection of Ventricular Septum, Percutaneous Approach */
"02TM4ZZ"  =  "1"  /* Resection of Ventricular Septum, Percutaneous Endoscopic Approach */
"02TN0ZZ"  =  "1"  /* Resection of Pericardium, Open Approach */
"02TN3ZZ"  =  "1"  /* Resection of Pericardium, Percutaneous Approach */
"02TN4ZZ"  =  "1"  /* Resection of Pericardium, Percutaneous Endoscopic Approach */
"02U507Z"  =  "1"  /* Supplement Atrial Septum with Autologous Tissue Substitute, Open Approach */
"02U508Z"  =  "1"  /* Supplement Atrial Septum with Zooplastic Tissue, Open Approach */
"02U50JZ"  =  "1"  /* Supplement Atrial Septum with Synthetic Substitute, Open Approach */
"02U50KZ"  =  "1"  /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Open Approach */
"02U537Z"  =  "1"  /* Supplement Atrial Septum with Autologous Tissue Substitute, Percutaneous Approach */
"02U538Z"  =  "1"  /* Supplement Atrial Septum with Zooplastic Tissue, Percutaneous Approach */
"02U53JZ"  =  "1"  /* Supplement Atrial Septum with Synthetic Substitute, Percutaneous Approach */
"02U53KZ"  =  "1"  /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U547Z"  =  "1"  /* Supplement Atrial Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U548Z"  =  "1"  /* Supplement Atrial Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U54JZ"  =  "1"  /* Supplement Atrial Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U54KZ"  =  "1"  /* Supplement Atrial Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U607Z"  =  "1"  /* Supplement Right Atrium with Autologous Tissue Substitute, Open Approach */
"02U608Z"  =  "1"  /* Supplement Right Atrium with Zooplastic Tissue, Open Approach */
"02U60KZ"  =  "1"  /* Supplement Right Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U707Z"  =  "1"  /* Supplement Left Atrium with Autologous Tissue Substitute, Open Approach */
"02U708Z"  =  "1"  /* Supplement Left Atrium with Zooplastic Tissue, Open Approach */
"02U70JZ"  =  "1"  /* Supplement Left Atrium with Synthetic Substitute, Open Approach */
"02U70KZ"  =  "1"  /* Supplement Left Atrium with Nonautologous Tissue Substitute, Open Approach */
"02U737Z"  =  "1"  /* Supplement Left Atrium with Autologous Tissue Substitute, Percutaneous Approach */
"02U738Z"  =  "1"  /* Supplement Left Atrium with Zooplastic Tissue, Percutaneous Approach */
"02U73KZ"  =  "1"  /* Supplement Left Atrium with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U747Z"  =  "1"  /* Supplement Left Atrium with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U748Z"  =  "1"  /* Supplement Left Atrium with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U74KZ"  =  "1"  /* Supplement Left Atrium with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U907Z"  =  "1"  /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Open Approach */
"02U908Z"  =  "1"  /* Supplement Chordae Tendineae with Zooplastic Tissue, Open Approach */
"02U90JZ"  =  "1"  /* Supplement Chordae Tendineae with Synthetic Substitute, Open Approach */
"02U90KZ"  =  "1"  /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Open Approach */
"02U937Z"  =  "1"  /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Approach */
"02U938Z"  =  "1"  /* Supplement Chordae Tendineae with Zooplastic Tissue, Percutaneous Approach */
"02U93JZ"  =  "1"  /* Supplement Chordae Tendineae with Synthetic Substitute, Percutaneous Approach */
"02U93KZ"  =  "1"  /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Approach */
"02U947Z"  =  "1"  /* Supplement Chordae Tendineae with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02U948Z"  =  "1"  /* Supplement Chordae Tendineae with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02U94JZ"  =  "1"  /* Supplement Chordae Tendineae with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02U94KZ"  =  "1"  /* Supplement Chordae Tendineae with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UA0JZ"  =  "1"  /* Supplement Heart with Synthetic Substitute, Open Approach */
"02UA3JZ"  =  "1"  /* Supplement Heart with Synthetic Substitute, Percutaneous Approach */
"02UA4JZ"  =  "1"  /* Supplement Heart with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UD07Z"  =  "1"  /* Supplement Papillary Muscle with Autologous Tissue Substitute, Open Approach */
"02UD08Z"  =  "1"  /* Supplement Papillary Muscle with Zooplastic Tissue, Open Approach */
"02UD0JZ"  =  "1"  /* Supplement Papillary Muscle with Synthetic Substitute, Open Approach */
"02UD0KZ"  =  "1"  /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Open Approach */
"02UD37Z"  =  "1"  /* Supplement Papillary Muscle with Autologous Tissue Substitute, Percutaneous Approach */
"02UD38Z"  =  "1"  /* Supplement Papillary Muscle with Zooplastic Tissue, Percutaneous Approach */
"02UD3JZ"  =  "1"  /* Supplement Papillary Muscle with Synthetic Substitute, Percutaneous Approach */
"02UD3KZ"  =  "1"  /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UD47Z"  =  "1"  /* Supplement Papillary Muscle with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UD48Z"  =  "1"  /* Supplement Papillary Muscle with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UD4JZ"  =  "1"  /* Supplement Papillary Muscle with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UD4KZ"  =  "1"  /* Supplement Papillary Muscle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF07Z"  =  "1"  /* Supplement Aortic Valve with Autologous Tissue Substitute, Open Approach */
"02UF08Z"  =  "1"  /* Supplement Aortic Valve with Zooplastic Tissue, Open Approach */
"02UF0JZ"  =  "1"  /* Supplement Aortic Valve with Synthetic Substitute, Open Approach */
"02UF0KZ"  =  "1"  /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF37Z"  =  "1"  /* Supplement Aortic Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UF38Z"  =  "1"  /* Supplement Aortic Valve with Zooplastic Tissue, Percutaneous Approach */
"02UF3JZ"  =  "1"  /* Supplement Aortic Valve with Synthetic Substitute, Percutaneous Approach */
"02UF3KZ"  =  "1"  /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UF47Z"  =  "1"  /* Supplement Aortic Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF48Z"  =  "1"  /* Supplement Aortic Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF4JZ"  =  "1"  /* Supplement Aortic Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4KZ"  =  "1"  /* Supplement Aortic Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG07Z"  =  "1"  /* Supplement Mitral Valve with Autologous Tissue Substitute, Open Approach */
"02UG08Z"  =  "1"  /* Supplement Mitral Valve with Zooplastic Tissue, Open Approach */
"02UG0JZ"  =  "1"  /* Supplement Mitral Valve with Synthetic Substitute, Open Approach */
"02UG0KZ"  =  "1"  /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG37Z"  =  "1"  /* Supplement Mitral Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UG38Z"  =  "1"  /* Supplement Mitral Valve with Zooplastic Tissue, Percutaneous Approach */
"02UG3JZ"  =  "1"  /* Supplement Mitral Valve with Synthetic Substitute, Percutaneous Approach */
"02UG3KZ"  =  "1"  /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UG47Z"  =  "1"  /* Supplement Mitral Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG48Z"  =  "1"  /* Supplement Mitral Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG4JZ"  =  "1"  /* Supplement Mitral Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4KZ"  =  "1"  /* Supplement Mitral Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH07Z"  =  "1"  /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Open Approach */
"02UH08Z"  =  "1"  /* Supplement Pulmonary Valve with Zooplastic Tissue, Open Approach */
"02UH0JZ"  =  "1"  /* Supplement Pulmonary Valve with Synthetic Substitute, Open Approach */
"02UH0KZ"  =  "1"  /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Open Approach */
"02UH37Z"  =  "1"  /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UH38Z"  =  "1"  /* Supplement Pulmonary Valve with Zooplastic Tissue, Percutaneous Approach */
"02UH3JZ"  =  "1"  /* Supplement Pulmonary Valve with Synthetic Substitute, Percutaneous Approach */
"02UH3KZ"  =  "1"  /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UH47Z"  =  "1"  /* Supplement Pulmonary Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UH48Z"  =  "1"  /* Supplement Pulmonary Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UH4JZ"  =  "1"  /* Supplement Pulmonary Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UH4KZ"  =  "1"  /* Supplement Pulmonary Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ07Z"  =  "1"  /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Open Approach */
"02UJ08Z"  =  "1"  /* Supplement Tricuspid Valve with Zooplastic Tissue, Open Approach */
"02UJ0JZ"  =  "1"  /* Supplement Tricuspid Valve with Synthetic Substitute, Open Approach */
"02UJ0KZ"  =  "1"  /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ37Z"  =  "1"  /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UJ38Z"  =  "1"  /* Supplement Tricuspid Valve with Zooplastic Tissue, Percutaneous Approach */
"02UJ3JZ"  =  "1"  /* Supplement Tricuspid Valve with Synthetic Substitute, Percutaneous Approach */
"02UJ3KZ"  =  "1"  /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UJ47Z"  =  "1"  /* Supplement Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ48Z"  =  "1"  /* Supplement Tricuspid Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ4JZ"  =  "1"  /* Supplement Tricuspid Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4KZ"  =  "1"  /* Supplement Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UK0KZ"  =  "1"  /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UK3KZ"  =  "1"  /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UK4KZ"  =  "1"  /* Supplement Right Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UL0KZ"  =  "1"  /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Open Approach */
"02UL3KZ"  =  "1"  /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UL4KZ"  =  "1"  /* Supplement Left Ventricle with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM07Z"  =  "1"  /* Supplement Ventricular Septum with Autologous Tissue Substitute, Open Approach */
"02UM0JZ"  =  "1"  /* Supplement Ventricular Septum with Synthetic Substitute, Open Approach */
"02UM0KZ"  =  "1"  /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Open Approach */
"02UM37Z"  =  "1"  /* Supplement Ventricular Septum with Autologous Tissue Substitute, Percutaneous Approach */
"02UM38Z"  =  "1"  /* Supplement Ventricular Septum with Zooplastic Tissue, Percutaneous Approach */
"02UM3JZ"  =  "1"  /* Supplement Ventricular Septum with Synthetic Substitute, Percutaneous Approach */
"02UM3KZ"  =  "1"  /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UM47Z"  =  "1"  /* Supplement Ventricular Septum with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UM48Z"  =  "1"  /* Supplement Ventricular Septum with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UM4JZ"  =  "1"  /* Supplement Ventricular Septum with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UM4KZ"  =  "1"  /* Supplement Ventricular Septum with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02VR0ZT"  =  "1"  /* Restriction of Ductus Arteriosus, Open Approach */
"02W50JZ"  =  "1"  /* Revision of Synthetic Substitute in Atrial Septum, Open Approach */
"02W54JZ"  =  "1"  /* Revision of Synthetic Substitute in Atrial Septum, Percutaneous Endoscopic Approach */
"02WA0JZ"  =  "1"  /* Revision of Synthetic Substitute in Heart, Open Approach */
"02WA0MZ"  =  "1"  /* Revision of Cardiac Lead in Heart, Open Approach */
"02WA0QZ"  =  "1"  /* Revision of Implantable Heart Assist System in Heart, Open Approach */
"02WA0RZ"  =  "1"  /* Revision of External Heart Assist System in Heart, Open Approach */
"02WA3MZ"  =  "1"  /* Revision of Cardiac Lead in Heart, Percutaneous Approach */
"02WA3QZ"  =  "1"  /* Revision of Implantable Heart Assist System in Heart, Percutaneous Approach */
"02WA3RZ"  =  "1"  /* Revision of External Heart Assist System in Heart, Percutaneous Approach */
"02WA4MZ"  =  "1"  /* Revision of Cardiac Lead in Heart, Percutaneous Endoscopic Approach */
"02WA4QZ"  =  "1"  /* Revision of Implantable Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WA4RZ"  =  "1"  /* Revision of External Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WF07Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF08Z"  =  "1"  /* Revision of Zooplastic Tissue in Aortic Valve, Open Approach */
"02WF0JZ"  =  "1"  /* Revision of Synthetic Substitute in Aortic Valve, Open Approach */
"02WF0KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Open Approach */
"02WF47Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF48Z"  =  "1"  /* Revision of Zooplastic Tissue in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4JZ"  =  "1"  /* Revision of Synthetic Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WF4KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Aortic Valve, Percutaneous Endoscopic Approach */
"02WG07Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG08Z"  =  "1"  /* Revision of Zooplastic Tissue in Mitral Valve, Open Approach */
"02WG0JZ"  =  "1"  /* Revision of Synthetic Substitute in Mitral Valve, Open Approach */
"02WG0KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Open Approach */
"02WG47Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG48Z"  =  "1"  /* Revision of Zooplastic Tissue in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4JZ"  =  "1"  /* Revision of Synthetic Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WG4KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Mitral Valve, Percutaneous Endoscopic Approach */
"02WH07Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH08Z"  =  "1"  /* Revision of Zooplastic Tissue in Pulmonary Valve, Open Approach */
"02WH0JZ"  =  "1"  /* Revision of Synthetic Substitute in Pulmonary Valve, Open Approach */
"02WH0KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Open Approach */
"02WH47Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH48Z"  =  "1"  /* Revision of Zooplastic Tissue in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4JZ"  =  "1"  /* Revision of Synthetic Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WH4KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Percutaneous Endoscopic Approach */
"02WJ07Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ08Z"  =  "1"  /* Revision of Zooplastic Tissue in Tricuspid Valve, Open Approach */
"02WJ0JZ"  =  "1"  /* Revision of Synthetic Substitute in Tricuspid Valve, Open Approach */
"02WJ0KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Open Approach */
"02WJ47Z"  =  "1"  /* Revision of Autologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ48Z"  =  "1"  /* Revision of Zooplastic Tissue in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4JZ"  =  "1"  /* Revision of Synthetic Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WJ4KZ"  =  "1"  /* Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Percutaneous Endoscopic Approach */
"02WM0JZ"  =  "1"  /* Revision of Synthetic Substitute in Ventricular Septum, Open Approach */
"02WM4JZ"  =  "1"  /* Revision of Synthetic Substitute in Ventricular Septum, Percutaneous Endoscopic Approach */
"02YA0Z0"  =  "1"  /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1"  =  "1"  /* Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2"  =  "1"  /* Transplantation of Heart, Zooplastic, Open Approach */
"0JH600Z"  =  "1"  /* Insertion of Hemodynamic Monitoring Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH604Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH605Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber Rate Responsive into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH606Z"  =  "1"  /* Insertion of Pacemaker, Dual Chamber into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH607Z"  =  "1"  /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH608Z"  =  "1"  /* Insertion of Defibrillator Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH609Z"  =  "1"  /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60AZ"  =  "1"  /* Insertion of Contractility Modulation Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH60PZ"  =  "1"  /* Insertion of Cardiac Rhythm Related Device into Chest Subcutaneous Tissue and Fascia, Open Approach */
"0JH630Z"  =  "1"  /* Insertion of Hemodynamic Monitoring Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH634Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH635Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber Rate Responsive into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH636Z"  =  "1"  /* Insertion of Pacemaker, Dual Chamber into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH637Z"  =  "1"  /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH638Z"  =  "1"  /* Insertion of Defibrillator Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH639Z"  =  "1"  /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63AZ"  =  "1"  /* Insertion of Contractility Modulation Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH63PZ"  =  "1"  /* Insertion of Cardiac Rhythm Related Device into Chest Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH800Z"  =  "1"  /* Insertion of Hemodynamic Monitoring Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH804Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH805Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber Rate Responsive into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH806Z"  =  "1"  /* Insertion of Pacemaker, Dual Chamber into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH807Z"  =  "1"  /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH808Z"  =  "1"  /* Insertion of Defibrillator Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH809Z"  =  "1"  /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80AZ"  =  "1"  /* Insertion of Contractility Modulation Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH80PZ"  =  "1"  /* Insertion of Cardiac Rhythm Related Device into Abdomen Subcutaneous Tissue and Fascia, Open Approach */
"0JH830Z"  =  "1"  /* Insertion of Hemodynamic Monitoring Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH834Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH835Z"  =  "1"  /* Insertion of Pacemaker, Single Chamber Rate Responsive into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH836Z"  =  "1"  /* Insertion of Pacemaker, Dual Chamber into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH837Z"  =  "1"  /* Insertion of Cardiac Resynchronization Pacemaker Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH838Z"  =  "1"  /* Insertion of Defibrillator Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH839Z"  =  "1"  /* Insertion of Cardiac Resynchronization Defibrillator Pulse Generator into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83AZ"  =  "1"  /* Insertion of Contractility Modulation Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JH83PZ"  =  "1"  /* Insertion of Cardiac Rhythm Related Device into Abdomen Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JPT0PZ"  =  "1"  /* Removal of Cardiac Rhythm Related Device from Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JPT3PZ"  =  "1"  /* Removal of Cardiac Rhythm Related Device from Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"0JWT0PZ"  =  "1"  /* Revision of Cardiac Rhythm Related Device in Trunk Subcutaneous Tissue and Fascia, Open Approach */
"0JWT3PZ"  =  "1"  /* Revision of Cardiac Rhythm Related Device in Trunk Subcutaneous Tissue and Fascia, Percutaneous Approach */
"3E07017"  =  "1"  /* Introduction of Other Thrombolytic into Coronary Artery, Open Approach */
"3E070PZ"  =  "1"  /* Introduction of Platelet Inhibitor into Coronary Artery, Open Approach */
"3E07317"  =  "1"  /* Introduction of Other Thrombolytic into Coronary Artery, Percutaneous Approach */
"3E073PZ"  =  "1"  /* Introduction of Platelet Inhibitor into Coronary Artery, Percutaneous Approach */
"5A02110"  =  "1"  /* Assistance with Cardiac Output using Balloon Pump, Intermittent */
"5A02116"  =  "1"  /* Assistance with Cardiac Output using Other Pump, Intermittent */
"5A02210"  =  "1"  /* Assistance with Cardiac Output using Balloon Pump, Continuous */
"5A02216"  =  "1"  /* Assistance with Cardiac Output using Other Pump, Continuous */
"5A1213Z"  =  "1"  /* Performance of Cardiac Pacing, Intermittent */
"5A1223Z"  =  "1"  /* Performance of Cardiac Pacing, Continuous */
OTHER   = 0 ;


 /* -------------------------------------- */
 /* Congestive Heart Failure rate (MRTCHF) */
 /*   Mortality Indicator / PQI 08         */
 /* -------------------------------------- */

 /* CHF */
 /* ICD-10-CM Diagnosis Codes: */

value $MRTCHFD
"I0981"  =  "1"  /* Rheumatic heart failure */
"I110"  =  "1"  /* Hypertensive heart disease with heart failure */
"I130"  =  "1"  /* Hypertensive heart and chronic kidney disease with heart failure and stage 1 through stage 4 chronic kidney disease, or unspecified chronic kidney disease */
"I132"  =  "1"  /* Hypertensive heart and chronic kidney disease with heart failure and with stage 5 chronic kidney disease, or end stage renal disease */
"I501"  =  "1"  /* Left ventricular failure */
"I5020"  =  "1"  /* Unspecified systolic (congestive) heart failure */
"I5021"  =  "1"  /* Acute systolic (congestive) heart failure */
"I5022"  =  "1"  /* Chronic systolic (congestive) heart failure */
"I5023"  =  "1"  /* Acute on chronic systolic (congestive) heart failure */
"I5030"  =  "1"  /* Unspecified diastolic (congestive) heart failure */
"I5031"  =  "1"  /* Acute diastolic (congestive) heart failure */
"I5032"  =  "1"  /* Chronic diastolic (congestive) heart failure */
"I5033"  =  "1"  /* Acute on chronic diastolic (congestive) heart failure */
"I5040"  =  "1"  /* Unspecified combined systolic (congestive) and diastolic (congestive) heart failure */
"I5041"  =  "1"  /* Acute combined systolic (congestive) and diastolic (congestive) heart failure */
"I5042"  =  "1"  /* Chronic combined systolic (congestive) and diastolic (congestive) heart failure */
"I5043"  =  "1"  /* Acute on chronic combined systolic (congestive) and diastolic (congestive) heart failure */
"I509"  =  "1"  /* Heart failure, unspecified */
OTHER   = '0' ;


 /* Dehydration */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSDEHD
"E860"  =  "1"  /* Dehydration */
"E861"  =  "1"  /* Hypovolemia */
"E869"  =  "1"  /* Volume depletion, unspecified */
OTHER   = 0 ;

 /* --------------------------------- */
 /* Bacterial Pneumonia rate (ACSBAC) */
 /*   PQI   11                        */
 /* --------------------------------- */

 /* Bacterial Pneumonia */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSBACD
"J13"  =  "1"  /* Pneumonia due to Streptococcus pneumoniae */
"J14"  =  "1"  /* Pneumonia due to Hemophilus influenzae */
"J15211"  =  "1"  /* Pneumonia due to Methicillin susceptible Staphylococcus aureus */
"J15212"  =  "1"  /* Pneumonia due to Methicillin resistant Staphylococcus aureus */
"J153"  =  "1"  /* Pneumonia due to streptococcus, group B */
"J154"  =  "1"  /* Pneumonia due to other streptococci */
"J157"  =  "1"  /* Pneumonia due to Mycoplasma pneumoniae */
"J159"  =  "1"  /* Unspecified bacterial pneumonia */
"J160"  =  "1"  /* Chlamydial pneumonia */
"J168"  =  "1"  /* Pneumonia due to other specified infectious organisms */
"J180"  =  "1"  /* Bronchopneumonia, unspecified organism */
"J181"  =  "1"  /* Lobar pneumonia, unspecified organism */
"J188"  =  "1"  /* Other pneumonia, unspecified organism */
"J189"  =  "1"  /* Pneumonia, unspecified organism */
OTHER   = 0 ;


 /* Exclude: Sickle Cell      */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSBA2D
"D5700"  =  "1"  /* Hb-SS disease with crisis, unspecified */
"D5701"  =  "1"  /* Hb-SS disease with acute chest syndrome */
"D5702"  =  "1"  /* Hb-SS disease with splenic sequestration */
"D571"  =  "1"  /* Sickle-cell disease without crisis */
"D5720"  =  "1"  /* Sickle-cell/Hb-C disease without crisis */
"D57211"  =  "1"  /* Sickle-cell/Hb-C disease with acute chest syndrome */
"D57212"  =  "1"  /* Sickle-cell/Hb-C disease with splenic sequestration */
"D57219"  =  "1"  /* Sickle-cell/Hb-C disease with crisis, unspecified */
"D5740"  =  "1"  /* Sickle-cell thalassemia without crisis */
"D57411"  =  "1"  /* Sickle-cell thalassemia with acute chest syndrome */
"D57412"  =  "1"  /* Sickle-cell thalassemia with splenic sequestration */
"D57419"  =  "1"  /* Sickle-cell thalassemia with crisis, unspecified */
"D5780"  =  "1"  /* Other sickle-cell disorders without crisis */
"D57811"  =  "1"  /* Other sickle-cell disorders with acute chest syndrome */
"D57812"  =  "1"  /* Other sickle-cell disorders with splenic sequestration */
"D57819"  =  "1"  /* Other sickle-cell disorders with crisis, unspecified */
OTHER   = 0 ;

 /* HYPEROSMOLALITY AND /OR HYPERNATREMIA   */
 /* ICD-10-CM DIAGNOSIS CODES:              */

 value $HYPERID
"E870"  =  "1"  /* Hyperosmolality and hypernatremia */
OTHER   = 0 ;


 /* Urinary Infection */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSUTID
"N10"  =  "1"  /* Acute tubulo-interstitial nephritis */
"N119"  =  "1"  /* Chronic tubulo-interstitial nephritis, unspecified */
"N12"  =  "1"  /* Tubulo-interstitial nephritis, not specified as acute or chronic */
"N151"  =  "1"  /* Renal and perinephric abscess */
"N159"  =  "1"  /* Renal tubulo-interstitial disease, unspecified */
"N16"  =  "1"  /* Renal tubulo-interstitial disorders in diseases classified elsewhere */
"N2884"  =  "1"  /* Pyelitis cystica */
"N2885"  =  "1"  /* Pyeloureteritis cystica */
"N2886"  =  "1"  /* Ureteritis cystica */
"N3000"  =  "1"  /* Acute cystitis without hematuria */
"N3001"  =  "1"  /* Acute cystitis with hematuria */
"N3090"  =  "1"  /* Cystitis, unspecified without hematuria */
"N3091"  =  "1"  /* Cystitis, unspecified with hematuria */
"N390"  =  "1"  /* Urinary tract infection, site not specified */
OTHER   = 0 ;

 /* EXCLUDE: IMMUNOCOMPROMISED */
 /* ICD-10-CM DIAGNOSIS CODES */

value $IMMUNID
"B20"  =  "1"  /* Human immunodeficiency virus [HIV] disease */
"B59"  =  "1"  /* Pneumocystosis */
"C802"  =  "1"  /* Malignant neoplasm associated with transplanted organ */
"C888"  =  "1"  /* Other malignant immunoproliferative diseases */
"C9440"  =  "1"  /* Acute panmyelosis with myelofibrosis not having achieved remission */
"C9441"  =  "1"  /* Acute panmyelosis with myelofibrosis, in remission */
"C9442"  =  "1"  /* Acute panmyelosis with myelofibrosis, in relapse */
"C946"  =  "1"  /* Myelodysplastic disease, not classified */
"D4622"  =  "1"  /* Refractory anemia with excess of blasts 2 */
"D471"  =  "1"  /* Chronic myeloproliferative disease */
"D479"  =  "1"  /* Neoplasm of uncertain behavior of lymphoid, hematopoietic and related tissue, unspecified */
"D47Z1"  =  "1"  /* Post-transplant lymphoproliferative disorder (PTLD) */
"D47Z9"  =  "1"  /* Other specified neoplasms of uncertain behavior of lymphoid, hematopoietic and related tissue */
"D6109"  =  "1"  /* Other constitutional aplastic anemia */
"D61810"  =  "1"  /* Antineoplastic chemotherapy induced pancytopenia */
"D61811"  =  "1"  /* Other drug-induced pancytopenia */
"D61818"  =  "1"  /* Other pancytopenia */
"D700"  =  "1"  /* Congenital agranulocytosis */
"D701"  =  "1"  /* Agranulocytosis secondary to cancer chemotherapy */
"D702"  =  "1"  /* Other drug-induced agranulocytosis */
"D704"  =  "1"  /* Cyclic neutropenia */
"D708"  =  "1"  /* Other neutropenia */
"D709"  =  "1"  /* Neutropenia, unspecified */
"D71"  =  "1"  /* Functional disorders of polymorphonuclear neutrophils */
"D720"  =  "1"  /* Genetic anomalies of leukocytes */
"D72810"  =  "1"  /* Lymphocytopenia */
"D72818"  =  "1"  /* Other decreased white blood cell count */
"D72819"  =  "1"  /* Decreased white blood cell count, unspecified */
"D7381"  =  "1"  /* Neutropenic splenomegaly */
"D7581"  =  "1"  /* Myelofibrosis */
"D761"  =  "1"  /* Hemophagocytic lymphohistiocytosis */
"D762"  =  "1"  /* Hemophagocytic syndrome, infection-associated */
"D763"  =  "1"  /* Other histiocytosis syndromes */
"D800"  =  "1"  /* Hereditary hypogammaglobulinemia */
"D801"  =  "1"  /* Nonfamilial hypogammaglobulinemia */
"D802"  =  "1"  /* Selective deficiency of immunoglobulin A [IgA] */
"D803"  =  "1"  /* Selective deficiency of immunoglobulin G [IgG] subclasses */
"D804"  =  "1"  /* Selective deficiency of immunoglobulin M [IgM] */
"D805"  =  "1"  /* Immunodeficiency with increased immunoglobulin M [IgM] */
"D806"  =  "1"  /* Antibody deficiency with near-normal immunoglobulins or with hyperimmunoglobulinemia */
"D807"  =  "1"  /* Transient hypogammaglobulinemia of infancy */
"D808"  =  "1"  /* Other immunodeficiencies with predominantly antibody defects */
"D809"  =  "1"  /* Immunodeficiency with predominantly antibody defects, unspecified */
"D810"  =  "1"  /* Severe combined immunodeficiency [SCID] with reticular dysgenesis */
"D811"  =  "1"  /* Severe combined immunodeficiency [SCID] with low T- and B-cell numbers */
"D812"  =  "1"  /* Severe combined immunodeficiency [SCID] with low or normal B-cell numbers */
"D814"  =  "1"  /* Nezelof's syndrome */
"D816"  =  "1"  /* Major histocompatibility complex class I deficiency */
"D817"  =  "1"  /* Major histocompatibility complex class II deficiency */
"D8189"  =  "1"  /* Other combined immunodeficiencies */
"D819"  =  "1"  /* Combined immunodeficiency, unspecified */
"D820"  =  "1"  /* Wiskott-Aldrich syndrome */
"D821"  =  "1"  /* Di George's syndrome */
"D822"  =  "1"  /* Immunodeficiency with short-limbed stature */
"D823"  =  "1"  /* Immunodeficiency following hereditary defective response to Epstein-Barr virus */
"D824"  =  "1"  /* Hyperimmunoglobulin E [IgE] syndrome */
"D828"  =  "1"  /* Immunodeficiency associated with other specified major defects */
"D829"  =  "1"  /* Immunodeficiency associated with major defect, unspecified */
"D830"  =  "1"  /* Common variable immunodeficiency with predominant abnormalities of B-cell numbers and function */
"D831"  =  "1"  /* Common variable immunodeficiency with predominant immunoregulatory T-cell disorders */
"D832"  =  "1"  /* Common variable immunodeficiency with autoantibodies to B- or T-cells */
"D838"  =  "1"  /* Other common variable immunodeficiencies */
"D839"  =  "1"  /* Common variable immunodeficiency, unspecified */
"D840"  =  "1"  /* Lymphocyte function antigen-1 [LFA-1] defect */
"D841"  =  "1"  /* Defects in the complement system */
"D848"  =  "1"  /* Other specified immunodeficiencies */
"D849"  =  "1"  /* Immunodeficiency, unspecified */
"D893"  =  "1"  /* Immune reconstitution syndrome */
"D89810"  =  "1"  /* Acute graft-versus-host disease */
"D89811"  =  "1"  /* Chronic graft-versus-host disease */
"D89812"  =  "1"  /* Acute on chronic graft-versus-host disease */
"D89813"  =  "1"  /* Graft-versus-host disease, unspecified */
"D8982"  =  "1"  /* Autoimmune lymphoproliferative syndrome [ALPS] */
"D8989"  =  "1"  /* Other specified disorders involving the immune mechanism, not elsewhere classified */
"D899"  =  "1"  /* Disorder involving the immune mechanism, unspecified */
"E40"  =  "1"  /* Kwashiorkor */
"E41"  =  "1"  /* Nutritional marasmus */
"E42"  =  "1"  /* Marasmic kwashiorkor */
"E43"  =  "1"  /* Unspecified severe protein-calorie malnutrition */
"I120"  =  "1"  /* Hypertensive chronic kidney disease with stage 5 chronic kidney disease or end stage renal disease */
"I1311"  =  "1"  /* Hypertensive heart and chronic kidney disease without heart failure, with stage 5 chronic kidney disease, or end stage renal disease */
"I132"  =  "1"  /* Hypertensive heart and chronic kidney disease with heart failure and with stage 5 chronic kidney disease, or end stage renal disease */
"K912"  =  "1"  /* Postsurgical malabsorption, not elsewhere classified */
"M359"  =  "1"  /* Systemic involvement of connective tissue, unspecified */
"N185"  =  "1"  /* Chronic kidney disease, stage 5 */
"N186"  =  "1"  /* End stage renal disease */
"T8600"  =  "1"  /* Unspecified complication of bone marrow transplant */
"T8601"  =  "1"  /* Bone marrow transplant rejection */
"T8602"  =  "1"  /* Bone marrow transplant failure */
"T8603"  =  "1"  /* Bone marrow transplant infection */
"T8609"  =  "1"  /* Other complications of bone marrow transplant */
"T8610"  =  "1"  /* Unspecified complication of kidney transplant */
"T8611"  =  "1"  /* Kidney transplant rejection */
"T8612"  =  "1"  /* Kidney transplant failure */
"T8613"  =  "1"  /* Kidney transplant infection */
"T8619"  =  "1"  /* Other complication of kidney transplant */
"T8620"  =  "1"  /* Unspecified complication of heart transplant */
"T8621"  =  "1"  /* Heart transplant rejection */
"T8622"  =  "1"  /* Heart transplant failure */
"T8623"  =  "1"  /* Heart transplant infection */
"T86290"  =  "1"  /* Cardiac allograft vasculopathy */
"T86298"  =  "1"  /* Other complications of heart transplant */
"T8630"  =  "1"  /* Unspecified complication of heart-lung transplant */
"T8631"  =  "1"  /* Heart-lung transplant rejection */
"T8632"  =  "1"  /* Heart-lung transplant failure */
"T8633"  =  "1"  /* Heart-lung transplant infection */
"T8639"  =  "1"  /* Other complications of heart-lung transplant */
"T8640"  =  "1"  /* Unspecified complication of liver transplant */
"T8641"  =  "1"  /* Liver transplant rejection */
"T8642"  =  "1"  /* Liver transplant failure */
"T8643"  =  "1"  /* Liver transplant infection */
"T8649"  =  "1"  /* Other complications of liver transplant */
"T865"  =  "1"  /* Complications of stem cell transplant */
"T86810"  =  "1"  /* Lung transplant rejection */
"T86811"  =  "1"  /* Lung transplant failure */
"T86812"  =  "1"  /* Lung transplant infection */
"T86818"  =  "1"  /* Other complications of lung transplant */
"T86819"  =  "1"  /* Unspecified complication of lung transplant */
"T86830"  =  "1"  /* Bone graft rejection */
"T86831"  =  "1"  /* Bone graft failure */
"T86832"  =  "1"  /* Bone graft infection */
"T86838"  =  "1"  /* Other complications of bone graft */
"T86839"  =  "1"  /* Unspecified complication of bone graft */
"T86850"  =  "1"  /* Intestine transplant rejection */
"T86851"  =  "1"  /* Intestine transplant failure */
"T86852"  =  "1"  /* Intestine transplant infection */
"T86858"  =  "1"  /* Other complications of intestine transplant */
"T86859"  =  "1"  /* Unspecified complication of intestine transplant */
"T86890"  =  "1"  /* Other transplanted tissue rejection */
"T86891"  =  "1"  /* Other transplanted tissue failure */
"T86892"  =  "1"  /* Other transplanted tissue infection */
"T86898"  =  "1"  /* Other complications of other transplanted tissue */
"T86899"  =  "1"  /* Unspecified complication of other transplanted tissue */
"T8690"  =  "1"  /* Unspecified complication of unspecified transplanted organ and tissue */
"T8691"  =  "1"  /* Unspecified transplanted organ and tissue rejection */
"T8692"  =  "1"  /* Unspecified transplanted organ and tissue failure */
"T8693"  =  "1"  /* Unspecified transplanted organ and tissue infection */
"T8699"  =  "1"  /* Other complications of unspecified transplanted organ and tissue */
"Z4821"  =  "1"  /* Encounter for aftercare following heart transplant */
"Z4822"  =  "1"  /* Encounter for aftercare following kidney transplant */
"Z4823"  =  "1"  /* Encounter for aftercare following liver transplant */
"Z4824"  =  "1"  /* Encounter for aftercare following lung transplant */
"Z48280"  =  "1"  /* Encounter for aftercare following heart-lung transplant */
"Z48290"  =  "1"  /* Encounter for aftercare following bone marrow transplant */
"Z48298"  =  "1"  /* Encounter for aftercare following other organ transplant */
"Z4901"  =  "1"  /* Encounter for fitting and adjustment of extracorporeal dialysis catheter */
"Z4902"  =  "1"  /* Encounter for fitting and adjustment of peritoneal dialysis catheter */
"Z4931"  =  "1"  /* Encounter for adequacy testing for hemodialysis */
"Z940"  =  "1"  /* Kidney transplant status */
"Z941"  =  "1"  /* Heart transplant status */
"Z942"  =  "1"  /* Lung transplant status */
"Z943"  =  "1"  /* Heart and lungs transplant status */
"Z944"  =  "1"  /* Liver transplant status */
"Z9481"  =  "1"  /* Bone marrow transplant status */
"Z9482"  =  "1"  /* Intestine transplant status */
"Z9483"  =  "1"  /* Pancreas transplant status */
"Z9484"  =  "1"  /* Stem cells transplant status */
"Z9489"  =  "1"  /* Other transplanted organ and tissue status */
"Z992"  =  "1"  /* Dependence on renal dialysis */
OTHER   = 0 ;

 /* EXCLUDE: IMMUNOCOMPROMISED */
 /* ICD-10-CM PROCEDURE CODES */

value $IMMUNIP
"02YA0Z0"  =  "1"  /* Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z2"  =  "1"  /* Transplantation of Heart, Zooplastic, Open Approach */
"0BYC0Z0"  =  "1"  /* Transplantation of Right Upper Lung Lobe, Allogeneic, Open Approach */
"0BYC0Z2"  =  "1"  /* Transplantation of Right Upper Lung Lobe, Zooplastic, Open Approach */
"0BYD0Z0"  =  "1"  /* Transplantation of Right Middle Lung Lobe, Allogeneic, Open Approach */
"0BYD0Z2"  =  "1"  /* Transplantation of Right Middle Lung Lobe, Zooplastic, Open Approach */
"0BYF0Z0"  =  "1"  /* Transplantation of Right Lower Lung Lobe, Allogeneic, Open Approach */
"0BYF0Z2"  =  "1"  /* Transplantation of Right Lower Lung Lobe, Zooplastic, Open Approach */
"0BYG0Z0"  =  "1"  /* Transplantation of Left Upper Lung Lobe, Allogeneic, Open Approach */
"0BYG0Z2"  =  "1"  /* Transplantation of Left Upper Lung Lobe, Zooplastic, Open Approach */
"0BYH0Z0"  =  "1"  /* Transplantation of Lung Lingula, Allogeneic, Open Approach */
"0BYH0Z2"  =  "1"  /* Transplantation of Lung Lingula, Zooplastic, Open Approach */
"0BYJ0Z0"  =  "1"  /* Transplantation of Left Lower Lung Lobe, Allogeneic, Open Approach */
"0BYJ0Z2"  =  "1"  /* Transplantation of Left Lower Lung Lobe, Zooplastic, Open Approach */
"0BYK0Z0"  =  "1"  /* Transplantation of Right Lung, Allogeneic, Open Approach */
"0BYK0Z2"  =  "1"  /* Transplantation of Right Lung, Zooplastic, Open Approach */
"0BYL0Z0"  =  "1"  /* Transplantation of Left Lung, Allogeneic, Open Approach */
"0BYL0Z2"  =  "1"  /* Transplantation of Left Lung, Zooplastic, Open Approach */
"0BYM0Z0"  =  "1"  /* Transplantation of Bilateral Lungs, Allogeneic, Open Approach */
"0BYM0Z2"  =  "1"  /* Transplantation of Bilateral Lungs, Zooplastic, Open Approach */
"0FSG0ZZ"  =  "1"  /* Reposition Pancreas, Open Approach */
"0FSG4ZZ"  =  "1"  /* Reposition Pancreas, Percutaneous Endoscopic Approach */
"0FY00Z0"  =  "1"  /* Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z2"  =  "1"  /* Transplantation of Liver, Zooplastic, Open Approach */
"0FYG0Z0"  =  "1"  /* Transplantation of Pancreas, Allogeneic, Open Approach */
"0FYG0Z2"  =  "1"  /* Transplantation of Pancreas, Zooplastic, Open Approach */
"0TY00Z0"  =  "1"  /* Transplantation of Right Kidney, Allogeneic, Open Approach */
"0TY00Z2"  =  "1"  /* Transplantation of Right Kidney, Zooplastic, Open Approach */
"0TY10Z0"  =  "1"  /* Transplantation of Left Kidney, Allogeneic, Open Approach */
"0TY10Z2"  =  "1"  /* Transplantation of Left Kidney, Zooplastic, Open Approach */
"30230AZ"  =  "1"  /* Transfusion of Embryonic Stem Cells into Peripheral Vein, Open Approach */
"30230G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Peripheral Vein, Open Approach */
"30230G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Peripheral Vein, Open Approach */
"30230X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30233AZ"  =  "1"  /* Transfusion of Embryonic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30240AZ"  =  "1"  /* Transfusion of Embryonic Stem Cells into Central Vein, Open Approach */
"30240G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Central Vein, Open Approach */
"30240G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Central Vein, Open Approach */
"30240X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Vein, Open Approach */
"30240Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Vein, Open Approach */
"30243AZ"  =  "1"  /* Transfusion of Embryonic Stem Cells into Central Vein, Percutaneous Approach */
"30243G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Central Vein, Percutaneous Approach */
"30243G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Central Vein, Percutaneous Approach */
"30243X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30250G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Peripheral Artery, Open Approach */
"30250G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Peripheral Artery, Open Approach */
"30250X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Artery, Open Approach */
"30250X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Artery, Open Approach */
"30250Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Artery, Open Approach */
"30250Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Artery, Open Approach */
"30253G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Peripheral Artery, Percutaneous Approach */
"30253G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Peripheral Artery, Percutaneous Approach */
"30253X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Peripheral Artery, Percutaneous Approach */
"30253Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Peripheral Artery, Percutaneous Approach */
"30260G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Central Artery, Open Approach */
"30260G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Central Artery, Open Approach */
"30260X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Central Artery, Open Approach */
"30260X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Artery, Open Approach */
"30260Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Central Artery, Open Approach */
"30260Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Artery, Open Approach */
"30263G0"  =  "1"  /* Transfusion of Autologous Bone Marrow into Central Artery, Percutaneous Approach */
"30263G1"  =  "1"  /* Transfusion of Nonautologous Bone Marrow into Central Artery, Percutaneous Approach */
"30263X0"  =  "1"  /* Transfusion of Autologous Cord Blood Stem Cells into Central Artery, Percutaneous Approach */
"30263X1"  =  "1"  /* Transfusion of Nonautologous Cord Blood Stem Cells into Central Artery, Percutaneous Approach */
"30263Y0"  =  "1"  /* Transfusion of Autologous Hematopoietic Stem Cells into Central Artery, Percutaneous Approach */
"30263Y1"  =  "1"  /* Transfusion of Nonautologous Hematopoietic Stem Cells into Central Artery, Percutaneous Approach */
"3E03005"  =  "1"  /* Introduction of Other Antineoplastic into Peripheral Vein, Open Approach */
"3E0300M"  =  "1"  /* Introduction of Monoclonal Antibody into Peripheral Vein, Open Approach */
"3E030U1"  =  "1"  /* Introduction of Nonautologous Pancreatic Islet Cells into Peripheral Vein, Open Approach */
"3E030WL"  =  "1"  /* Introduction of Immunosuppressive into Peripheral Vein, Open */
"3E03305"  =  "1"  /* Introduction of Other Antineoplastic into Peripheral Vein, Percutaneous Approach */
"3E0330M"  =  "1"  /* Introduction of Monoclonal Antibody into Peripheral Vein, Percutaneous Approach */
"3E033U1"  =  "1"  /* Introduction of Nonautologous Pancreatic Islet Cells into Peripheral Vein, Percutaneous Approach */
"3E033WL"  =  "1"  /* Introduction of Immunosuppressive into Peripheral Vein, Percutaneous */
"3E04005"  =  "1"  /* Introduction of Other Antineoplastic into Central Vein, Open Approach */
"3E0400M"  =  "1"  /* Introduction of Monoclonal Antibody into Central Vein, Open Approach */
"3E040WL"  =  "1"  /* Introduction of Immunosuppressive into Central Vein, Open */
"3E04305"  =  "1"  /* Introduction of Other Antineoplastic into Central Vein, Percutaneous Approach */
"3E0430M"  =  "1"  /* Introduction of Monoclonal Antibody into Central Vein, Percutaneous Approach */
"3E043WL"  =  "1"  /* Introduction of Immunosuppressive into Central Vein, Percutaneous */
"3E05005"  =  "1"  /* Introduction of Other Antineoplastic into Peripheral Artery, Open Approach */
"3E0500M"  =  "1"  /* Introduction of Monoclonal Antibody into Peripheral Artery, Open Approach */
"3E050WL"  =  "1"  /* Introduction of Immunosuppressive into Peripheral Artery, Open */
"3E05305"  =  "1"  /* Introduction of Other Antineoplastic into Peripheral Artery, Percutaneous Approach */
"3E0530M"  =  "1"  /* Introduction of Monoclonal Antibody into Peripheral Artery, Percutaneous Approach */
"3E053WL"  =  "1"  /* Introduction of Immunosuppressive into Peripheral Artery, Percutaneous */
"3E06005"  =  "1"  /* Introduction of Other Antineoplastic into Central Artery, Open Approach */
"3E0600M"  =  "1"  /* Introduction of Monoclonal Antibody into Central Artery, Open Approach */
"3E060WL"  =  "1"  /* Introduction of Immunosuppressive into Central Artery, Open */
"3E06305"  =  "1"  /* Introduction of Other Antineoplastic into Central Artery, Percutaneous Approach */
"3E0630M"  =  "1"  /* Introduction of Monoclonal Antibody into Central Artery, Percutaneous Approach */
"3E063WL"  =  "1"  /* Introduction of Immunosuppressive into Central Artery, Percutaneous */
"3E0J3U1"  =  "1"  /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Percutaneous Approach */
"3E0J7U1"  =  "1"  /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Via Natural or Artificial Opening */
"3E0J8U1"  =  "1"  /* Introduction of Nonautologous Pancreatic Islet Cells into Biliary and Pancreatic Tract, Via Natural or Artificial Opening Endoscopic */
OTHER  = "0" ;

 /* EXCLUDE: KIDNEY OR URINARY TRACT DISORDER */
 /* ICD-10-CM DIAGNOSIS CODES */

value $KIDNEY
"N110"  =  "1"  /* Nonobstructive reflux-associated chronic pyelonephritis */
"N111"  =  "1"  /* Chronic obstructive pyelonephritis */
"N118"  =  "1"  /* Other chronic tubulo-interstitial nephritis */
"N119"  =  "1"  /* Chronic tubulo-interstitial nephritis, unspecified */
"N1370"  =  "1"  /* Vesicoureteral-reflux, unspecified */
"N1371"  =  "1"  /* Vesicoureteral-reflux without reflux nephropathy */
"N13721"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, unilateral */
"N13722"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, bilateral */
"N13729"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy without hydroureter, unspecified */
"N13731"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, unilateral */
"N13732"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, bilateral */
"N13739"  =  "1"  /* Vesicoureteral-reflux with reflux nephropathy with hydroureter, unspecified */
"N139"  =  "1"  /* Obstructive and reflux uropathy, unspecified */
"Q600"  =  "1"  /* Renal agenesis, unilateral */
"Q601"  =  "1"  /* Renal agenesis, bilateral */
"Q602"  =  "1"  /* Renal agenesis, unspecified */
"Q603"  =  "1"  /* Renal hypoplasia, unilateral */
"Q604"  =  "1"  /* Renal hypoplasia, bilateral */
"Q605"  =  "1"  /* Renal hypoplasia, unspecified */
"Q606"  =  "1"  /* Potter's syndrome */
"Q6100"  =  "1"  /* Congenital renal cyst, unspecified */
"Q6101"  =  "1"  /* Congenital single renal cyst */
"Q6102"  =  "1"  /* Congenital multiple renal cysts */
"Q6111"  =  "1"  /* Cystic dilatation of collecting ducts */
"Q6119"  =  "1"  /* Other polycystic kidney, infantile type */
"Q612"  =  "1"  /* Polycystic kidney, adult type */
"Q613"  =  "1"  /* Polycystic kidney, unspecified */
"Q614"  =  "1"  /* Renal dysplasia */
"Q615"  =  "1"  /* Medullary cystic kidney */
"Q618"  =  "1"  /* Other cystic kidney diseases */
"Q619"  =  "1"  /* Cystic kidney disease, unspecified */
"Q620"  =  "1"  /* Congenital hydronephrosis */
"Q6210"  =  "1"  /* Congenital occlusion of ureter, unspecified */
"Q6211"  =  "1"  /* Congenital occlusion of ureteropelvic junction */
"Q6212"  =  "1"  /* Congenital occlusion of ureterovesical orifice */
"Q622"  =  "1"  /* Congenital megaureter */
"Q6231"  =  "1"  /* Congenital ureterocele, orthotopic */
"Q6232"  =  "1"  /* Cecoureterocele */
"Q6239"  =  "1"  /* Other obstructive defects of renal pelvis and ureter */
"Q624"  =  "1"  /* Agenesis of ureter */
"Q625"  =  "1"  /* Duplication of ureter */
"Q6260"  =  "1"  /* Malposition of ureter, unspecified */
"Q6261"  =  "1"  /* Deviation of ureter */
"Q6262"  =  "1"  /* Displacement of ureter */
"Q6263"  =  "1"  /* Anomalous implantation of ureter */
"Q6269"  =  "1"  /* Other malposition of ureter */
"Q627"  =  "1"  /* Congenital vesico-uretero-renal reflux */
"Q628"  =  "1"  /* Other congenital malformations of ureter */
"Q630"  =  "1"  /* Accessory kidney */
"Q631"  =  "1"  /* Lobulated, fused and horseshoe kidney */
"Q632"  =  "1"  /* Ectopic kidney */
"Q633"  =  "1"  /* Hyperplastic and giant kidney */
"Q638"  =  "1"  /* Other specified congenital malformations of kidney */
"Q639"  =  "1"  /* Congenital malformation of kidney, unspecified */
"Q6410"  =  "1"  /* Exstrophy of urinary bladder, unspecified */
"Q6411"  =  "1"  /* Supravesical fissure of urinary bladder */
"Q6412"  =  "1"  /* Cloacal extrophy of urinary bladder */
"Q6419"  =  "1"  /* Other exstrophy of urinary bladder */
"Q642"  =  "1"  /* Congenital posterior urethral valves */
"Q6431"  =  "1"  /* Congenital bladder neck obstruction */
"Q6432"  =  "1"  /* Congenital stricture of urethra */
"Q6433"  =  "1"  /* Congenital stricture of urinary meatus */
"Q6439"  =  "1"  /* Other atresia and stenosis of urethra and bladder neck */
"Q645"  =  "1"  /* Congenital absence of bladder and urethra */
"Q646"  =  "1"  /* Congenital diverticulum of bladder */
"Q6470"  =  "1"  /* Unspecified congenital malformation of bladder and urethra */
"Q6471"  =  "1"  /* Congenital prolapse of urethra */
"Q6472"  =  "1"  /* Congenital prolapse of urinary meatus */
"Q6473"  =  "1"  /* Congenital urethrorectal fistula */
"Q6474"  =  "1"  /* Double urethra */
"Q6475"  =  "1"  /* Double urinary meatus */
"Q6479"  =  "1"  /* Other congenital malformations of bladder and urethra */
"Q648"  =  "1"  /* Other specified congenital malformations of urinary system */
"Q649"  =  "1"  /* Congenital malformation of urinary system, unspecified */
OTHER   = 0;


 /* ----------------------------------- */
 /* Diabetes uncontrolled rate (ACDIAU) */
 /*   PQI   14                          */
 /* ----------------------------------- */

 /* Diabetes uncontrolled     */
 /* ICD-10-CM Diagnosis Codes: */

value $ACDIAUD
"E1065"  =  "1"  /* Type 1 diabetes mellitus with hyperglycemia */
"E1165"  =  "1"  /* Type 2 diabetes mellitus with hyperglycemia */
"E10649 "  =  "1"  /* Type 1 diabetes mellitus with hypoglycemia without coma */
"E11649"  =  "1"  /* Type 2 diabetes mellitus with hypoglycemia without coma */
OTHER   = 0 ;


 /* ----------------------------------------- */
 /* Lower extremity amputation rate (ACSCLEA) */
 /*   PQI  16                                 */
 /* ----------------------------------------- */

 /* Lower extremity amputation */
 /* ICD-10-CM Procedure Codes: */

value $ACSLEAP
"0Y620ZZ"  =  "1"  /* Detachment at Right Hindquarter, Open Approach */
"0Y630ZZ"  =  "1"  /* Detachment at Left Hindquarter, Open Approach */
"0Y640ZZ"  =  "1"  /* Detachment at Bilateral Hindquarter, Open Approach */
"0Y670ZZ"  =  "1"  /* Detachment at Right Femoral Region, Open Approach */
"0Y680ZZ"  =  "1"  /* Detachment at Left Femoral Region, Open Approach */
"0Y6C0Z1"  =  "1"  /* Detachment at Right Upper Leg, High, Open Approach */
"0Y6C0Z2"  =  "1"  /* Detachment at Right Upper Leg, Mid, Open Approach */
"0Y6C0Z3"  =  "1"  /* Detachment at Right Upper Leg, Low, Open Approach */
"0Y6D0Z1"  =  "1"  /* Detachment at Left Upper Leg, High, Open Approach */
"0Y6D0Z2"  =  "1"  /* Detachment at Left Upper Leg, Mid, Open Approach */
"0Y6D0Z3"  =  "1"  /* Detachment at Left Upper Leg, Low, Open Approach */
"0Y6F0ZZ"  =  "1"  /* Detachment at Right Knee Region, Open Approach */
"0Y6G0ZZ"  =  "1"  /* Detachment at Left Knee Region, Open Approach */
"0Y6H0Z1"  =  "1"  /* Detachment at Right Lower Leg, High, Open Approach */
"0Y6H0Z2"  =  "1"  /* Detachment at Right Lower Leg, Mid, Open Approach */
"0Y6H0Z3"  =  "1"  /* Detachment at Right Lower Leg, Low, Open Approach */
"0Y6J0Z1"  =  "1"  /* Detachment at Left Lower Leg, High, Open Approach */
"0Y6J0Z2"  =  "1"  /* Detachment at Left Lower Leg, Mid, Open Approach */
"0Y6J0Z3"  =  "1"  /* Detachment at Left Lower Leg, Low, Open Approach */
"0Y6M0Z0"  =  "1"  /* Detachment at Right Foot, Complete, Open Approach */
"0Y6M0Z4"  =  "1"  /* Detachment at Right Foot, Complete 1st Ray, Open Approach */
"0Y6M0Z5"  =  "1"  /* Detachment at Right Foot, Complete 2nd Ray, Open Approach */
"0Y6M0Z6"  =  "1"  /* Detachment at Right Foot, Complete 3rd Ray, Open Approach */
"0Y6M0Z7"  =  "1"  /* Detachment at Right Foot, Complete 4th Ray, Open Approach */
"0Y6M0Z8"  =  "1"  /* Detachment at Right Foot, Complete 5th Ray, Open Approach */
"0Y6M0Z9"  =  "1"  /* Detachment at Right Foot, Partial 1st Ray, Open Approach */
"0Y6M0ZB"  =  "1"  /* Detachment at Right Foot, Partial 2nd Ray, Open Approach */
"0Y6M0ZC"  =  "1"  /* Detachment at Right Foot, Partial 3rd Ray, Open Approach */
"0Y6M0ZD"  =  "1"  /* Detachment at Right Foot, Partial 4th Ray, Open Approach */
"0Y6M0ZF"  =  "1"  /* Detachment at Right Foot, Partial 5th Ray, Open Approach */
"0Y6N0Z0"  =  "1"  /* Detachment at Left Foot, Complete, Open Approach */
"0Y6N0Z4"  =  "1"  /* Detachment at Left Foot, Complete 1st Ray, Open Approach */
"0Y6N0Z5"  =  "1"  /* Detachment at Left Foot, Complete 2nd Ray, Open Approach */
"0Y6N0Z6"  =  "1"  /* Detachment at Left Foot, Complete 3rd Ray, Open Approach */
"0Y6N0Z7"  =  "1"  /* Detachment at Left Foot, Complete 4th Ray, Open Approach */
"0Y6N0Z8"  =  "1"  /* Detachment at Left Foot, Complete 5th Ray, Open Approach */
"0Y6N0Z9"  =  "1"  /* Detachment at Left Foot, Partial 1st Ray, Open Approach */
"0Y6N0ZB"  =  "1"  /* Detachment at Left Foot, Partial 2nd Ray, Open Approach */
"0Y6N0ZC"  =  "1"  /* Detachment at Left Foot, Partial 3rd Ray, Open Approach */
"0Y6N0ZD"  =  "1"  /* Detachment at Left Foot, Partial 4th Ray, Open Approach */
"0Y6N0ZF"  =  "1"  /* Detachment at Left Foot, Partial 5th Ray, Open Approach */
OTHER   = 0 ;

 /* Include only: Diabetes */
 /* ICD-10-CM Diagnosis Codes: */

value $ACSLEAD
"E1010"  =  "1"  /* Type 1 diabetes mellitus with ketoacidosis without coma */
"E1011"  =  "1"  /* Type 1 diabetes mellitus with ketoacidosis with coma */
"E1021"  =  "1"  /* Type 1 diabetes mellitus with diabetic nephropathy */
"E1022"  =  "1"  /* Type 1 diabetes mellitus with diabetic chronic kidney disease */
"E1029"  =  "1"  /* Type 1 diabetes mellitus with other diabetic kidney complication */
"E10311"  =  "1"  /* Type 1 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E10319"  =  "1"  /* Type 1 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E10321"  =  "1"  /* Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E10329"  =  "1"  /* Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E10331"  =  "1"  /* Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E10339"  =  "1"  /* Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E10341"  =  "1"  /* Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E10349"  =  "1"  /* Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E10351"  =  "1"  /* Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E10359"  =  "1"  /* Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E1036"  =  "1"  /* Type 1 diabetes mellitus with diabetic cataract */
"E1039"  =  "1"  /* Type 1 diabetes mellitus with other diabetic ophthalmic complication */
"E1040"  =  "1"  /* Type 1 diabetes mellitus with diabetic neuropathy, unspecified */
"E1041"  =  "1"  /* Type 1 diabetes mellitus with diabetic mononeuropathy */
"E1042"  =  "1"  /* Type 1 diabetes mellitus with diabetic polyneuropathy */
"E1043"  =  "1"  /* Type 1 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1044"  =  "1"  /* Type 1 diabetes mellitus with diabetic amyotrophy */
"E1049"  =  "1"  /* Type 1 diabetes mellitus with other diabetic neurological complication */
"E1051"  =  "1"  /* Type 1 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1052"  =  "1"  /* Type 1 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1059"  =  "1"  /* Type 1 diabetes mellitus with other circulatory complications */
"E10610"  =  "1"  /* Type 1 diabetes mellitus with diabetic neuropathic arthropathy */
"E10618"  =  "1"  /* Type 1 diabetes mellitus with other diabetic arthropathy */
"E10620"  =  "1"  /* Type 1 diabetes mellitus with diabetic dermatitis */
"E10621"  =  "1"  /* Type 1 diabetes mellitus with foot ulcer */
"E10622"  =  "1"  /* Type 1 diabetes mellitus with other skin ulcer */
"E10628"  =  "1"  /* Type 1 diabetes mellitus with other skin complications */
"E10630"  =  "1"  /* Type 1 diabetes mellitus with periodontal disease */
"E10638"  =  "1"  /* Type 1 diabetes mellitus with other oral complications */
"E10641"  =  "1"  /* Type 1 diabetes mellitus with hypoglycemia with coma */
"E10649"  =  "1"  /* Type 1 diabetes mellitus with hypoglycemia without coma */
"E1065"  =  "1"  /* Type 1 diabetes mellitus with hyperglycemia */
"E1069"  =  "1"  /* Type 1 diabetes mellitus with other specified complication */
"E108"  =  "1"  /* Type 1 diabetes mellitus with unspecified complications */
"E109"  =  "1"  /* Type 1 diabetes mellitus without complications */
"E1100"  =  "1"  /* Type 2 diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1101"  =  "1"  /* Type 2 diabetes mellitus with hyperosmolarity with coma */
"E1121"  =  "1"  /* Type 2 diabetes mellitus with diabetic nephropathy */
"E1122"  =  "1"  /* Type 2 diabetes mellitus with diabetic chronic kidney disease */
"E1129"  =  "1"  /* Type 2 diabetes mellitus with other diabetic kidney complication */
"E11311"  =  "1"  /* Type 2 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E11319"  =  "1"  /* Type 2 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E11321"  =  "1"  /* Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E11329"  =  "1"  /* Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E11331"  =  "1"  /* Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E11339"  =  "1"  /* Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E11341"  =  "1"  /* Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E11349"  =  "1"  /* Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E11351"  =  "1"  /* Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E11359"  =  "1"  /* Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E1136"  =  "1"  /* Type 2 diabetes mellitus with diabetic cataract */
"E1139"  =  "1"  /* Type 2 diabetes mellitus with other diabetic ophthalmic complication */
"E1140"  =  "1"  /* Type 2 diabetes mellitus with diabetic neuropathy, unspecified */
"E1141"  =  "1"  /* Type 2 diabetes mellitus with diabetic mononeuropathy */
"E1142"  =  "1"  /* Type 2 diabetes mellitus with diabetic polyneuropathy */
"E1143"  =  "1"  /* Type 2 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1144"  =  "1"  /* Type 2 diabetes mellitus with diabetic amyotrophy */
"E1149"  =  "1"  /* Type 2 diabetes mellitus with other diabetic neurological complication */
"E1151"  =  "1"  /* Type 2 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1152"  =  "1"  /* Type 2 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1159"  =  "1"  /* Type 2 diabetes mellitus with other circulatory complications */
"E11610"  =  "1"  /* Type 2 diabetes mellitus with diabetic neuropathic arthropathy */
"E11618"  =  "1"  /* Type 2 diabetes mellitus with other diabetic arthropathy */
"E11620"  =  "1"  /* Type 2 diabetes mellitus with diabetic dermatitis */
"E11621"  =  "1"  /* Type 2 diabetes mellitus with foot ulcer */
"E11622"  =  "1"  /* Type 2 diabetes mellitus with other skin ulcer */
"E11628"  =  "1"  /* Type 2 diabetes mellitus with other skin complications */
"E11630"  =  "1"  /* Type 2 diabetes mellitus with periodontal disease */
"E11638"  =  "1"  /* Type 2 diabetes mellitus with other oral complications */
"E11641"  =  "1"  /* Type 2 diabetes mellitus with hypoglycemia with coma */
"E11649"  =  "1"  /* Type 2 diabetes mellitus with hypoglycemia without coma */
"E1165"  =  "1"  /* Type 2 diabetes mellitus with hyperglycemia */
"E1169"  =  "1"  /* Type 2 diabetes mellitus with other specified complication */
"E118"  =  "1"  /* Type 2 diabetes mellitus with unspecified complications */
"E119"  =  "1"  /* Type 2 diabetes mellitus without complications */
"E1300"  =  "1"  /* Other specified diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1301"  =  "1"  /* Other specified diabetes mellitus with hyperosmolarity with coma */
"E1310"  =  "1"  /* Other specified diabetes mellitus with ketoacidosis without coma */
"E1311"  =  "1"  /* Other specified diabetes mellitus with ketoacidosis with coma */
"E1321"  =  "1"  /* Other specified diabetes mellitus with diabetic nephropathy */
"E1322"  =  "1"  /* Other specified diabetes mellitus with diabetic chronic kidney disease */
"E1329"  =  "1"  /* Other specified diabetes mellitus with other diabetic kidney complication */
"E13311"  =  "1"  /* Other specified diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E13319"  =  "1"  /* Other specified diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E13321"  =  "1"  /* Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E13329"  =  "1"  /* Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E13331"  =  "1"  /* Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E13339"  =  "1"  /* Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E13341"  =  "1"  /* Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E13349"  =  "1"  /* Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E13351"  =  "1"  /* Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E13359"  =  "1"  /* Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E1336"  =  "1"  /* Other specified diabetes mellitus with diabetic cataract */
"E1339"  =  "1"  /* Other specified diabetes mellitus with other diabetic ophthalmic complication */
"E1340"  =  "1"  /* Other specified diabetes mellitus with diabetic neuropathy, unspecified */
"E1341"  =  "1"  /* Other specified diabetes mellitus with diabetic mononeuropathy */
"E1342"  =  "1"  /* Other specified diabetes mellitus with diabetic polyneuropathy */
"E1343"  =  "1"  /* Other specified diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1344"  =  "1"  /* Other specified diabetes mellitus with diabetic amyotrophy */
"E1349"  =  "1"  /* Other specified diabetes mellitus with other diabetic neurological complication */
"E1351"  =  "1"  /* Other specified diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1352"  =  "1"  /* Other specified diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1359"  =  "1"  /* Other specified diabetes mellitus with other circulatory complications */
"E13610"  =  "1"  /* Other specified diabetes mellitus with diabetic neuropathic arthropathy */
"E13618"  =  "1"  /* Other specified diabetes mellitus with other diabetic arthropathy */
"E13620"  =  "1"  /* Other specified diabetes mellitus with diabetic dermatitis */
"E13621"  =  "1"  /* Other specified diabetes mellitus with foot ulcer */
"E13622"  =  "1"  /* Other specified diabetes mellitus with other skin ulcer */
"E13628"  =  "1"  /* Other specified diabetes mellitus with other skin complications */
"E13630"  =  "1"  /* Other specified diabetes mellitus with periodontal disease */
"E13638"  =  "1"  /* Other specified diabetes mellitus with other oral complications */
"E13641"  =  "1"  /* Other specified diabetes mellitus with hypoglycemia with coma */
"E13649"  =  "1"  /* Other specified diabetes mellitus with hypoglycemia without coma */
"E1365"  =  "1"  /* Other specified diabetes mellitus with hyperglycemia */
"E1369"  =  "1"  /* Other specified diabetes mellitus with other specified complication */
"E138"  =  "1"  /* Other specified diabetes mellitus with unspecified complications */
"E139"  =  "1"  /* Other specified diabetes mellitus without complications */
OTHER   = 0 ;

 /* Exclude: Trauma */
 /* ICD-10-CM Diagnosis Codes: */

value $ACLEA2D
"S78011A"  =  "1"  /* Complete traumatic amputation at right hip joint, initial encounter */
"S78012A"  =  "1"  /* Complete traumatic amputation at left hip joint, initial encounter */
"S78019A"  =  "1"  /* Complete traumatic amputation at unspecified hip joint, initial encounter */
"S78021A"  =  "1"  /* Partial traumatic amputation at right hip joint, initial encounter */
"S78022A"  =  "1"  /* Partial traumatic amputation at left hip joint, initial encounter */
"S78029A"  =  "1"  /* Partial traumatic amputation at unspecified hip joint, initial encounter */
"S78111A"  =  "1"  /* Complete traumatic amputation at level between right hip and knee, initial encounter */
"S78112A"  =  "1"  /* Complete traumatic amputation at level between left hip and knee, initial encounter */
"S78119A"  =  "1"  /* Complete traumatic amputation at level between unspecified hip and knee, initial encounter */
"S78121A"  =  "1"  /* Partial traumatic amputation at level between right hip and knee, initial encounter */
"S78122A"  =  "1"  /* Partial traumatic amputation at level between left hip and knee, initial encounter */
"S78129A"  =  "1"  /* Partial traumatic amputation at level between unspecified hip and knee, initial encounter */
"S78911A"  =  "1"  /* Complete traumatic amputation of right hip and thigh, level unspecified, initial encounter */
"S78912A"  =  "1"  /* Complete traumatic amputation of left hip and thigh, level unspecified, initial encounter */
"S78919A"  =  "1"  /* Complete traumatic amputation of unspecified hip and thigh, level unspecified, initial encounter */
"S78921A"  =  "1"  /* Partial traumatic amputation of right hip and thigh, level unspecified, initial encounter */
"S78922A"  =  "1"  /* Partial traumatic amputation of left hip and thigh, level unspecified, initial encounter */
"S78929A"  =  "1"  /* Partial traumatic amputation of unspecified hip and thigh, level unspecified, initial encounter */
"S88011A"  =  "1"  /* Complete traumatic amputation at knee level, right lower leg, initial encounter */
"S88012A"  =  "1"  /* Complete traumatic amputation at knee level, left lower leg, initial encounter */
"S88019A"  =  "1"  /* Complete traumatic amputation at knee level, unspecified lower leg, initial encounter */
"S88021A"  =  "1"  /* Partial traumatic amputation at knee level, right lower leg, initial encounter */
"S88022A"  =  "1"  /* Partial traumatic amputation at knee level, left lower leg, initial encounter */
"S88029A"  =  "1"  /* Partial traumatic amputation at knee level, unspecified lower leg, initial encounter */
"S88111A"  =  "1"  /* Complete traumatic amputation at level between knee and ankle, right lower leg, initial encounter */
"S88112A"  =  "1"  /* Complete traumatic amputation at level between knee and ankle, left lower leg, initial encounter */
"S88119A"  =  "1"  /* Complete traumatic amputation at level between knee and ankle, unspecified lower leg, initial encounter */
"S88121A"  =  "1"  /* Partial traumatic amputation at level between knee and ankle, right lower leg, initial encounter */
"S88122A"  =  "1"  /* Partial traumatic amputation at level between knee and ankle, left lower leg, initial encounter */
"S88129A"  =  "1"  /* Partial traumatic amputation at level between knee and ankle, unspecified lower leg, initial encounter */
"S88911A"  =  "1"  /* Complete traumatic amputation of right lower leg, level unspecified, initial encounter */
"S88912A"  =  "1"  /* Complete traumatic amputation of left lower leg, level unspecified, initial encounter */
"S88919A"  =  "1"  /* Complete traumatic amputation of unspecified lower leg, level unspecified, initial encounter */
"S88921A"  =  "1"  /* Partial traumatic amputation of right lower leg, level unspecified, initial encounter */
"S88922A"  =  "1"  /* Partial traumatic amputation of left lower leg, level unspecified, initial encounter */
"S88929A"  =  "1"  /* Partial traumatic amputation of unspecified lower leg, level unspecified, initial encounter */
"S98011A"  =  "1"  /* Complete traumatic amputation of right foot at ankle level, initial encounter */
"S98012A"  =  "1"  /* Complete traumatic amputation of left foot at ankle level, initial encounter */
"S98019A"  =  "1"  /* Complete traumatic amputation of unspecified foot at ankle level, initial encounter */
"S98021A"  =  "1"  /* Partial traumatic amputation of right foot at ankle level, initial encounter */
"S98022A"  =  "1"  /* Partial traumatic amputation of left foot at ankle level, initial encounter */
"S98029A"  =  "1"  /* Partial traumatic amputation of unspecified foot at ankle level, initial encounter */
"S98111A"  =  "1"  /* Complete traumatic amputation of right great toe, initial encounter */
"S98112A"  =  "1"  /* Complete traumatic amputation of left great toe, initial encounter */
"S98119A"  =  "1"  /* Complete traumatic amputation of unspecified great toe, initial encounter */
"S98121A"  =  "1"  /* Partial traumatic amputation of right great toe, initial encounter */
"S98122A"  =  "1"  /* Partial traumatic amputation of left great toe, initial encounter */
"S98129A"  =  "1"  /* Partial traumatic amputation of unspecified great toe, initial encounter */
"S98131A"  =  "1"  /* Complete traumatic amputation of one right lesser toe, initial encounter */
"S98132A"  =  "1"  /* Complete traumatic amputation of one left lesser toe, initial encounter */
"S98139A"  =  "1"  /* Complete traumatic amputation of one unspecified lesser toe, initial encounter */
"S98141A"  =  "1"  /* Partial traumatic amputation of one right lesser toe, initial encounter */
"S98142A"  =  "1"  /* Partial traumatic amputation of one left lesser toe, initial encounter */
"S98149A"  =  "1"  /* Partial traumatic amputation of one unspecified lesser toe, initial encounter */
"S98211A"  =  "1"  /* Complete traumatic amputation of two or more right lesser toes, initial encounter */
"S98212A"  =  "1"  /* Complete traumatic amputation of two or more left lesser toes, initial encounter */
"S98219A"  =  "1"  /* Complete traumatic amputation of two or more unspecified lesser toes, initial encounter */
"S98221A"  =  "1"  /* Partial traumatic amputation of two or more right lesser toes, initial encounter */
"S98222A"  =  "1"  /* Partial traumatic amputation of two or more left lesser toes, initial encounter */
"S98229A"  =  "1"  /* Partial traumatic amputation of two or more unspecified lesser toes, initial encounter */
"S98311A"  =  "1"  /* Complete traumatic amputation of right midfoot, initial encounter */
"S98312A"  =  "1"  /* Complete traumatic amputation of left midfoot, initial encounter */
"S98319A"  =  "1"  /* Complete traumatic amputation of unspecified midfoot, initial encounter */
"S98321A"  =  "1"  /* Partial traumatic amputation of right midfoot, initial encounter */
"S98322A"  =  "1"  /* Partial traumatic amputation of left midfoot, initial encounter */
"S98329A"  =  "1"  /* Partial traumatic amputation of unspecified midfoot, initial encounter */
"S98911A"  =  "1"  /* Complete traumatic amputation of right foot, level unspecified, initial encounter */
"S98912A"  =  "1"  /* Complete traumatic amputation of left foot, level unspecified, initial encounter */
"S98919A"  =  "1"  /* Complete traumatic amputation of unspecified foot, level unspecified, initial encounter */
"S98921A"  =  "1"  /* Partial traumatic amputation of right foot, level unspecified, initial encounter */
"S98922A"  =  "1"  /* Partial traumatic amputation of left foot, level unspecified, initial encounter */
"S98929A"  =  "1"  /* Partial traumatic amputation of unspecified foot, level unspecified, initial encounter */
OTHER   = 0 ;


 * ----------------------------------------------------- ;
 * --- DRG FORMATS  ------------------------------------ ;
 * ----------------------------------------------------- ;

 /* MS-DRG (V33) TO MDC */;

value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77   
015 = 77  
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER  = 99 ;


 * ----------------------------------------------------- ;
 * --- AREA FORMATS ------------------------------------ ;
 * ---   Translates FIPS State and County Code (SSCCC)   ;
 * ---   to MSA (Metropolitan Statistical Area)          ;
 * ----------------------------------------------------- ;

/* MODIFIED FIPS */

value $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;

/* OMB 1999 METRO AREA */

value $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* OMB 2003 METRO AREA */

value $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;


 /* -------------------------------------------------------------- */
 /* --- FORMATS FOR AGE STRATIFIERS                            --- */
 /* -------------------------------------------------------------- */

Value AGEFMT
low - 4 =  1
 5 -  9 =  2
10 - 14 =  3
15 - 17 =  4
18 - 24 =  5
25 - 29 =  6
30 - 34 =  7
35 - 39 =  8
40 - 44 =  9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18;

/*MAREA TO POVERTY DECILE CATEGORY */

value $POVCAT
"01001" = 3
"01003" = 4
"01005" = 10
"01007" = 9
"01009" = 6
"01011" = 10
"01013" = 10
"01015" = 10
"01017" = 10
"01019" = 9
"01021" = 9
"01023" = 9
"01025" = 10
"01027" = 9
"01029" = 8
"01031" = 9
"01033" = 9
"01035" = 10
"01037" = 8
"01039" = 9
"01041" = 9
"01043" = 9
"01045" = 8
"01047" = 10
"01049" = 9
"01051" = 4
"01053" = 10
"01055" = 8
"01057" = 10
"01059" = 9
"01061" = 9
"01063" = 10
"01065" = 10
"01067" = 8
"01069" = 8
"01071" = 9
"01073" = 8
"01075" = 9
"01077" = 7
"01079" = 8
"01081" = 9
"01083" = 4
"01085" = 10
"01087" = 10
"01089" = 4
"01091" = 10
"01093" = 9
"01095" = 9
"01097" = 9
"01099" = 10
"01101" = 9
"01103" = 4
"01105" = 10
"01107" = 10
"01109" = 10
"01111" = 10
"01113" = 10
"01115" = 4
"01117" = 2
"01119" = 10
"01121" = 10
"01123" = 8
"01125" = 8
"01127" = 10
"01129" = 9
"01131" = 10
"01133" = 9
"02013" = 7
"02016" = 2
"02020" = 2
"02050" = 10
"02060" = 2
"02068" = 1
"02070" = 9
"02090" = 2
"02100" = 3
"02105" = 9
"02110" = 1
"02122" = 2
"02130" = 2
"02150" = 2
"02164" = 8
"02170" = 3
"02180" = 10
"02185" = 3
"02188" = 9
"02195" = 2
"02198" = 7
"02220" = 2
"02230" = 1
"02240" = 4
"02261" = 2
"02270" = 10
"02275" = 4
"02282" = 5
"02290" = 10
"04001" = 10
"04003" = 8
"04005" = 10
"04007" = 9
"04009" = 9
"04011" = 4
"04012" = 10
"04013" = 6
"04015" = 8
"04017" = 10
"04019" = 8
"04021" = 5
"04023" = 10
"04025" = 8
"04027" = 9
"05001" = 8
"05003" = 9
"05005" = 6
"05007" = 2
"05009" = 6
"05011" = 10
"05013" = 6
"05015" = 6
"05017" = 10
"05019" = 10
"05021" = 8
"05023" = 8
"05025" = 6
"05027" = 10
"05029" = 8
"05031" = 9
"05033" = 6
"05035" = 10
"05037" = 9
"05039" = 9
"05041" = 10
"05043" = 9
"05045" = 5
"05047" = 7
"05049" = 8
"05051" = 9
"05053" = 3
"05055" = 7
"05057" = 10
"05059" = 5
"05061" = 9
"05063" = 8
"05065" = 8
"05067" = 10
"05069" = 10
"05071" = 10
"05073" = 10
"05075" = 10
"05077" = 10
"05079" = 10
"05081" = 8
"05083" = 7
"05085" = 4
"05087" = 9
"05089" = 9
"05091" = 9
"05093" = 10
"05095" = 10
"05097" = 10
"05099" = 10
"05101" = 10
"05103" = 9
"05105" = 7
"05107" = 10
"05109" = 9
"05111" = 10
"05113" = 10
"05115" = 8
"05117" = 8
"05119" = 7
"05121" = 9
"05123" = 10
"05125" = 2
"05127" = 10
"05129" = 10
"05131" = 9
"05133" = 10
"05135" = 10
"05137" = 10
"05139" = 9
"05141" = 9
"05143" = 9
"05145" = 6
"05147" = 10
"05149" = 9
"06001" = 4
"06003" = 7
"06005" = 4
"06007" = 9
"06009" = 3
"06011" = 5
"06013" = 2
"06015" = 10
"06017" = 2
"06019" = 10
"06021" = 7
"06023" = 8
"06025" = 10
"06027" = 4
"06029" = 9
"06031" = 10
"06033" = 9
"06035" = 7
"06037" = 7
"06039" = 9
"06041" = 2
"06043" = 5
"06045" = 9
"06047" = 10
"06049" = 10
"06051" = 3
"06053" = 7
"06055" = 2
"06057" = 3
"06059" = 3
"06061" = 2
"06063" = 5
"06065" = 6
"06067" = 6
"06069" = 4
"06071" = 8
"06073" = 5
"06075" = 4
"06077" = 8
"06079" = 5
"06081" = 1
"06083" = 8
"06085" = 2
"06087" = 5
"06089" = 8
"06091" = 4
"06093" = 9
"06095" = 3
"06097" = 4
"06099" = 9
"06101" = 7
"06103" = 9
"06105" = 8
"06107" = 10
"06109" = 5
"06111" = 3
"06113" = 6
"06115" = 9
"08001" = 4
"08003" = 9
"08005" = 3
"08007" = 4
"08009" = 7
"08011" = 10
"08013" = 4
"08014" = 1
"08015" = 4
"08017" = 3
"08019" = 2
"08021" = 9
"08023" = 10
"08025" = 10
"08027" = 5
"08029" = 6
"08031" = 9
"08033" = 4
"08035" = 1
"08037" = 2
"08039" = 1
"08041" = 4
"08043" = 6
"08045" = 2
"08047" = 1
"08049" = 2
"08051" = 5
"08053" = 2
"08055" = 10
"08057" = 5
"08059" = 2
"08061" = 4
"08063" = 4
"08065" = 5
"08067" = 3
"08069" = 4
"08071" = 8
"08073" = 8
"08075" = 6
"08077" = 5
"08079" = 3
"08081" = 2
"08083" = 7
"08085" = 5
"08087" = 5
"08089" = 9
"08091" = 2
"08093" = 2
"08095" = 3
"08097" = 1
"08099" = 10
"08101" = 9
"08103" = 2
"08105" = 7
"08107" = 1
"08109" = 10
"08111" = 6
"08113" = 2
"08115" = 4
"08117" = 2
"08119" = 2
"08121" = 4
"08123" = 5
"08125" = 4
"09001" = 2
"09003" = 3
"09005" = 1
"09007" = 1
"09009" = 3
"09011" = 2
"09013" = 1
"09015" = 3
"10001" = 3
"10003" = 3
"10005" = 4
"11001" = 8
"12001" = 10
"12003" = 7
"12005" = 5
"12007" = 9
"12009" = 4
"12011" = 5
"12013" = 10
"12015" = 4
"12017" = 7
"12019" = 3
"12021" = 6
"12023" = 9
"12027" = 10
"12029" = 10
"12031" = 6
"12033" = 9
"12035" = 6
"12037" = 10
"12039" = 10
"12041" = 9
"12043" = 9
"12045" = 9
"12047" = 10
"12049" = 10
"12051" = 10
"12053" = 5
"12055" = 9
"12057" = 6
"12059" = 10
"12061" = 5
"12063" = 8
"12065" = 8
"12067" = 10
"12069" = 4
"12071" = 7
"12073" = 10
"12075" = 10
"12077" = 10
"12079" = 10
"12081" = 5
"12083" = 9
"12085" = 3
"12086" = 9
"12087" = 4
"12089" = 3
"12091" = 4
"12093" = 10
"12095" = 6
"12097" = 6
"12099" = 5
"12101" = 5
"12103" = 5
"12105" = 7
"12107" = 10
"12109" = 3
"12111" = 7
"12113" = 4
"12115" = 4
"12117" = 3
"12119" = 4
"12121" = 9
"12123" = 9
"12125" = 10
"12127" = 6
"12129" = 4
"12131" = 6
"12133" = 9
"13001" = 10
"13003" = 10
"13005" = 10
"13007" = 10
"13009" = 10
"13011" = 6
"13013" = 3
"13015" = 5
"13017" = 10
"13019" = 9
"13021" = 10
"13023" = 9
"13025" = 10
"13027" = 10
"13029" = 3
"13031" = 10
"13033" = 10
"13035" = 6
"13037" = 10
"13039" = 6
"13043" = 10
"13045" = 8
"13047" = 5
"13049" = 10
"13051" = 9
"13053" = 8
"13055" = 9
"13057" = 2
"13059" = 10
"13061" = 10
"13063" = 10
"13065" = 10
"13067" = 4
"13069" = 10
"13071" = 10
"13073" = 2
"13075" = 10
"13077" = 3
"13079" = 8
"13081" = 10
"13083" = 6
"13085" = 4
"13087" = 10
"13089" = 9
"13091" = 10
"13093" = 10
"13095" = 10
"13097" = 4
"13099" = 10
"13101" = 10
"13103" = 2
"13105" = 10
"13107" = 10
"13109" = 10
"13111" = 8
"13113" = 1
"13115" = 9
"13117" = 1
"13119" = 8
"13121" = 8
"13123" = 6
"13125" = 8
"13127" = 8
"13129" = 8
"13131" = 10
"13133" = 10
"13135" = 4
"13137" = 7
"13139" = 8
"13141" = 10
"13143" = 9
"13145" = 2
"13147" = 10
"13149" = 9
"13151" = 2
"13153" = 4
"13155" = 10
"13157" = 6
"13159" = 8
"13161" = 10
"13163" = 10
"13165" = 10
"13167" = 10
"13169" = 3
"13171" = 8
"13173" = 10
"13175" = 9
"13177" = 2
"13179" = 10
"13181" = 9
"13183" = 9
"13185" = 10
"13187" = 6
"13189" = 9
"13191" = 8
"13193" = 10
"13195" = 7
"13197" = 10
"13199" = 9
"13201" = 10
"13205" = 10
"13207" = 5
"13209" = 10
"13211" = 6
"13213" = 9
"13215" = 9
"13217" = 5
"13219" = 1
"13221" = 6
"13223" = 2
"13225" = 10
"13227" = 4
"13229" = 8
"13231" = 4
"13233" = 10
"13235" = 9
"13237" = 8
"13239" = 10
"13241" = 8
"13243" = 10
"13245" = 10
"13247" = 5
"13249" = 7
"13251" = 10
"13253" = 10
"13255" = 10
"13257" = 10
"13259" = 10
"13261" = 10
"13263" = 9
"13265" = 10
"13267" = 10
"13269" = 10
"13271" = 10
"13273" = 10
"13275" = 10
"13277" = 10
"13279" = 10
"13281" = 5
"13283" = 10
"13285" = 9
"13287" = 10
"13289" = 10
"13291" = 9
"13293" = 9
"13295" = 8
"13297" = 5
"13299" = 10
"13301" = 10
"13303" = 10
"13305" = 10
"13307" = 10
"13309" = 10
"13311" = 7
"13313" = 9
"13315" = 10
"13317" = 10
"13319" = 9
"13321" = 9
"15001" = 8
"15003" = 2
"15005" = 1
"15007" = 3
"15009" = 3
"16001" = 4
"16003" = 6
"16005" = 6
"16007" = 6
"16009" = 7
"16011" = 6
"16013" = 2
"16015" = 5
"16017" = 7
"16019" = 4
"16021" = 7
"16023" = 6
"16025" = 3
"16027" = 9
"16029" = 3
"16031" = 6
"16033" = 8
"16035" = 5
"16037" = 5
"16039" = 6
"16041" = 2
"16043" = 6
"16045" = 7
"16047" = 6
"16049" = 8
"16051" = 3
"16053" = 9
"16055" = 5
"16057" = 7
"16059" = 9
"16061" = 8
"16063" = 4
"16065" = 10
"16067" = 6
"16069" = 4
"16071" = 4
"16073" = 10
"16075" = 7
"16077" = 6
"16079" = 9
"16081" = 3
"16083" = 6
"16085" = 4
"16087" = 7
"17001" = 4
"17003" = 10
"17005" = 4
"17007" = 3
"17009" = 5
"17011" = 3
"17013" = 3
"17015" = 4
"17017" = 4
"17019" = 9
"17021" = 5
"17023" = 3
"17025" = 5
"17027" = 2
"17029" = 8
"17031" = 7
"17033" = 5
"17035" = 3
"17037" = 5
"17039" = 3
"17041" = 3
"17043" = 1
"17045" = 5
"17047" = 3
"17049" = 2
"17051" = 6
"17053" = 3
"17055" = 9
"17057" = 5
"17059" = 8
"17061" = 5
"17063" = 1
"17065" = 5
"17067" = 4
"17069" = 9
"17071" = 3
"17073" = 3
"17075" = 3
"17077" = 10
"17079" = 3
"17081" = 7
"17083" = 2
"17085" = 2
"17087" = 5
"17089" = 3
"17091" = 5
"17093" = 1
"17095" = 6
"17097" = 2
"17099" = 4
"17101" = 7
"17103" = 3
"17105" = 3
"17107" = 3
"17109" = 10
"17111" = 1
"17113" = 3
"17115" = 8
"17117" = 4
"17119" = 5
"17121" = 6
"17123" = 3
"17125" = 5
"17127" = 6
"17129" = 2
"17131" = 3
"17133" = 1
"17135" = 5
"17137" = 5
"17139" = 2
"17141" = 3
"17143" = 5
"17145" = 7
"17147" = 1
"17149" = 7
"17151" = 8
"17153" = 9
"17155" = 1
"17157" = 4
"17159" = 5
"17161" = 4
"17163" = 6
"17165" = 9
"17167" = 4
"17169" = 3
"17171" = 2
"17173" = 3
"17175" = 2
"17177" = 4
"17179" = 2
"17181" = 8
"17183" = 9
"17185" = 5
"17187" = 4
"17189" = 1
"17191" = 5
"17193" = 7
"17195" = 3
"17197" = 2
"17199" = 6
"17201" = 7
"17203" = 1
"18001" = 7
"18003" = 4
"18005" = 4
"18007" = 3
"18009" = 6
"18011" = 1
"18013" = 4
"18015" = 2
"18017" = 6
"18019" = 4
"18021" = 4
"18023" = 4
"18025" = 7
"18027" = 5
"18029" = 2
"18031" = 4
"18033" = 2
"18035" = 10
"18037" = 2
"18039" = 7
"18041" = 7
"18043" = 4
"18045" = 4
"18047" = 3
"18049" = 4
"18051" = 3
"18053" = 9
"18055" = 4
"18057" = 1
"18059" = 2
"18061" = 3
"18063" = 1
"18065" = 6
"18067" = 6
"18069" = 3
"18071" = 4
"18073" = 2
"18075" = 6
"18077" = 6
"18079" = 5
"18081" = 2
"18083" = 7
"18085" = 4
"18087" = 6
"18089" = 8
"18091" = 6
"18093" = 5
"18095" = 8
"18097" = 9
"18099" = 4
"18101" = 4
"18103" = 7
"18105" = 10
"18107" = 5
"18109" = 3
"18111" = 3
"18113" = 4
"18115" = 2
"18117" = 7
"18119" = 4
"18121" = 6
"18123" = 4
"18125" = 5
"18127" = 3
"18129" = 2
"18131" = 5
"18133" = 4
"18135" = 6
"18137" = 2
"18139" = 4
"18141" = 6
"18143" = 8
"18145" = 4
"18147" = 3
"18149" = 8
"18151" = 4
"18153" = 5
"18155" = 6
"18157" = 9
"18159" = 2
"18161" = 4
"18163" = 7
"18165" = 4
"18167" = 9
"18169" = 3
"18171" = 2
"18173" = 1
"18175" = 6
"18177" = 9
"18179" = 2
"18181" = 3
"18183" = 2
"19001" = 2
"19003" = 4
"19005" = 4
"19007" = 6
"19009" = 2
"19011" = 2
"19013" = 8
"19015" = 2
"19017" = 1
"19019" = 3
"19021" = 4
"19023" = 2
"19025" = 3
"19027" = 2
"19029" = 4
"19031" = 1
"19033" = 4
"19035" = 2
"19037" = 2
"19039" = 4
"19041" = 3
"19043" = 3
"19045" = 4
"19047" = 4
"19049" = 1
"19051" = 7
"19053" = 9
"19055" = 2
"19057" = 5
"19059" = 2
"19061" = 2
"19063" = 4
"19065" = 4
"19067" = 5
"19069" = 3
"19071" = 3
"19073" = 3
"19075" = 1
"19077" = 2
"19079" = 3
"19081" = 2
"19083" = 3
"19085" = 2
"19087" = 5
"19089" = 4
"19091" = 2
"19093" = 4
"19095" = 1
"19097" = 4
"19099" = 4
"19101" = 5
"19103" = 7
"19105" = 3
"19107" = 4
"19109" = 2
"19111" = 6
"19113" = 2
"19115" = 3
"19117" = 7
"19119" = 2
"19121" = 2
"19123" = 6
"19125" = 2
"19127" = 4
"19129" = 2
"19131" = 3
"19133" = 3
"19135" = 4
"19137" = 5
"19139" = 4
"19141" = 3
"19143" = 2
"19145" = 5
"19147" = 3
"19149" = 1
"19151" = 3
"19153" = 3
"19155" = 5
"19157" = 3
"19159" = 8
"19161" = 2
"19163" = 5
"19165" = 2
"19167" = 1
"19169" = 8
"19171" = 3
"19173" = 4
"19175" = 5
"19177" = 6
"19179" = 7
"19181" = 1
"19183" = 2
"19185" = 7
"19187" = 6
"19189" = 2
"19191" = 2
"19193" = 5
"19195" = 3
"19197" = 3
"20001" = 8
"20003" = 5
"20005" = 6
"20007" = 4
"20009" = 4
"20011" = 6
"20013" = 8
"20015" = 2
"20017" = 4
"20019" = 6
"20021" = 9
"20023" = 4
"20025" = 3
"20027" = 3
"20029" = 6
"20031" = 2
"20033" = 2
"20035" = 7
"20037" = 9
"20039" = 4
"20041" = 3
"20043" = 4
"20045" = 6
"20047" = 3
"20049" = 8
"20051" = 4
"20053" = 3
"20055" = 5
"20057" = 4
"20059" = 3
"20061" = 3
"20063" = 3
"20065" = 4
"20067" = 3
"20069" = 1
"20071" = 2
"20073" = 7
"20075" = 4
"20077" = 5
"20079" = 2
"20081" = 3
"20083" = 2
"20085" = 3
"20087" = 2
"20089" = 4
"20091" = 1
"20093" = 3
"20095" = 4
"20097" = 4
"20099" = 7
"20101" = 2
"20103" = 2
"20105" = 4
"20107" = 5
"20109" = 2
"20111" = 9
"20113" = 2
"20115" = 3
"20117" = 3
"20119" = 2
"20121" = 2
"20123" = 2
"20125" = 8
"20127" = 3
"20129" = 3
"20131" = 2
"20133" = 6
"20135" = 2
"20137" = 4
"20139" = 3
"20141" = 5
"20143" = 2
"20145" = 4
"20147" = 3
"20149" = 2
"20151" = 3
"20153" = 4
"20155" = 5
"20157" = 3
"20159" = 4
"20161" = 9
"20163" = 5
"20165" = 4
"20167" = 6
"20169" = 7
"20171" = 2
"20173" = 5
"20175" = 6
"20177" = 7
"20179" = 4
"20181" = 7
"20183" = 4
"20185" = 4
"20187" = 3
"20189" = 3
"20191" = 3
"20193" = 2
"20195" = 3
"20197" = 2
"20199" = 4
"20201" = 2
"20203" = 4
"20205" = 6
"20207" = 7
"20209" = 10
"21001" = 10
"21003" = 10
"21005" = 4
"21007" = 5
"21009" = 9
"21011" = 10
"21013" = 10
"21015" = 2
"21017" = 7
"21019" = 9
"21021" = 6
"21023" = 6
"21025" = 10
"21027" = 9
"21029" = 2
"21031" = 9
"21033" = 8
"21035" = 7
"21037" = 4
"21039" = 5
"21041" = 10
"21043" = 10
"21045" = 10
"21047" = 9
"21049" = 7
"21051" = 10
"21053" = 10
"21055" = 9
"21057" = 10
"21059" = 6
"21061" = 8
"21063" = 10
"21065" = 10
"21067" = 9
"21069" = 8
"21071" = 10
"21073" = 6
"21075" = 10
"21077" = 6
"21079" = 7
"21081" = 8
"21083" = 9
"21085" = 9
"21087" = 9
"21089" = 7
"21091" = 5
"21093" = 5
"21095" = 10
"21097" = 6
"21099" = 10
"21101" = 6
"21103" = 7
"21105" = 8
"21107" = 9
"21109" = 10
"21111" = 7
"21113" = 6
"21115" = 10
"21117" = 4
"21119" = 10
"21121" = 10
"21123" = 9
"21125" = 10
"21127" = 9
"21129" = 10
"21131" = 10
"21133" = 10
"21135" = 10
"21137" = 10
"21139" = 5
"21141" = 8
"21143" = 5
"21145" = 6
"21147" = 10
"21149" = 6
"21151" = 9
"21153" = 10
"21155" = 8
"21157" = 3
"21159" = 10
"21161" = 9
"21163" = 5
"21165" = 10
"21167" = 5
"21169" = 9
"21171" = 10
"21173" = 9
"21175" = 10
"21177" = 9
"21179" = 6
"21181" = 8
"21183" = 9
"21185" = 1
"21187" = 6
"21189" = 10
"21191" = 5
"21193" = 10
"21195" = 10
"21197" = 10
"21199" = 9
"21201" = 10
"21203" = 10
"21205" = 10
"21207" = 10
"21209" = 3
"21211" = 3
"21213" = 6
"21215" = 2
"21217" = 10
"21219" = 10
"21221" = 5
"21223" = 5
"21225" = 9
"21227" = 9
"21229" = 6
"21231" = 10
"21233" = 5
"21235" = 10
"21237" = 10
"21239" = 3
"22001" = 9
"22003" = 9
"22005" = 4
"22007" = 6
"22009" = 9
"22011" = 6
"22013" = 10
"22015" = 4
"22017" = 9
"22019" = 7
"22021" = 9
"22023" = 4
"22025" = 10
"22027" = 10
"22029" = 10
"22031" = 9
"22033" = 7
"22035" = 10
"22037" = 8
"22039" = 10
"22041" = 10
"22043" = 9
"22045" = 10
"22047" = 10
"22049" = 9
"22051" = 6
"22053" = 9
"22055" = 8
"22057" = 4
"22059" = 5
"22061" = 10
"22063" = 4
"22065" = 10
"22067" = 10
"22069" = 10
"22071" = 10
"22073" = 9
"22075" = 5
"22077" = 7
"22079" = 9
"22081" = 10
"22083" = 10
"22085" = 10
"22087" = 8
"22089" = 4
"22091" = 10
"22093" = 6
"22095" = 8
"22097" = 10
"22099" = 10
"22101" = 9
"22103" = 2
"22105" = 9
"22107" = 10
"22109" = 8
"22111" = 9
"22113" = 7
"22115" = 4
"22117" = 10
"22119" = 10
"22121" = 5
"22123" = 10
"22125" = 9
"22127" = 10
"23001" = 5
"23003" = 4
"23005" = 2
"23007" = 6
"23009" = 4
"23011" = 3
"23013" = 4
"23015" = 4
"23017" = 5
"23019" = 6
"23021" = 6
"23023" = 2
"23025" = 8
"23027" = 6
"23029" = 9
"23031" = 2
"24001" = 7
"24003" = 1
"24005" = 1
"24009" = 1
"24011" = 4
"24013" = 1
"24015" = 2
"24017" = 1
"24019" = 6
"24021" = 1
"24023" = 5
"24025" = 1
"24027" = 1
"24029" = 5
"24031" = 1
"24033" = 2
"24035" = 1
"24037" = 1
"24039" = 9
"24041" = 2
"24043" = 3
"24045" = 6
"24047" = 2
"24510" = 10
"25001" = 3
"25003" = 4
"25005" = 4
"25007" = 2
"25009" = 2
"25011" = 3
"25013" = 7
"25015" = 4
"25017" = 1
"25019" = 1
"25021" = 1
"25023" = 2
"25025" = 10
"25027" = 3
"26001" = 6
"26003" = 5
"26005" = 5
"26007" = 7
"26009" = 5
"26011" = 8
"26013" = 4
"26015" = 3
"26017" = 6
"26019" = 4
"26021" = 7
"26023" = 9
"26025" = 7
"26027" = 6
"26029" = 4
"26031" = 7
"26033" = 9
"26035" = 10
"26037" = 2
"26039" = 6
"26041" = 5
"26043" = 4
"26045" = 3
"26047" = 3
"26049" = 9
"26051" = 9
"26053" = 9
"26055" = 3
"26057" = 8
"26059" = 7
"26061" = 9
"26063" = 6
"26065" = 9
"26067" = 6
"26069" = 9
"26071" = 5
"26073" = 10
"26075" = 9
"26077" = 9
"26079" = 8
"26081" = 6
"26083" = 4
"26085" = 10
"26087" = 4
"26089" = 2
"26091" = 5
"26093" = 1
"26095" = 9
"26097" = 5
"26099" = 4
"26101" = 7
"26103" = 5
"26105" = 6
"26107" = 10
"26109" = 4
"26111" = 3
"26113" = 6
"26115" = 3
"26117" = 9
"26119" = 9
"26121" = 9
"26123" = 9
"26125" = 2
"26127" = 10
"26129" = 9
"26131" = 6
"26133" = 9
"26135" = 9
"26137" = 4
"26139" = 3
"26141" = 5
"26143" = 10
"26145" = 8
"26147" = 6
"26149" = 6
"26151" = 7
"26153" = 6
"26155" = 5
"26157" = 6
"26159" = 6
"26161" = 4
"26163" = 10
"26165" = 7
"27001" = 4
"27003" = 1
"27005" = 5
"27007" = 9
"27009" = 2
"27011" = 3
"27013" = 7
"27015" = 2
"27017" = 3
"27019" = 1
"27021" = 6
"27023" = 2
"27025" = 1
"27027" = 4
"27029" = 6
"27031" = 2
"27033" = 3
"27035" = 3
"27037" = 1
"27039" = 1
"27041" = 2
"27043" = 3
"27045" = 4
"27047" = 3
"27049" = 2
"27051" = 3
"27053" = 4
"27055" = 2
"27057" = 4
"27059" = 2
"27061" = 3
"27063" = 2
"27065" = 4
"27067" = 5
"27069" = 2
"27071" = 5
"27073" = 2
"27075" = 3
"27077" = 3
"27079" = 2
"27081" = 2
"27083" = 3
"27085" = 2
"27087" = 10
"27089" = 1
"27091" = 3
"27093" = 2
"27095" = 4
"27097" = 4
"27099" = 3
"27101" = 2
"27103" = 2
"27105" = 4
"27107" = 3
"27109" = 2
"27111" = 4
"27113" = 3
"27115" = 5
"27117" = 2
"27119" = 3
"27121" = 2
"27123" = 7
"27125" = 3
"27127" = 2
"27129" = 3
"27131" = 2
"27133" = 3
"27135" = 2
"27137" = 7
"27139" = 1
"27141" = 1
"27143" = 2
"27145" = 3
"27147" = 2
"27149" = 3
"27151" = 2
"27153" = 7
"27155" = 4
"27157" = 1
"27159" = 7
"27161" = 2
"27163" = 1
"27165" = 3
"27167" = 2
"27169" = 6
"27171" = 1
"27173" = 4
"28001" = 10
"28003" = 10
"28005" = 10
"28007" = 10
"28009" = 10
"28011" = 10
"28013" = 10
"28015" = 8
"28017" = 10
"28019" = 10
"28021" = 10
"28023" = 10
"28025" = 10
"28027" = 10
"28029" = 10
"28031" = 9
"28033" = 2
"28035" = 10
"28037" = 9
"28039" = 7
"28041" = 10
"28043" = 9
"28045" = 8
"28047" = 9
"28049" = 10
"28051" = 10
"28053" = 10
"28055" = 10
"28057" = 7
"28059" = 6
"28061" = 9
"28063" = 10
"28065" = 10
"28067" = 10
"28069" = 10
"28071" = 9
"28073" = 6
"28075" = 10
"28077" = 8
"28079" = 10
"28081" = 9
"28083" = 10
"28085" = 8
"28087" = 10
"28089" = 4
"28091" = 10
"28093" = 10
"28095" = 10
"28097" = 10
"28099" = 10
"28101" = 9
"28103" = 10
"28105" = 10
"28107" = 10
"28109" = 9
"28111" = 9
"28113" = 10
"28115" = 6
"28117" = 10
"28119" = 10
"28121" = 4
"28123" = 9
"28125" = 10
"28127" = 10
"28129" = 9
"28131" = 9
"28133" = 10
"28135" = 10
"28137" = 8
"28139" = 9
"28141" = 8
"28143" = 10
"28145" = 9
"28147" = 10
"28149" = 10
"28151" = 10
"28153" = 10
"28155" = 10
"28157" = 10
"28159" = 10
"28161" = 10
"28163" = 10
"29001" = 10
"29003" = 2
"29005" = 3
"29007" = 8
"29009" = 8
"29011" = 7
"29013" = 6
"29015" = 9
"29017" = 9
"29019" = 8
"29021" = 6
"29023" = 9
"29025" = 4
"29027" = 4
"29029" = 5
"29031" = 5
"29033" = 6
"29035" = 10
"29037" = 2
"29039" = 9
"29041" = 4
"29043" = 3
"29045" = 6
"29047" = 2
"29049" = 3
"29051" = 3
"29053" = 6
"29055" = 9
"29057" = 9
"29059" = 9
"29061" = 7
"29063" = 6
"29065" = 9
"29067" = 10
"29069" = 10
"29071" = 4
"29073" = 4
"29075" = 5
"29077" = 9
"29079" = 7
"29081" = 7
"29083" = 7
"29085" = 10
"29087" = 5
"29089" = 6
"29091" = 9
"29093" = 9
"29095" = 7
"29097" = 7
"29099" = 3
"29101" = 8
"29103" = 9
"29105" = 8
"29107" = 3
"29109" = 6
"29111" = 6
"29113" = 3
"29115" = 6
"29117" = 6
"29119" = 9
"29121" = 5
"29123" = 9
"29125" = 5
"29127" = 6
"29129" = 5
"29131" = 9
"29133" = 10
"29135" = 5
"29137" = 5
"29139" = 7
"29141" = 9
"29143" = 10
"29145" = 6
"29147" = 7
"29149" = 10
"29151" = 3
"29153" = 10
"29155" = 10
"29157" = 4
"29159" = 8
"29161" = 8
"29163" = 8
"29165" = 1
"29167" = 9
"29169" = 5
"29171" = 9
"29173" = 3
"29175" = 8
"29177" = 3
"29179" = 10
"29181" = 10
"29183" = 1
"29185" = 9
"29186" = 3
"29187" = 8
"29189" = 2
"29195" = 9
"29197" = 9
"29199" = 6
"29201" = 8
"29203" = 10
"29205" = 5
"29207" = 8
"29209" = 6
"29211" = 7
"29213" = 9
"29215" = 10
"29217" = 8
"29219" = 4
"29221" = 10
"29223" = 10
"29225" = 7
"29227" = 6
"29229" = 10
"29510" = 10
"30001" = 8
"30003" = 10
"30005" = 10
"30007" = 3
"30009" = 4
"30011" = 8
"30013" = 4
"30015" = 6
"30017" = 5
"30019" = 3
"30021" = 4
"30023" = 8
"30025" = 2
"30027" = 4
"30029" = 5
"30031" = 4
"30033" = 9
"30035" = 10
"30037" = 9
"30039" = 5
"30041" = 8
"30043" = 2
"30045" = 6
"30047" = 9
"30049" = 3
"30051" = 10
"30053" = 8
"30055" = 6
"30057" = 3
"30059" = 9
"30061" = 8
"30063" = 5
"30065" = 8
"30067" = 4
"30069" = 9
"30071" = 6
"30073" = 9
"30075" = 5
"30077" = 9
"30079" = 6
"30081" = 7
"30083" = 3
"30085" = 10
"30087" = 8
"30089" = 9
"30091" = 3
"30093" = 8
"30095" = 2
"30097" = 3
"30099" = 6
"30101" = 6
"30103" = 3
"30105" = 4
"30107" = 7
"30109" = 4
"30111" = 4
"31001" = 4
"31003" = 4
"31005" = 3
"31007" = 4
"31009" = 9
"31011" = 2
"31013" = 4
"31015" = 4
"31017" = 4
"31019" = 4
"31021" = 3
"31023" = 2
"31025" = 1
"31027" = 3
"31029" = 3
"31031" = 4
"31033" = 2
"31035" = 3
"31037" = 3
"31039" = 2
"31041" = 4
"31043" = 4
"31045" = 7
"31047" = 3
"31049" = 4
"31051" = 2
"31053" = 4
"31055" = 5
"31057" = 4
"31059" = 2
"31061" = 5
"31063" = 4
"31065" = 4
"31067" = 4
"31069" = 6
"31071" = 5
"31073" = 2
"31075" = 3
"31077" = 4
"31079" = 4
"31081" = 2
"31083" = 3
"31085" = 7
"31087" = 5
"31089" = 4
"31091" = 2
"31093" = 2
"31095" = 4
"31097" = 3
"31099" = 2
"31101" = 3
"31103" = 10
"31105" = 4
"31107" = 5
"31109" = 5
"31111" = 3
"31113" = 4
"31115" = 7
"31117" = 8
"31119" = 4
"31121" = 3
"31123" = 6
"31125" = 4
"31127" = 4
"31129" = 4
"31131" = 2
"31133" = 4
"31135" = 2
"31137" = 2
"31139" = 2
"31141" = 2
"31143" = 2
"31145" = 4
"31147" = 4
"31149" = 6
"31151" = 2
"31153" = 1
"31155" = 2
"31157" = 6
"31159" = 1
"31161" = 7
"31163" = 4
"31165" = 7
"31167" = 2
"31169" = 3
"31171" = 6
"31173" = 10
"31175" = 5
"31177" = 1
"31179" = 5
"31181" = 3
"31183" = 9
"31185" = 2
"32001" = 3
"32003" = 5
"32005" = 2
"32007" = 2
"32009" = 5
"32011" = 2
"32013" = 2
"32015" = 2
"32017" = 4
"32019" = 3
"32021" = 6
"32023" = 8
"32027" = 8
"32029" = 2
"32031" = 5
"32033" = 4
"32510" = 5
"33001" = 2
"33003" = 2
"33005" = 3
"33007" = 5
"33009" = 3
"33011" = 1
"33013" = 2
"33015" = 1
"33017" = 3
"33019" = 3
"34001" = 4
"34003" = 1
"34005" = 1
"34007" = 3
"34009" = 3
"34011" = 7
"34013" = 6
"34015" = 1
"34017" = 6
"34019" = 1
"34021" = 3
"34023" = 1
"34025" = 1
"34027" = 1
"34029" = 3
"34031" = 6
"34033" = 3
"34035" = 1
"34037" = 1
"34039" = 3
"34041" = 1
"35001" = 6
"35003" = 10
"35005" = 10
"35006" = 10
"35007" = 8
"35009" = 9
"35011" = 8
"35013" = 10
"35015" = 6
"35017" = 8
"35019" = 10
"35021" = 4
"35023" = 10
"35025" = 8
"35027" = 8
"35028" = 1
"35029" = 10
"35031" = 10
"35033" = 10
"35035" = 10
"35037" = 10
"35039" = 9
"35041" = 10
"35043" = 4
"35045" = 10
"35047" = 10
"35049" = 6
"35051" = 9
"35053" = 10
"35055" = 8
"35057" = 10
"35059" = 8
"35061" = 10
"36001" = 4
"36003" = 7
"36005" = 10
"36007" = 6
"36009" = 5
"36011" = 4
"36013" = 7
"36015" = 6
"36017" = 6
"36019" = 6
"36021" = 2
"36023" = 5
"36025" = 3
"36027" = 1
"36029" = 5
"36031" = 4
"36033" = 6
"36035" = 6
"36037" = 3
"36039" = 7
"36041" = 2
"36043" = 6
"36045" = 5
"36047" = 10
"36049" = 5
"36051" = 4
"36053" = 3
"36055" = 5
"36057" = 7
"36059" = 1
"36061" = 6
"36063" = 4
"36065" = 5
"36067" = 4
"36069" = 2
"36071" = 3
"36073" = 4
"36075" = 7
"36077" = 6
"36079" = 1
"36081" = 5
"36083" = 4
"36085" = 3
"36087" = 3
"36089" = 7
"36091" = 1
"36093" = 3
"36095" = 4
"36097" = 4
"36099" = 4
"36101" = 5
"36103" = 1
"36105" = 9
"36107" = 2
"36109" = 9
"36111" = 4
"36113" = 2
"36115" = 3
"36117" = 2
"36119" = 2
"36121" = 3
"36123" = 7
"37001" = 8
"37003" = 7
"37005" = 10
"37007" = 10
"37009" = 9
"37011" = 10
"37013" = 9
"37015" = 10
"37017" = 10
"37019" = 6
"37021" = 7
"37023" = 8
"37025" = 4
"37027" = 8
"37029" = 2
"37031" = 4
"37033" = 9
"37035" = 5
"37037" = 5
"37039" = 8
"37041" = 9
"37043" = 8
"37045" = 9
"37047" = 10
"37049" = 7
"37051" = 8
"37053" = 3
"37055" = 3
"37057" = 7
"37059" = 4
"37061" = 10
"37063" = 8
"37065" = 10
"37067" = 6
"37069" = 6
"37071" = 9
"37073" = 7
"37075" = 10
"37077" = 6
"37079" = 10
"37081" = 8
"37083" = 10
"37085" = 6
"37087" = 5
"37089" = 6
"37091" = 10
"37093" = 8
"37095" = 10
"37097" = 4
"37099" = 9
"37101" = 6
"37103" = 8
"37105" = 8
"37107" = 10
"37109" = 5
"37111" = 9
"37113" = 9
"37115" = 9
"37117" = 10
"37119" = 6
"37121" = 8
"37123" = 10
"37125" = 6
"37127" = 6
"37129" = 8
"37131" = 10
"37133" = 6
"37135" = 7
"37137" = 5
"37139" = 10
"37141" = 6
"37143" = 6
"37145" = 6
"37147" = 9
"37149" = 5
"37151" = 8
"37153" = 10
"37155" = 10
"37157" = 8
"37159" = 9
"37161" = 10
"37163" = 9
"37165" = 10
"37167" = 6
"37169" = 5
"37171" = 9
"37173" = 8
"37175" = 6
"37177" = 10
"37179" = 2
"37181" = 10
"37183" = 3
"37185" = 10
"37187" = 10
"37189" = 10
"37191" = 9
"37193" = 9
"37195" = 10
"37197" = 5
"37199" = 9
"38001" = 2
"38003" = 3
"38005" = 10
"38007" = 3
"38009" = 3
"38011" = 1
"38013" = 2
"38015" = 2
"38017" = 3
"38019" = 2
"38021" = 3
"38023" = 2
"38025" = 3
"38027" = 3
"38029" = 6
"38031" = 2
"38033" = 4
"38035" = 6
"38037" = 8
"38039" = 2
"38041" = 3
"38043" = 6
"38045" = 2
"38047" = 5
"38049" = 4
"38051" = 5
"38053" = 4
"38055" = 2
"38057" = 1
"38059" = 2
"38061" = 4
"38063" = 2
"38065" = 3
"38067" = 2
"38069" = 4
"38071" = 4
"38073" = 2
"38075" = 2
"38077" = 3
"38079" = 10
"38081" = 2
"38083" = 7
"38085" = 10
"38087" = 4
"38089" = 2
"38091" = 1
"38093" = 3
"38095" = 2
"38097" = 2
"38099" = 3
"38101" = 4
"38103" = 4
"38105" = 2
"39001" = 10
"39003" = 8
"39005" = 6
"39007" = 6
"39009" = 10
"39011" = 2
"39013" = 6
"39015" = 4
"39017" = 4
"39019" = 6
"39021" = 4
"39023" = 9
"39025" = 2
"39027" = 6
"39029" = 8
"39031" = 9
"39033" = 6
"39035" = 8
"39037" = 3
"39039" = 3
"39041" = 1
"39043" = 5
"39045" = 3
"39047" = 6
"39049" = 8
"39051" = 3
"39053" = 8
"39055" = 1
"39057" = 4
"39059" = 9
"39061" = 8
"39063" = 3
"39065" = 7
"39067" = 8
"39069" = 4
"39071" = 8
"39073" = 6
"39075" = 6
"39077" = 4
"39079" = 10
"39081" = 8
"39083" = 6
"39085" = 2
"39087" = 9
"39089" = 4
"39091" = 7
"39093" = 5
"39095" = 9
"39097" = 5
"39099" = 7
"39101" = 9
"39103" = 1
"39105" = 10
"39107" = 2
"39109" = 3
"39111" = 7
"39113" = 8
"39115" = 9
"39117" = 4
"39119" = 8
"39121" = 7
"39123" = 2
"39125" = 4
"39127" = 9
"39129" = 4
"39131" = 10
"39133" = 5
"39135" = 3
"39137" = 2
"39139" = 5
"39141" = 9
"39143" = 3
"39145" = 10
"39147" = 5
"39149" = 3
"39151" = 5
"39153" = 6
"39155" = 8
"39157" = 5
"39159" = 1
"39161" = 4
"39163" = 10
"39165" = 1
"39167" = 6
"39169" = 4
"39171" = 3
"39173" = 4
"39175" = 2
"40001" = 10
"40003" = 7
"40005" = 10
"40007" = 3
"40009" = 8
"40011" = 9
"40013" = 7
"40015" = 9
"40017" = 2
"40019" = 8
"40021" = 10
"40023" = 10
"40025" = 8
"40027" = 4
"40029" = 9
"40031" = 7
"40033" = 6
"40035" = 6
"40037" = 6
"40039" = 7
"40041" = 10
"40043" = 4
"40045" = 4
"40047" = 6
"40049" = 6
"40051" = 6
"40053" = 4
"40055" = 10
"40057" = 10
"40059" = 3
"40061" = 7
"40063" = 10
"40065" = 7
"40067" = 9
"40069" = 10
"40071" = 7
"40073" = 3
"40075" = 10
"40077" = 8
"40079" = 10
"40081" = 5
"40083" = 5
"40085" = 6
"40087" = 3
"40089" = 10
"40091" = 9
"40093" = 4
"40095" = 8
"40097" = 8
"40099" = 5
"40101" = 9
"40103" = 5
"40105" = 6
"40107" = 10
"40109" = 7
"40111" = 9
"40113" = 6
"40115" = 9
"40117" = 6
"40119" = 9
"40121" = 8
"40123" = 8
"40125" = 8
"40127" = 10
"40129" = 4
"40131" = 2
"40133" = 10
"40135" = 9
"40137" = 6
"40139" = 3
"40141" = 10
"40143" = 6
"40145" = 3
"40147" = 4
"40149" = 5
"40151" = 6
"40153" = 5
"41001" = 9
"41003" = 9
"41005" = 2
"41007" = 5
"41009" = 4
"41011" = 9
"41013" = 7
"41015" = 6
"41017" = 5
"41019" = 9
"41021" = 3
"41023" = 6
"41025" = 9
"41027" = 4
"41029" = 6
"41031" = 9
"41033" = 8
"41035" = 7
"41037" = 9
"41039" = 9
"41041" = 7
"41043" = 8
"41045" = 10
"41047" = 8
"41049" = 6
"41051" = 8
"41053" = 6
"41055" = 4
"41057" = 6
"41059" = 6
"41061" = 6
"41063" = 6
"41065" = 6
"41067" = 2
"41069" = 9
"41071" = 5
"42001" = 2
"42003" = 3
"42005" = 4
"42007" = 5
"42009" = 4
"42011" = 4
"42013" = 4
"42015" = 3
"42017" = 1
"42019" = 2
"42021" = 4
"42023" = 5
"42025" = 3
"42027" = 8
"42029" = 1
"42031" = 8
"42033" = 7
"42035" = 7
"42037" = 6
"42039" = 9
"42041" = 1
"42043" = 4
"42045" = 2
"42047" = 3
"42049" = 7
"42051" = 9
"42053" = 9
"42055" = 2
"42057" = 2
"42059" = 8
"42061" = 5
"42063" = 8
"42065" = 6
"42067" = 3
"42069" = 4
"42071" = 2
"42073" = 6
"42075" = 3
"42077" = 4
"42079" = 6
"42081" = 7
"42083" = 5
"42085" = 6
"42087" = 6
"42089" = 4
"42091" = 1
"42093" = 3
"42095" = 2
"42097" = 5
"42099" = 2
"42101" = 10
"42103" = 2
"42105" = 5
"42107" = 4
"42109" = 4
"42111" = 5
"42113" = 5
"42115" = 4
"42117" = 6
"42119" = 4
"42121" = 6
"42123" = 4
"42125" = 2
"42127" = 4
"42129" = 2
"42131" = 4
"42133" = 2
"44001" = 1
"44003" = 2
"44005" = 2
"44007" = 7
"44009" = 2
"45001" = 9
"45003" = 8
"45005" = 10
"45007" = 8
"45009" = 10
"45011" = 10
"45013" = 4
"45015" = 5
"45017" = 8
"45019" = 8
"45021" = 9
"45023" = 9
"45025" = 10
"45027" = 10
"45029" = 10
"45031" = 10
"45033" = 10
"45035" = 3
"45037" = 9
"45039" = 10
"45041" = 9
"45043" = 9
"45045" = 6
"45047" = 10
"45049" = 10
"45051" = 9
"45053" = 10
"45055" = 8
"45057" = 9
"45059" = 9
"45061" = 10
"45063" = 4
"45065" = 9
"45067" = 10
"45069" = 10
"45071" = 8
"45073" = 4
"45075" = 10
"45077" = 7
"45079" = 7
"45081" = 9
"45083" = 7
"45085" = 9
"45087" = 8
"45089" = 10
"45091" = 4
"46003" = 3
"46005" = 5
"46007" = 10
"46009" = 7
"46011" = 7
"46013" = 2
"46015" = 5
"46017" = 10
"46019" = 5
"46021" = 3
"46023" = 10
"46025" = 5
"46027" = 9
"46029" = 3
"46031" = 10
"46033" = 3
"46035" = 5
"46037" = 7
"46039" = 2
"46041" = 10
"46043" = 5
"46045" = 3
"46047" = 6
"46049" = 5
"46051" = 3
"46053" = 10
"46055" = 4
"46057" = 3
"46059" = 3
"46061" = 2
"46063" = 7
"46065" = 2
"46067" = 3
"46069" = 4
"46071" = 10
"46073" = 6
"46075" = 6
"46077" = 2
"46079" = 3
"46081" = 4
"46083" = 1
"46085" = 10
"46087" = 2
"46089" = 8
"46091" = 5
"46093" = 2
"46095" = 10
"46097" = 4
"46099" = 3
"46101" = 3
"46103" = 5
"46105" = 7
"46107" = 3
"46109" = 9
"46111" = 5
"46113" = 10
"46115" = 4
"46117" = 2
"46119" = 2
"46121" = 10
"46123" = 9
"46125" = 3
"46127" = 1
"46129" = 6
"46135" = 3
"46137" = 10
"47001" = 6
"47003" = 10
"47005" = 9
"47007" = 10
"47009" = 4
"47011" = 9
"47013" = 10
"47015" = 6
"47017" = 9
"47019" = 10
"47021" = 3
"47023" = 9
"47025" = 10
"47027" = 10
"47029" = 10
"47031" = 10
"47033" = 9
"47035" = 8
"47037" = 9
"47039" = 9
"47041" = 9
"47043" = 4
"47045" = 9
"47047" = 4
"47049" = 10
"47051" = 5
"47053" = 8
"47055" = 7
"47057" = 9
"47059" = 10
"47061" = 10
"47063" = 9
"47065" = 6
"47067" = 10
"47069" = 10
"47071" = 10
"47073" = 8
"47075" = 10
"47077" = 7
"47079" = 9
"47081" = 9
"47083" = 9
"47085" = 6
"47087" = 9
"47089" = 6
"47091" = 10
"47093" = 4
"47095" = 10
"47097" = 10
"47099" = 8
"47101" = 9
"47103" = 7
"47105" = 5
"47107" = 8
"47109" = 10
"47111" = 10
"47113" = 9
"47115" = 10
"47117" = 5
"47119" = 5
"47121" = 10
"47123" = 9
"47125" = 6
"47127" = 4
"47129" = 9
"47131" = 6
"47133" = 9
"47135" = 9
"47137" = 9
"47139" = 9
"47141" = 9
"47143" = 9
"47145" = 5
"47147" = 4
"47149" = 5
"47151" = 10
"47153" = 10
"47155" = 6
"47157" = 9
"47159" = 9
"47161" = 5
"47163" = 8
"47165" = 4
"47167" = 4
"47169" = 7
"47171" = 7
"47173" = 10
"47175" = 10
"47177" = 10
"47179" = 8
"47181" = 10
"47183" = 9
"47185" = 9
"47187" = 1
"47189" = 2
"48001" = 9
"48003" = 4
"48005" = 8
"48007" = 10
"48009" = 3
"48011" = 2
"48013" = 9
"48015" = 4
"48017" = 8
"48019" = 6
"48021" = 6
"48023" = 9
"48025" = 10
"48027" = 4
"48029" = 7
"48031" = 4
"48033" = 3
"48035" = 7
"48037" = 8
"48039" = 3
"48041" = 10
"48043" = 5
"48045" = 6
"48047" = 10
"48049" = 8
"48051" = 5
"48053" = 5
"48055" = 7
"48057" = 9
"48059" = 6
"48061" = 10
"48063" = 9
"48065" = 2
"48067" = 9
"48069" = 9
"48071" = 2
"48073" = 10
"48075" = 10
"48077" = 4
"48079" = 9
"48081" = 4
"48083" = 9
"48085" = 1
"48087" = 8
"48089" = 7
"48091" = 3
"48093" = 9
"48095" = 10
"48097" = 5
"48099" = 4
"48101" = 9
"48103" = 2
"48105" = 6
"48107" = 10
"48109" = 10
"48111" = 5
"48113" = 8
"48115" = 10
"48117" = 9
"48119" = 8
"48121" = 1
"48123" = 9
"48125" = 9
"48127" = 10
"48129" = 7
"48131" = 10
"48133" = 10
"48135" = 9
"48137" = 10
"48139" = 3
"48141" = 10
"48143" = 8
"48145" = 10
"48147" = 6
"48149" = 4
"48151" = 5
"48153" = 9
"48155" = 8
"48157" = 2
"48159" = 6
"48161" = 8
"48163" = 10
"48165" = 8
"48167" = 4
"48169" = 10
"48171" = 3
"48173" = 3
"48175" = 6
"48177" = 9
"48179" = 6
"48181" = 5
"48183" = 9
"48185" = 9
"48187" = 3
"48189" = 9
"48191" = 10
"48193" = 6
"48195" = 5
"48197" = 10
"48199" = 4
"48201" = 8
"48203" = 7
"48205" = 3
"48207" = 10
"48209" = 5
"48211" = 2
"48213" = 9
"48215" = 10
"48217" = 7
"48219" = 9
"48221" = 3
"48223" = 8
"48225" = 10
"48227" = 10
"48229" = 10
"48231" = 9
"48233" = 4
"48235" = 2
"48237" = 6
"48239" = 6
"48241" = 9
"48243" = 3
"48245" = 10
"48247" = 10
"48249" = 9
"48251" = 4
"48253" = 10
"48255" = 10
"48257" = 3
"48259" = 2
"48261" = 4
"48263" = 3
"48265" = 6
"48267" = 8
"48269" = 4
"48271" = 10
"48273" = 10
"48275" = 10
"48277" = 8
"48279" = 9
"48281" = 5
"48283" = 10
"48285" = 5
"48287" = 4
"48289" = 5
"48291" = 8
"48293" = 8
"48295" = 4
"48297" = 8
"48299" = 6
"48301" = 5
"48303" = 9
"48305" = 9
"48307" = 10
"48309" = 9
"48311" = 3
"48313" = 10
"48315" = 10
"48317" = 6
"48319" = 6
"48321" = 9
"48323" = 10
"48325" = 7
"48327" = 10
"48329" = 5
"48331" = 9
"48333" = 7
"48335" = 10
"48337" = 6
"48339" = 3
"48341" = 5
"48343" = 9
"48345" = 6
"48347" = 10
"48349" = 9
"48351" = 10
"48353" = 9
"48355" = 9
"48357" = 4
"48359" = 4
"48361" = 5
"48363" = 7
"48365" = 4
"48367" = 3
"48369" = 5
"48371" = 10
"48373" = 9
"48375" = 10
"48377" = 10
"48379" = 6
"48381" = 2
"48383" = 3
"48385" = 10
"48387" = 9
"48389" = 10
"48391" = 8
"48393" = 1
"48395" = 9
"48397" = 1
"48399" = 10
"48401" = 5
"48403" = 8
"48405" = 9
"48407" = 9
"48409" = 9
"48411" = 9
"48413" = 7
"48415" = 7
"48417" = 4
"48419" = 10
"48421" = 4
"48423" = 5
"48425" = 2
"48427" = 10
"48429" = 9
"48431" = 4
"48433" = 7
"48435" = 4
"48437" = 9
"48439" = 5
"48441" = 8
"48443" = 5
"48445" = 10
"48447" = 5
"48449" = 9
"48451" = 9
"48453" = 8
"48455" = 8
"48457" = 9
"48459" = 6
"48461" = 6
"48463" = 10
"48465" = 10
"48467" = 7
"48469" = 8
"48471" = 10
"48473" = 9
"48475" = 9
"48477" = 5
"48479" = 10
"48481" = 9
"48483" = 4
"48485" = 7
"48487" = 7
"48489" = 10
"48491" = 1
"48493" = 3
"48495" = 6
"48497" = 4
"48499" = 8
"48501" = 5
"48503" = 7
"48505" = 10
"48507" = 10
"49001" = 4
"49003" = 2
"49005" = 6
"49007" = 5
"49009" = 1
"49011" = 1
"49013" = 4
"49015" = 3
"49017" = 3
"49019" = 5
"49021" = 9
"49023" = 3
"49025" = 4
"49027" = 4
"49029" = 1
"49031" = 9
"49033" = 3
"49035" = 4
"49037" = 10
"49039" = 8
"49041" = 5
"49043" = 1
"49045" = 2
"49047" = 5
"49049" = 5
"49051" = 1
"49053" = 5
"49055" = 5
"49057" = 4
"50001" = 3
"50003" = 4
"50005" = 6
"50007" = 3
"50009" = 7
"50011" = 3
"50013" = 1
"50015" = 4
"50017" = 4
"50019" = 7
"50021" = 4
"50023" = 3
"50025" = 4
"50027" = 2
"51001" = 9
"51003" = 2
"51005" = 4
"51007" = 3
"51009" = 4
"51011" = 4
"51013" = 1
"51015" = 2
"51017" = 3
"51019" = 2
"51021" = 5
"51023" = 1
"51025" = 9
"51027" = 10
"51029" = 9
"51031" = 5
"51033" = 3
"51035" = 7
"51036" = 3
"51037" = 8
"51041" = 1
"51043" = 2
"51045" = 3
"51047" = 2
"51049" = 7
"51051" = 10
"51053" = 3
"51057" = 4
"51059" = 1
"51061" = 1
"51063" = 4
"51065" = 1
"51067" = 5
"51069" = 1
"51071" = 4
"51073" = 2
"51075" = 1
"51077" = 7
"51079" = 2
"51081" = 10
"51083" = 9
"51085" = 1
"51087" = 2
"51089" = 8
"51091" = 5
"51093" = 2
"51095" = 1
"51097" = 4
"51099" = 1
"51101" = 1
"51103" = 4
"51105" = 10
"51107" = 1
"51109" = 2
"51111" = 9
"51113" = 3
"51115" = 2
"51117" = 9
"51119" = 4
"51121" = 9
"51125" = 4
"51127" = 1
"51131" = 8
"51133" = 5
"51135" = 9
"51137" = 2
"51139" = 6
"51141" = 8
"51143" = 6
"51145" = 1
"51147" = 10
"51149" = 2
"51153" = 1
"51155" = 6
"51157" = 2
"51159" = 8
"51161" = 1
"51163" = 3
"51165" = 3
"51167" = 8
"51169" = 8
"51171" = 3
"51173" = 8
"51175" = 6
"51177" = 1
"51179" = 1
"51181" = 3
"51183" = 10
"51185" = 8
"51187" = 2
"51191" = 4
"51193" = 5
"51195" = 10
"51197" = 6
"51199" = 1
"51510" = 2
"51515" = 7
"51520" = 9
"51530" = 6
"51540" = 9
"51550" = 1
"51570" = 2
"51580" = 6
"51590" = 10
"51595" = 10
"51600" = 1
"51610" = 1
"51620" = 9
"51630" = 9
"51640" = 10
"51650" = 4
"51660" = 10
"51670" = 7
"51678" = 9
"51680" = 10
"51683" = 3
"51685" = 2
"51690" = 10
"51700" = 5
"51710" = 8
"51720" = 9
"51730" = 10
"51735" = 1
"51740" = 8
"51750" = 10
"51760" = 10
"51770" = 10
"51775" = 2
"51790" = 5
"51800" = 3
"51810" = 1
"51820" = 7
"51830" = 8
"51840" = 9
"53001" = 9
"53003" = 6
"53005" = 4
"53007" = 5
"53009" = 6
"53011" = 4
"53013" = 5
"53015" = 9
"53017" = 5
"53019" = 9
"53021" = 8
"53023" = 4
"53025" = 9
"53027" = 8
"53029" = 2
"53031" = 3
"53033" = 3
"53035" = 3
"53037" = 9
"53039" = 7
"53041" = 6
"53043" = 3
"53045" = 6
"53047" = 10
"53049" = 8
"53051" = 8
"53053" = 3
"53055" = 3
"53057" = 4
"53059" = 4
"53061" = 2
"53063" = 5
"53065" = 7
"53067" = 2
"53069" = 4
"53071" = 6
"53073" = 5
"53075" = 10
"53077" = 10
"54001" = 7
"54003" = 4
"54005" = 8
"54007" = 10
"54009" = 5
"54011" = 10
"54013" = 10
"54015" = 10
"54017" = 9
"54019" = 10
"54021" = 10
"54023" = 7
"54025" = 9
"54027" = 8
"54029" = 4
"54031" = 6
"54033" = 7
"54035" = 9
"54037" = 3
"54039" = 5
"54041" = 9
"54043" = 10
"54045" = 10
"54047" = 10
"54049" = 7
"54051" = 7
"54053" = 8
"54055" = 9
"54057" = 6
"54059" = 10
"54061" = 10
"54063" = 8
"54065" = 4
"54067" = 8
"54069" = 6
"54071" = 5
"54073" = 5
"54075" = 9
"54077" = 6
"54079" = 2
"54081" = 8
"54083" = 8
"54085" = 9
"54087" = 10
"54089" = 10
"54091" = 9
"54093" = 9
"54095" = 6
"54097" = 10
"54099" = 9
"54101" = 10
"54103" = 8
"54105" = 10
"54107" = 6
"54109" = 9
"55001" = 5
"55003" = 8
"55005" = 4
"55007" = 5
"55009" = 2
"55011" = 3
"55013" = 5
"55015" = 1
"55017" = 3
"55019" = 5
"55021" = 2
"55023" = 5
"55025" = 3
"55027" = 2
"55029" = 3
"55031" = 5
"55033" = 5
"55035" = 6
"55037" = 4
"55039" = 3
"55041" = 7
"55043" = 6
"55045" = 2
"55047" = 4
"55049" = 2
"55051" = 7
"55053" = 8
"55055" = 3
"55057" = 6
"55059" = 4
"55061" = 2
"55063" = 4
"55065" = 3
"55067" = 4
"55069" = 3
"55071" = 3
"55073" = 3
"55075" = 5
"55077" = 3
"55078" = 10
"55079" = 10
"55081" = 6
"55083" = 4
"55085" = 3
"55087" = 2
"55089" = 1
"55091" = 3
"55093" = 3
"55095" = 4
"55097" = 3
"55099" = 4
"55101" = 5
"55103" = 5
"55105" = 4
"55107" = 9
"55109" = 1
"55111" = 3
"55113" = 8
"55115" = 4
"55117" = 2
"55119" = 4
"55121" = 4
"55123" = 5
"55125" = 5
"55127" = 4
"55129" = 5
"55131" = 1
"55133" = 1
"55135" = 3
"55137" = 5
"55139" = 3
"55141" = 3
"56001" = 9
"56003" = 4
"56005" = 1
"56007" = 4
"56009" = 2
"56011" = 1
"56013" = 4
"56015" = 7
"56017" = 3
"56019" = 2
"56021" = 3
"56023" = 2
"56025" = 2
"56027" = 5
"56029" = 3
"56031" = 3
"56033" = 2
"56035" = 1
"56037" = 2
"56039" = 2
"56041" = 3
"56043" = 3
"56045" = 2
"02201" = 7
"02232" = 5
"02280" = 3
OTHER = 0
;

run;
